@@ -1,10 +1,30 @@
 /*
  * GNOME diskusage panel applet
  * (C) 1997 The Free Software Foundation
+ *
+ * Shows a pie with the used and free space
+ * for the selected filesystem.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *                                
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *           
+ * Authors: 	Bruno Widmann
+ *		Martin Baulig - libgtop support
+ *		Dave Finton - mountlist menu
  * 
- * Author: Bruno Widmann
- * 	   Modified from code taken from 
- * 	   cpumemusage & cpuload applets.
+ * With code from cpumemusage & cpuload applets.
+ *
  */
 
 #include <stdio.h>
@@ -20,11 +40,9 @@
 
 #include "diskusage.h"
 #include "properties.h"
-#include "mountlist.h"
 
 /*#define DU_DEBUG*/
 
-
 diskusage_properties props;
 
 static gint update_values ();
@@ -32,13 +50,28 @@ static gint update_values ();
 DiskusageInfo   summary_info;
 
 static GtkWidget *diskusage;
-static GtkWidget *my_frame;  /* the frame wherer hbox or vbox reside   */
 static GtkWidget *my_applet;
 GtkWidget *disp;
 GdkPixmap *pixmap;
 GdkGC *gc;
 GdkColor ucolor, fcolor, tcolor, bcolor;
 
+void update_mount_list_menu_items (void);
+void diskusage_resize (void);
+int draw_h(void);
+int draw_v(void);
+void draw(void);
+void setup_colors(void);
+void create_gc(void);
+void start_timer(void);
+void change_filesystem_cb (AppletWidget *applet, gpointer data);
+void add_mount_list_menu_items (void);
+GtkWidget *diskusage_widget(void);
+
+GString **mpoints;
+GString **menuitem;
+guint num_mpoints;
+
 int timer_index=-1;
 
 int first_time=1;
@@ -53,7 +86,6 @@ void diskusage_resize ()
  */
 int draw_h(void)
 {
-	int i, l;
 
 	GdkFont* my_font;
 	char *text;
@@ -157,7 +189,6 @@ int draw_h(void)
  */
 int draw_v(void)
 {
-	int i, l;
 
 	GdkFont* my_font;
 	char *text;
@@ -184,7 +215,7 @@ int draw_v(void)
 
 
 	/* Free Space text, part1*/		        
-	sprintf (avail_buf2,"av: \0", summary_info.filesystems[sel_fs].sizeinfo[2]);
+	sprintf (avail_buf2,"av: \0");
 
 
 	
@@ -274,7 +305,7 @@ int draw_v(void)
 
 
 
-int draw(void)
+void draw(void)
 {
 
 	if (summary_info.orient == ORIENT_LEFT || summary_info.orient == ORIENT_RIGHT)
@@ -377,8 +408,10 @@ static gint update_values ()
 #endif
 
 	diskusage_read (&summary_info);
-	draw();
+	update_mount_list_menu_items ();
 	
+	draw();
+
 	return TRUE;
 }
 
@@ -437,9 +470,138 @@ static gint diskusage_clicked_cb(GtkWidget * widget, GdkEventButton * e,
 	return TRUE; 
 }
 
+void change_filesystem_cb (AppletWidget *applet, gpointer data) {
+
+  gchar *my_mpoint = (gchar *)data;
+
+  guint n_mpoints = summary_info.n_filesystems;
+  guint lim1;
+
+  for (lim1 = 0; lim1 < n_mpoints; lim1++)
+    if (!strcmp (my_mpoint, summary_info.filesystems [lim1].mount_dir))
+      break;
+
+  summary_info.selected_filesystem = lim1;
+  props.startfs = summary_info.selected_filesystem;
+
+  update_values ();
+
+}
+
+void add_mount_list_menu_items (void) {
+
+  guint n_mpoints = summary_info.n_filesystems;
+  guint lim1;
+
+  gchar digit1 = '0', digit2 = '0';
+
+  mpoints = g_new0 (GString *, n_mpoints);
+  menuitem = g_new0 (GString *, n_mpoints);
+
+  applet_widget_register_callback_dir (APPLET_WIDGET (my_applet),
+				       "filesystem",
+				       "File Systems");
+
+  for (lim1 = 0; lim1 < n_mpoints; lim1++) {
+
+    mpoints [lim1] = g_string_new (summary_info.filesystems [lim1].mount_dir);
+
+    menuitem [lim1] = g_string_new ("filesystem/fsitem");
+    g_string_append_c (menuitem [lim1], digit1);
+    g_string_append_c (menuitem [lim1], digit2);
+
+    if (digit2 == '9') {
+      digit1++;
+      digit2 = '0';
+    }
+    else
+      digit2++;
+
+    applet_widget_register_callback (APPLET_WIDGET (my_applet),
+				     menuitem [lim1]->str,
+				     mpoints [lim1]->str,
+				     change_filesystem_cb,
+				     mpoints [lim1]->str);
+
+  }
+
+  num_mpoints = n_mpoints;
+
+}
+
+void update_mount_list_menu_items () {
+
+  guint n_mpoints = summary_info.n_filesystems;
+  guint lim1;
+  int retval = TRUE;
+
+  gchar digit1 = '0', digit2 = '0';
+
+  if (num_mpoints != n_mpoints)
+    retval = FALSE;
+
+  for (lim1 = 0; (lim1 < n_mpoints) && retval; lim1++)
+    if (strcmp (mpoints [lim1]->str, summary_info.filesystems [lim1].mount_dir)) {
+      retval = FALSE;
+      break;
+    }
+
+  if (!retval) {
+
+    printf ("File System Changed!\n");
+
+    for (lim1 = 0; lim1 < num_mpoints; lim1++) {
+
+      /* This causes a sigsegv if the menu is actually open... dunno
+	 what to do about it :) */
+
+      applet_widget_unregister_callback (APPLET_WIDGET (my_applet), 
+					 menuitem [lim1]->str);
+
+      g_string_free (mpoints [lim1], TRUE);
+      g_string_free (menuitem [lim1], TRUE);
+
+    }
+
+    g_free (mpoints);
+    g_free (menuitem);
+
+    num_mpoints = n_mpoints;
+
+    mpoints = g_new0 (GString *, n_mpoints);
+    menuitem = g_new0 (GString *, n_mpoints);
+
+    for (lim1 = 0; lim1 < num_mpoints; lim1++) {
+
+      mpoints [lim1] = g_string_new (summary_info.filesystems [lim1].mount_dir);
+
+      menuitem [lim1] = g_string_new ("filesystem/fsitem");
+      g_string_append_c (menuitem [lim1], digit1);
+      g_string_append_c (menuitem [lim1], digit2);
+
+      if (digit2 == '9') {
+	digit1++;
+	digit2 = '0';
+      }
+      else
+	digit2++;
+
+      applet_widget_register_callback (APPLET_WIDGET (my_applet),
+				       menuitem [lim1]->str,
+				       mpoints [lim1]->str,
+				       change_filesystem_cb,
+				       mpoints [lim1]->str);
+
+    }
+
+  }
+
+
+
+}
+
 GtkWidget *diskusage_widget(void)
 {
-	int i;
 	
 	GtkWidget *frame, *box;
 	GtkWidget *event_box;
@@ -447,12 +609,6 @@ GtkWidget *diskusage_widget(void)
 #ifdef DU_DEBUG
 	printf ("entering diskusage_widget  \n");
 #endif
-	
-
-	/*
-	 * default to horizontal panel, as long as we don't know for sure
-	 */
-	/*summary_info.orient = ORIENT_UP;*/
 
 	summary_info.selected_filesystem = 0;
 
@@ -500,32 +656,8 @@ GtkWidget *diskusage_widget(void)
 
 	return frame;
 	
-
 }
 
-static void
-about_cb (AppletWidget *widget, gpointer data)
-{
-	GtkWidget *about;
-	gchar *authors[] = {
-		"Bruno Widmann (bwidmann@tks.fh-sbg.ac.at)",
-		"Martin Baulig (martin@home-of-linux.org)",
-	  NULL
-	  };
-
-	about = gnome_about_new ( "The GNOME Disk Usage Applet", "0.1.0",
-			"(C) 1998",
-			authors,
-			"This applet is released under "
-			"the terms and conditions of the "
-			"GNU Public Licence."
-			"\nShows a pie with the used and free space "
-			"for the selected filesystem.  ",
-			NULL);
-	gtk_widget_show (about);
-
-	return;
-}
 
 static gint applet_save_session(GtkWidget *widget, char *privcfgpath, char *globcfgpath, gpointer data)
 {
@@ -566,12 +698,7 @@ int main(int argc, char **argv)
 	create_gc();
 	setup_colors();
        	
-	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
-					      "about",
-					      GNOME_STOCK_MENU_ABOUT,
-					      _("About..."),
-					      about_cb,
-					      NULL);
+	add_mount_list_menu_items ();
         
 	gtk_signal_connect(GTK_OBJECT(applet),"save_session",
                            GTK_SIGNAL_FUNC(applet_save_session),
@@ -584,8 +711,6 @@ int main(int argc, char **argv)
 					      properties,
 					      NULL);
 
-
-	
 	applet_widget_gtk_main();
 
 
