@@ -1,5 +1,5 @@
 /*#####################################################*/
-/*##           modemlights applet 0.3.1 beta         ##*/
+/*##           modemlights applet 0.3.2              ##*/
 /*#####################################################*/
 
 #include "modemlights.h"
@@ -10,18 +10,22 @@
 #include "button_off.xpm"
 #include "button_on.xpm"
 
-/* how many times per second to update the lights (1 - 20) */
-gint UPDATE_DELAY = 10;
+#ifdef __linux__
+#include <linux/isdn.h>
+#include <sys/ioctl.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 
-/* the modem lock file */
-gchar *lock_file;
+static unsigned long *isdn_stats = NULL;
+#endif
 
-/* connection commands */
-gchar *command_connect;
+gint UPDATE_DELAY = 5;		/* status lights update interval in Hz (1 - 20) */
+gchar *lock_file;		/* the modem lock file */
+gchar *device_name;		/* the device name eg:ppp0 */
+gchar *command_connect;		/* connection commands */
 gchar *command_disconnect;
-
-/* do we ask for confirmation? */
-gint ask_for_confirmation = TRUE;
+gint ask_for_confirmation = TRUE;	/* do we ask for confirmation? */
+gint use_ISDN = FALSE;		/* do we use ISDN? */
 
 GtkWidget *applet;
 static GtkWidget *frame;
@@ -49,6 +53,28 @@ static int confirm_dialog = FALSE;
 
 static PanelOrientType orient;
 
+static void about_cb (AppletWidget *widget, gpointer data);
+static int is_Modem_on();
+static int is_ISDN_on();
+static int is_connected();
+static void command_connect_cb( gint button, gpointer data);
+static void command_disconnect_cb( gint button, gpointer data);
+static void dial_cb();
+static void update_tooltip(int connected, int rx, int tx);
+static void redraw_display();
+static void draw_load(int rxbytes,int txbytes);
+static void draw_light(int lit,int x,int y);
+static void update_lights(int rx,int tx,int cd);
+static gint update_display();
+static void create_pixmaps();
+static void setup_colors();
+static void applet_change_orient(GtkWidget *w, PanelOrientType o, gpointer data);
+static gint applet_save_session(GtkWidget *widget, char *privcfgpath, char *globcfgpath);
+
+static int get_modem_stats(int *in, int *out);
+static int get_ISDN_stats(int *in, int *out);
+static int get_stats(int *in, int *out);
+
 static void about_cb (AppletWidget *widget, gpointer data)
 {
 	GtkWidget *about;
@@ -71,7 +97,7 @@ static void about_cb (AppletWidget *widget, gpointer data)
 	gtk_widget_show (about);
 }
 
-static int Modem_on()
+static int is_Modem_on()
 {
 	FILE *f = 0;
 
@@ -83,6 +109,188 @@ static int Modem_on()
 	return TRUE;
 }
 
+/* FIX ME!** this is a slot for checking if isdn is connected,
+ * add code please */
+static int is_ISDN_on()
+{
+#ifdef __linux__
+
+	/* Perhaps I should try to explain this code a little bit.
+	 *
+	 * ------------------------------------------------------------
+	 * This is from the manpage of isdninfo(4):
+	 *
+	 * DESCRIPTION
+	 *   /dev/isdninfo  is  a character device with major number 45
+	 *   and minor number 255.  It delivers status information from
+	 *   the Linux ISDN subsystem to user level.
+	 *
+	 * DATA FORMAT
+	 *   When  reading  from this device, the current status of the
+	 *   Linux ISDN subsystem is delivered in 6 lines of text. Each
+	 *   line  starts  with  a  tag  string followed by a colon and
+	 *   whitespace. After that the status values are appended sep-
+	 *   arated by whitespace.
+	 *
+	 *   flags  is the tag of line 5. In this line for every driver
+	 *          slot, it's B-Channel status is shown. If no  driver
+	 *          is  registered  in a slot, a ? is shown.  For every
+	 *          established B-Channel of the driver, a bit  is  set
+	 *          in  the  shown value. The driver's first channel is
+	 *          mapped to bit 0, the second channel to bit 1 and so
+	 *          on.
+	 * ------------------------------------------------------------
+	 *
+	 * So we open /dev/isdninfo, discard the first four lines of text
+	 * and then check whether we have something that is not `0' or `?'
+	 * in one of the flags fields.
+	 *
+	 * Sounds complicated, but I don't see any other way to check whether
+	 * we are connected. Also, this is the method some other ISDN tools
+	 * for Linux use.
+	 *
+	 * Martin
+	 */
+
+	FILE *f = 0;
+	char buffer [BUFSIZ], *p;
+	int i;
+
+	f = fopen("/dev/isdninfo", "r");
+
+	if (!f) return FALSE;
+
+	for (i = 0; i < 5; i++) {
+		if (fgets (buffer, BUFSIZ, f) == NULL) {
+			fclose (f);
+			return FALSE;
+		}
+	}
+
+	if (strncmp (buffer, "flags:", 6)) {
+		fclose (f);
+		return FALSE;
+	}
+
+	p = buffer+6;
+
+	while (*p) {
+		char *end = p;
+
+		if (isspace (*p)) {
+			p++;
+			continue;
+		}
+
+		for (end = p; *end && !isspace (*end); end++)
+			;
+
+		if (*end == 0)
+			break;
+		else
+			*end = 0;
+
+		if (!strcmp (p, "?") || !strcmp (p, "0")) {
+			p = end+1;
+			continue;
+		}
+
+		fclose (f);
+
+		return TRUE;
+	}
+
+	fclose (f);
+
+	return FALSE;
+#else
+	return FALSE;
+#endif
+}
+
+static int is_connected()
+{
+	if (use_ISDN)
+		return is_ISDN_on();
+	else
+		return is_Modem_on();
+}
+
+static int get_modem_stats(int *in, int *out)
+{
+	struct 	ifreq ifreq;
+	struct 	ppp_stats stats;
+
+	memset(&ifreq, 0, sizeof(ifreq));
+#ifndef __FreeBSD__
+	strncpy(ifreq.ifr_ifrn.ifrn_name, device_name, IFNAMSIZ);
+#else
+	strncpy(ifreq.ifr_name, device_name, IFNAMSIZ);
+#endif /* __FreeBSD__ */
+	ifreq.ifr_ifru.ifru_data = (caddr_t)&stats;
+#ifndef __FreeBSD__
+	if ((ioctl(ip_socket,SIOCDEVPRIVATE,(caddr_t)&ifreq) < 0))
+#else
+		if ((ioctl(ip_socket,SIOCGPPPSTATS,(caddr_t)&ifreq) < 0))
+#endif /* __FreeBSD__ */
+			{
+				/* failure means ppp is not up */
+				*in = *out = 0;
+				return FALSE;
+			}
+		else
+			{
+				*in = stats.p.ppp_ibytes;
+				*out = stats.p.ppp_obytes;
+				return TRUE;
+			}
+}
+
+static int get_ISDN_stats(int *in, int *out)
+{
+#ifdef __linux__
+	int fd, i;
+	unsigned long *ptr;
+
+	*in = *out = 0;
+
+	if (!isdn_stats)
+		isdn_stats = g_new0 (unsigned long, ISDN_MAX_CHANNELS  *  2);
+
+	fd = open("/dev/isdninfo", O_RDONLY);
+
+	if (fd < 0)
+		return FALSE;
+
+	if ((ioctl (fd, IIOCGETCPS, isdn_stats) < 0) && (errno != 0)) {
+		close (fd);
+		
+		return FALSE;
+	}
+
+	for (i = 0, ptr = isdn_stats; i < ISDN_MAX_CHANNELS; i++) {
+		*in  += *ptr++; *out += *ptr++;
+	}
+
+	close (fd);
+
+	return TRUE;
+
+#else
+	*in = *out = 0;
+
+	return FALSE;
+#endif
+}
+
+static int get_stats(int *in, int *out)
+{
+	if (use_ISDN)
+		return get_ISDN_stats(in, out);
+	else
+		return get_modem_stats(in, out);
+}
+
 static void command_connect_cb( gint button, gpointer data)
 {
 	confirm_dialog = FALSE;
@@ -97,7 +305,7 @@ static void command_disconnect_cb( gint button, gpointer data)
 
 static void dial_cb()
 {
-	if (Modem_on()) {
+	if (is_connected()) {
 	  if (ask_for_confirmation) {
 	    if (confirm_dialog) return;
 	    confirm_dialog = TRUE;
@@ -263,38 +471,17 @@ static gint update_display()
 	int rx, tx;
 	int light_rx = FALSE;
 	int light_tx = FALSE;
-	struct 	ifreq ifreq;
-	struct 	ppp_stats stats;
 
 	load_count++;
 
-	if (Modem_on())
-		{
-		memset(&ifreq, 0, sizeof(ifreq));
-#ifndef __FreeBSD__
-		strcpy(ifreq.ifr_ifrn.ifrn_name, "ppp0");
-#else
-		strcpy(ifreq.ifr_name, "ppp0");
-#endif /* __FreeBSD__ */
-		ifreq.ifr_ifru.ifru_data = (caddr_t)&stats;
-#ifndef __FreeBSD__
-		if ((ioctl(ip_socket,SIOCDEVPRIVATE,(caddr_t)&ifreq) < 0))
-#else
-		if ((ioctl(ip_socket,SIOCGPPPSTATS,(caddr_t)&ifreq) < 0))
-#endif /* __FreeBSD__ */
-			{
-			/* failure means ppp is not up */
-			old_tx = old_rx = 0;
-			rx = tx = 0;
-			}
-		else
-			{
-			rx = stats.p.ppp_ibytes;
-			tx = stats.p.ppp_obytes;
+	if (is_connected()) {
+		if (!get_stats (&rx, &tx)) {
+			old_rx = old_tx = 0;
+		} else {
 			if (rx > old_rx) light_rx = TRUE;
 			if (tx > old_tx) light_tx = TRUE;
-			}
-
+		}
+		
 		update_lights(light_rx,light_tx,TRUE);
 		if (load_count > UPDATE_DELAY * 2)
 			{
@@ -458,9 +645,10 @@ int main (int argc, char *argv[])
 	applet_widget_init_defaults("modemlights_applet", NULL, argc, argv, 0,
 				    NULL,argv[0]);
 
-	lock_file = strdup("/var/lock/LCK..modem");
-	command_connect = strdup("pppon");
-	command_disconnect = strdup("pppoff");
+	lock_file = g_strdup("/var/lock/LCK..modem");
+	device_name = g_strdup("ppp0");
+	command_connect = g_strdup("pppon");
+	command_disconnect = g_strdup("pppoff");
 	orient = ORIENT_UP;
 
 	/* open ip socket */
