@@ -2,7 +2,6 @@
 #define __SCREENSAVER_H__
 
 #include <stddef.h>
-#include "ghash.h"
 #include <gtk/gtk.h>
 
 enum {
@@ -47,23 +46,22 @@ struct ScreenSaver {
 	ScreenSaver (gchar *n, gchar *c) {
 		name = g_strdup (n);
 		comment = g_strdup (c);
-		modes = g_hash_table_new (g_hash_function_gcharp,
-					  g_hash_compare_gcharp);
+		modes = g_hash_table_new (g_str_hash,
+					  g_str_equal);
 		modesL = NULL;
 	}
 
 	virtual ~ScreenSaver () {
-		g_free (name);
-		g_free (comment);
-		g_hash_table_destroy (modes);
-		g_list_free (modesL);
+		g_free (name); name = NULL;
+		g_free (comment); comment = NULL;
+		g_hash_table_destroy (modes); modes = NULL;
+		g_list_free (modesL); modesL = NULL;
 	}
 
 	void addMode (ScreenSaverMode *m) {
 		g_hash_table_insert (modes, m->name, m);
 		modesL = g_list_append (modesL, (gpointer) m);
 	}
-
 };
 
 #endif
