@@ -5,10 +5,11 @@
 #include <config.h>
 
 #include "gmenu.h"
-#include "wait-feet.h"
 #include "top.xpm"
 
+static void update_pbar(GtkWidget *pbar);
 static gint find_file_cb(gconstpointer a, gconstpointer b);
+static void recalc_paths_cb (GtkCTree *ctree, GtkCTreeNode *node, gpointer data);
 static void move_item_down(GtkCTreeNode *node);
 static void move_item_up(GtkCTreeNode *node);
 static void add_tree_recurse_cb(GtkCTree *ctree, GtkCTreeNode *node, gpointer data);
@@ -16,36 +17,15 @@ static void get_ctree_count_cb(GtkCTree *ctree, GtkCTreeNode *node, gpointer dat
 static gint get_ctree_count(GtkCTree *ctree);
 
 /* new = TRUE, increment feet = FALSE */
-static GtkWidget *wait_pixmap(gint mode)
+static void update_pbar(GtkWidget *pbar)
 {
-	static GtkWidget *p;
-
-	static gint c;
-
-	if (mode)
-		{
-		c = 0;
-		p = gnome_pixmap_new_from_xpm_d(wait_1_xpm);
-		return p;
-		}
-	else
-		{
-		c++;
-		if (c > 7) c = 0;
-
-		if (c == 0) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_1_xpm);
-		if (c == 1) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_2_xpm);
-		if (c == 2) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_3_xpm);
-		if (c == 3) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_4_xpm);
-		if (c == 4) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_5_xpm);
-		if (c == 5) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_6_xpm);
-		if (c == 6) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_7_xpm);
-		if (c == 7) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_8_xpm);
-
-		gtk_widget_draw(p, NULL);
-
-		return NULL;
-		}
+	gfloat val;
+	if (!pbar) return;
+	val = gtk_progress_get_value(GTK_PROGRESS(pbar));
+	val += 1;
+	if (val > 100) val = 0;
+	gtk_progress_set_value(GTK_PROGRESS(pbar), val);
+	gtk_widget_draw(pbar, NULL);
 }
 
 static gint find_file_cb(gconstpointer a, gconstpointer b)
@@ -67,13 +47,13 @@ void update_tree_highlight(GtkWidget *w, GtkCTreeNode *old, GtkCTreeNode *new, g
 	if (old) gtk_ctree_unselect(GTK_CTREE(w),old);
         if (new && select) gtk_ctree_select(GTK_CTREE(w),new);
 
-	d = gtk_ctree_get_row_data(GTK_CTREE(w), new);
+	d = gtk_ctree_node_get_row_data(GTK_CTREE(w), new);
 	gtk_label_set(GTK_LABEL(infolabel),d->comment);
 	if (d->editable)
-		gnome_stock_pixmap_widget_set_icon(GNOME_STOCK_PIXMAP_WIDGET(infopixmap),
+		gnome_stock_set_icon(GNOME_STOCK(infopixmap),
 							GNOME_STOCK_MENU_BLANK );
 	else
-		gnome_stock_pixmap_widget_set_icon(GNOME_STOCK_PIXMAP_WIDGET(infopixmap),
+		gnome_stock_set_icon(GNOME_STOCK(infopixmap),
 							GNOME_STOCK_MENU_BOOK_RED );
 	if (current_path) g_free (current_path);
 	if (d->isfolder)
@@ -88,6 +68,130 @@ void update_tree_highlight(GtkWidget *w, GtkCTreeNode *old, GtkCTreeNode *new, g
 
 }
 
+static void recalc_paths_cb (GtkCTree *ctree, GtkCTreeNode *node, gpointer data)
+{
+	GtkCTreeNode *parent;
+	Desktop_Data *n;
+	Desktop_Data *p;
+	gchar *path;
+
+	parent = GTK_CTREE_ROW(node)->parent;
+	n = gtk_ctree_node_get_row_data(ctree, node);
+	p = gtk_ctree_node_get_row_data(ctree, parent);
+
+	path = g_strconcat(p->path, "/", n->path + g_filename_index(n->path), NULL);
+	g_free(n->path);
+	n->path = path;
+
+	/* now update current state */
+	if (node == current_node)
+		{
+		g_free(current_path);
+		current_path = g_strdup(p->path);
+		gtk_label_set(GTK_LABEL(pathlabel),current_path);
+		}
+}
+
+void tree_moved(GtkCTree *ctree, GtkCTreeNode *node, GtkCTreeNode *new_parent,
+			GtkCTreeNode *new_sibling, gpointer data)
+{
+	static GtkCTreeNode *old_parent;
+
+	if (data)
+		{
+		/* this happens before the move, we need this to get the original parent,
+		because we can't save or move anything until the node moves */
+		old_parent = GTK_CTREE_ROW(node)->parent;
+		}
+	else
+		{
+		/* this happens after the move */
+		Desktop_Data *node_data;
+		gchar *old_filename;
+		gchar *new_filename;
+		GtkCTreeNode *parent;
+
+		node_data = gtk_ctree_node_get_row_data(ctree, node);
+		old_filename = node_data->path;
+
+		parent = GTK_CTREE_ROW(node)->parent;
+
+		if (parent == old_parent)
+			{
+			/* nothing to physically move, only update order file */
+			save_order_of_dir(parent);
+			}
+		else
+			{
+			Desktop_Data *d = gtk_ctree_node_get_row_data(ctree, parent);
+			new_filename = g_strconcat(d->path, "/",
+					old_filename + g_filename_index(old_filename), NULL);
+
+			if (rename (old_filename, new_filename) < 0)
+				g_print("Failed to move file: %s\n", old_filename);
+
+			g_free(old_filename);
+			node_data->path = new_filename;
+
+			save_order_of_dir(old_parent);
+			save_order_of_dir(parent);
+
+			/* it would probably be easier to reread the menus, but I'm doing
+			it this way :)    --John */
+			if (node_data->isfolder)
+				{
+				gtk_ctree_pre_recursive(ctree, node, recalc_paths_cb, NULL);
+				}
+			}
+		}
+}
+
+gboolean tree_move_test_cb(GtkCTree *ctree, GtkCTreeNode *source_node,
+			GtkCTreeNode *new_parent, GtkCTreeNode *new_sibling)
+{
+	Desktop_Data *d;
+
+	if (source_node == topnode || source_node == usernode || source_node == systemnode ||
+			new_parent == NULL)
+		return FALSE;
+
+	if (gtk_ctree_is_ancestor(ctree, usernode, source_node))
+		{
+		if (new_parent != usernode && !gtk_ctree_is_ancestor(ctree, usernode, new_parent))
+			return FALSE;
+		}
+
+	if (gtk_ctree_is_ancestor(ctree, systemnode, source_node))
+		{
+		if (new_parent != systemnode && !gtk_ctree_is_ancestor(ctree, systemnode, new_parent))
+			return FALSE;
+		}
+
+	d = gtk_ctree_node_get_row_data(ctree, new_parent);
+	if (!d || !d->editable)
+		return FALSE;
+
+	d = gtk_ctree_node_get_row_data(ctree, source_node);
+	if (!d || !d->editable)
+		return FALSE;
+
+	/* and a final check to make sure a DIFFERENT file of the same name does not exist */
+	if (new_parent != GTK_CTREE_ROW(source_node)->parent)
+		{
+		gint index = g_filename_index(d->path);
+		GtkCTreeNode *node = GTK_CTREE_ROW(new_parent)->children;
+		while (node)
+			{
+			Desktop_Data *n = gtk_ctree_node_get_row_data(ctree, node);
+			if (!strcmp(d->path + index, n->path + g_filename_index(n->path)))
+				return FALSE;
+			node = GTK_CTREE_ROW(node)->sibling;
+			}
+		}
+
+	return TRUE;
+}
+
 static void move_item_down(GtkCTreeNode *node)
 {
 	GtkCTreeNode *parent = GTK_CTREE_ROW(node)->parent;
@@ -106,7 +210,7 @@ static void move_item_down(GtkCTreeNode *node)
 		next = node;
 	row = g_list_position((GList *)topnode, (GList *)next);
 	if (!gtk_clist_row_is_visible(GTK_CLIST(menu_tree_ctree),row ))
-		gtk_ctree_moveto (GTK_CTREE(menu_tree_ctree), next, 0, 1.0, 0.0);
+		gtk_ctree_node_moveto (GTK_CTREE(menu_tree_ctree), next, 0, 1.0, 0.0);
 }
 
 static void move_item_up(GtkCTreeNode *node)
@@ -129,7 +233,7 @@ static void move_item_up(GtkCTreeNode *node)
 		next = node;
 	row = g_list_position((GList *)topnode, (GList *)next);
 	if (!gtk_clist_row_is_visible(GTK_CLIST(menu_tree_ctree),row ))
-		gtk_ctree_moveto (GTK_CTREE(menu_tree_ctree), next, 0, 0.0, 0.0);
+		gtk_ctree_node_moveto (GTK_CTREE(menu_tree_ctree), next, 0, 0.0, 0.0);
 }
 
 void move_down_cb(GtkWidget *w, gpointer data)
@@ -159,7 +263,7 @@ int is_node_editable(GtkCTreeNode *node)
 	else
 		parent = node;
 
-	d = gtk_ctree_get_row_data(GTK_CTREE(menu_tree_ctree), parent);
+	d = gtk_ctree_node_get_row_data(GTK_CTREE(menu_tree_ctree), parent);
 	return d->editable;
 }
 
@@ -169,7 +273,7 @@ void edit_pressed_cb()
 
 	if (!current_node || current_node == topnode || current_node == usernode ||
 			current_node == systemnode) return;
-	d = gtk_ctree_get_row_data(GTK_CTREE(menu_tree_ctree),current_node);
+	d = gtk_ctree_node_get_row_data(GTK_CTREE(menu_tree_ctree),current_node);
 	update_edit_area(d);
 }
 
@@ -197,7 +301,7 @@ void tree_item_selected (GtkCTree *ctree, GdkEventButton *event, gpointer data)
 
 	if (event->button == 3 && (node == systemnode || node == usernode)) return;
 
-	d = gtk_ctree_get_row_data(GTK_CTREE(ctree),node);
+	d = gtk_ctree_node_get_row_data(GTK_CTREE(ctree),node);
 
 	update_tree_highlight(menu_tree_ctree, current_node, node, TRUE);
 
@@ -212,7 +316,7 @@ void tree_item_selected (GtkCTree *ctree, GdkEventButton *event, gpointer data)
 		if (!d->expanded)
 			{
 			d->expanded = TRUE;
-			add_tree_node(ctree, node);
+			add_tree_node(ctree, node, NULL);
 			}
 		}
 
@@ -226,9 +330,7 @@ GtkCTreeNode *add_leaf_node(GtkCTree *ctree, GtkCTreeNode *parent, GtkCTreeNode
 	Desktop_Data *parent_data;
 	char *path_buf;
 
-/*	g_print("%s\n",file);*/
-
-	parent_data = gtk_ctree_get_row_data(GTK_CTREE(ctree), parent);
+	parent_data = gtk_ctree_node_get_row_data(GTK_CTREE(ctree), parent);
 
 	path_buf = g_copy_strings (parent_data->path, "/", file, NULL);
 				
@@ -248,20 +350,23 @@ GtkCTreeNode *add_leaf_node(GtkCTree *ctree, GtkCTreeNode *parent, GtkCTreeNode
 		text[0] = d->name;
 		text[1] = NULL;
 		if (d->isfolder)
-			node = gtk_ctree_insert (GTK_CTREE(ctree), parent, node, text, 5,
+			node = gtk_ctree_insert_node (GTK_CTREE(ctree), parent, node, text, 5,
 				GNOME_PIXMAP(d->pixmap)->pixmap,
-				GNOME_PIXMAP(d->pixmap)->mask, NULL, NULL, FALSE, FALSE);
+				GNOME_PIXMAP(d->pixmap)->mask,
+				GNOME_PIXMAP(d->pixmap)->pixmap,
+				GNOME_PIXMAP(d->pixmap)->mask,
+				FALSE, FALSE);
 		else
-			node = gtk_ctree_insert (GTK_CTREE(ctree), parent, node, text, 5,
+			node = gtk_ctree_insert_node (GTK_CTREE(ctree), parent, node, text, 5,
 				GNOME_PIXMAP(d->pixmap)->pixmap,
 				GNOME_PIXMAP(d->pixmap)->mask, NULL, NULL, TRUE, FALSE);
-		gtk_ctree_set_row_data (GTK_CTREE(ctree), node, d);
+		gtk_ctree_node_set_row_data (GTK_CTREE(ctree), node, d);
 		}
 	g_free(path_buf);
 	return node;
 }
 
-void add_tree_node(GtkCTree *ctree, GtkCTreeNode *parent)
+void add_tree_node(GtkCTree *ctree, GtkCTreeNode *parent, GtkWidget *pbar)
 {
 	DIR *dp; 
 	struct dirent *dir;
@@ -270,11 +375,9 @@ void add_tree_node(GtkCTree *ctree, GtkCTreeNode *parent)
 	GList *orderlist = NULL;
 	Desktop_Data *parent_data;
 
-	parent_data = gtk_ctree_get_row_data(GTK_CTREE(ctree), parent);
+	parent_data = gtk_ctree_node_get_row_data(GTK_CTREE(ctree), parent);
 	parent_data->expanded = TRUE;
 
-/*	g_print("reading node: %s\n", parent_data->path);*/
-
 	orderlist = get_order_of_dir(parent_data->path);
 	if (orderlist)
 		{
@@ -319,6 +422,7 @@ void add_tree_node(GtkCTree *ctree, GtkCTreeNode *parent)
 					node = add_leaf_node(ctree, parent, NULL, dir->d_name);
 					}
 				}
+			if (pbar) update_pbar(pbar);
 			}
 		} 
 
@@ -340,11 +444,11 @@ void add_tree_node(GtkCTree *ctree, GtkCTreeNode *parent)
 
 static void add_tree_recurse_cb(GtkCTree *ctree, GtkCTreeNode *node, gpointer data)
 {
-	Desktop_Data *d = gtk_ctree_get_row_data(GTK_CTREE(ctree), node);
+	GtkWidget *pbar = data;
+	Desktop_Data *d = gtk_ctree_node_get_row_data(GTK_CTREE(ctree), node);
 	if (d->isfolder && !d->expanded )
 		{
-		wait_pixmap(FALSE);
-		add_tree_node(ctree, node);
+		add_tree_node(ctree, node, pbar);
 		}
 }
 
@@ -366,33 +470,27 @@ void add_main_tree_node()
 	gchar *text[2];
 	Desktop_Data *d;
 	GtkWidget *pixmap;
-	GtkWidget *wait_icon;
+	GtkWidget *progressbar;
 	GtkWidget *dialog;
 	GtkWidget *label;
-	GtkWidget *hbox;
 	gint c;
 
 
 	dialog = gnome_dialog_new(_("GNOME menu editor"),NULL);
 
-	hbox = gtk_hbox_new(FALSE, 5);
-	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), hbox, TRUE, TRUE, 5);
-	gtk_widget_show(hbox);
-
-	wait_icon = wait_pixmap(TRUE);
-	gtk_box_pack_start(GTK_BOX(hbox), wait_icon, TRUE, TRUE, 5);
-	gtk_widget_show(wait_icon);
-
 	label = gtk_label_new(_("One moment, reading menus..."));
-	gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 5);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label, FALSE, FALSE, 5);
 	gtk_widget_show(label);
 
+	progressbar = gtk_progress_bar_new();
+	gtk_progress_set_activity_mode(GTK_PROGRESS(progressbar), TRUE);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), progressbar, FALSE, FALSE, 5);
+	gtk_widget_show(progressbar);
+
 	gtk_widget_show(dialog);
 
 	while(gtk_events_pending()) gtk_main_iteration();
 
-/*	g_print("adding top node...\n");*/
-
 	gtk_clist_freeze(GTK_CLIST(menu_tree_ctree));
 
 	/* very top of tree */
@@ -401,8 +499,8 @@ void add_main_tree_node()
 	text[1] = NULL;
 	
 	pixmap = gnome_pixmap_new_from_xpm_d(top_xpm);
-	topnode = gtk_ctree_insert (GTK_CTREE(menu_tree_ctree), NULL, NULL, text, 5,
-		NULL, NULL,
+	topnode = gtk_ctree_insert_node (GTK_CTREE(menu_tree_ctree), NULL, NULL, text, 5,
+		GNOME_PIXMAP(pixmap)->pixmap, GNOME_PIXMAP(pixmap)->mask,
 		GNOME_PIXMAP(pixmap)->pixmap, GNOME_PIXMAP(pixmap)->mask,
 		FALSE, TRUE);
 
@@ -413,13 +511,13 @@ void add_main_tree_node()
 	d->isfolder = TRUE;
 	d->editable = FALSE;
 
-	gtk_ctree_set_row_data (GTK_CTREE(menu_tree_ctree), topnode, d);
+	gtk_ctree_node_set_row_data (GTK_CTREE(menu_tree_ctree), topnode, d);
 
 	/* system's menu tree */
 	text[0] = _("System Menus");
 	pixmap = gnome_pixmap_new_from_xpm_d(top_xpm);
-	systemnode = gtk_ctree_insert (GTK_CTREE(menu_tree_ctree), topnode, NULL, text, 5,
-		NULL, NULL,
+	systemnode = gtk_ctree_insert_node (GTK_CTREE(menu_tree_ctree), topnode, NULL, text, 5,
+		GNOME_PIXMAP(pixmap)->pixmap, GNOME_PIXMAP(pixmap)->mask,
 		GNOME_PIXMAP(pixmap)->pixmap, GNOME_PIXMAP(pixmap)->mask,
 		FALSE, TRUE);
 
@@ -439,13 +537,13 @@ void add_main_tree_node()
 	else
 		d->editable = FALSE;
 
-	gtk_ctree_set_row_data (GTK_CTREE(menu_tree_ctree), systemnode, d);
+	gtk_ctree_node_set_row_data (GTK_CTREE(menu_tree_ctree), systemnode, d);
 
 	/* user's menu tree */
 	text[0] = _("User Menus");
 	pixmap = gnome_pixmap_new_from_xpm_d(top_xpm);
-	usernode = gtk_ctree_insert (GTK_CTREE(menu_tree_ctree), topnode, systemnode, text, 5,
-		NULL, NULL,
+	usernode = gtk_ctree_insert_node (GTK_CTREE(menu_tree_ctree), topnode, systemnode, text, 5,
+		GNOME_PIXMAP(pixmap)->pixmap, GNOME_PIXMAP(pixmap)->mask,
 		GNOME_PIXMAP(pixmap)->pixmap, GNOME_PIXMAP(pixmap)->mask,
 		FALSE, TRUE);
 
@@ -456,7 +554,7 @@ void add_main_tree_node()
 	d->expanded = FALSE;
 	d->editable = TRUE;
 
-	gtk_ctree_set_row_data (GTK_CTREE(menu_tree_ctree), usernode, d);
+	gtk_ctree_node_set_row_data (GTK_CTREE(menu_tree_ctree), usernode, d);
 
 	/* now load the entire menu tree */
 	c = 0;
@@ -464,7 +562,8 @@ void add_main_tree_node()
 		{
 		c = get_ctree_count(GTK_CTREE(menu_tree_ctree));
 
-		gtk_ctree_post_recursive(GTK_CTREE(menu_tree_ctree), topnode, add_tree_recurse_cb, NULL);
+		gtk_ctree_post_recursive(GTK_CTREE(menu_tree_ctree), topnode,
+			add_tree_recurse_cb, progressbar);
 		}
 
 	current_node = usernode;
