@@ -1,5 +1,21 @@
 /* manager.h - Definitions for session manager.
-   Written by Tom Tromey <tromey@cygnus.com>.  */
+
+   Copyright (C) 1998 Tom Tromey
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+   02111-1307, USA.  */
 
 #ifndef MANAGER_H
 #define MANAGER_H
@@ -119,11 +135,4 @@ gboolean find_vector_property (const Client *client, const char *name,
 /* Free the return result from find_vector_property.  */
 void free_vector (int argc, char **argv);
 
-/*
- * exec.c
- */
-
-/* Execute some command in the background and immediately return.  */
-void execute_async (int argc, char *argv[]);
-
 #endif /* MANAGER_H */
