@@ -25,6 +25,7 @@
 #include "libgnome/libgnome.h"
 #include "libgnomeui/gnome-client.h"
 #include "manager.h"
+#include "session.h"
 
 
 
@@ -34,6 +35,10 @@
 /* Name of current session.  A NULL value means the default.  */
 static char *session_name = NULL;
 
+/* This is true if we've ever started a session.  We use this to see
+   if we need to run the preloads again.  */
+static int session_loaded = 0;
+
 /* This is used to hold a table of all properties we care to save.  */
 typedef struct
 {
@@ -47,7 +52,8 @@ static propsave properties[] =
 {
   { SmCurrentDirectory, 0, 0 },
   { SmDiscardCommand, 1, 0 },
-  { SmRestartCommand, 1, 1 }
+  { SmRestartCommand, 1, 1 },
+  { SmEnvironment, 1, 0 }
 };
 
 #define NUM_PROPERTIES (sizeof (properties) / sizeof (propsave))
@@ -60,7 +66,7 @@ static int
 write_one_client (int number, const Client *client)
 {
   /* We over-allocate; it doesn't matter.  */
-  int i, j, vec_count, string_count, argcs[NUM_PROPERTIES], failure;
+  int i, vec_count, string_count, argcs[NUM_PROPERTIES], failure;
   char **argvs[NUM_PROPERTIES];
   char *strings[NUM_PROPERTIES];
   const char *argv_names[NUM_PROPERTIES];
@@ -189,25 +195,45 @@ run_commands (const char *name, int number, const char *command)
 {
   int i, result = 0;
 
-  /* Run each delete command.  */
+  /* Run each command.  */
   for (i = 0; i < number; ++i)
     {
-      int argc, j;
-      gboolean def;
-      char **argv, *dir, prefix[1024];
+      int argc, envc;
+      gboolean def, envd;
+      char **argv, *dir, prefix[1024], **envv, **envp;
 
       sprintf (prefix, "session/%s/%d,%s=", name, i, SmCurrentDirectory);
       dir = gnome_config_get_string (prefix);
       sprintf (prefix, "session/%s/%d,%s=", name, i, command);
       gnome_config_get_vector_with_default (prefix, &argc, &argv, &def);
 
+      sprintf (prefix, "session/%s/%d,%s=", name, i, SmEnvironment);
+      gnome_config_get_vector_with_default (prefix, &envc, &envv, &envd);
+      if (envd)
+	envp = NULL;
+      else
+	{
+	  char **newenv = (char **) malloc ((envc / 2 + 2) * sizeof (char *));
+	  int i;
+
+	  for (i = 0; i < envc / 2; ++i)
+	    newenv[i] = g_copy_strings (envv[2 * i], "=", envv[2 * i + 1],
+					NULL);
+	  newenv[i] = NULL;
+	  free_vector (envc, envv);
+	  envc = i;
+	  envv = newenv;
+	  envp = newenv;
+	}
+
       if (! def)
 	{
-	  gnome_execute_async (dir, argc, argv);
+	  gnome_execute_async_with_env (dir, argc, argv, envc, envp);
 	  result = 1;
 	}
 
       free_vector (argc, argv);
+      free_vector (envc, envv);
       if (dir)
 	free (dir);
     }
@@ -217,34 +243,50 @@ run_commands (const char *name, int number, const char *command)
 
 
 
-/* Run the default session.  The default should probably be in a
-   config file somewhere, instead of hard-coded here.  */
+/* Return number of preloads.  */
+static int
+num_preloads (void)
+{
+  return gnome_config_get_int (PRELOAD_PREFIX PRELOAD_COUNT_KEY "=0");
+}
+
+/* Run all the preloads, if required.  */
+static void
+run_preloads (int count)
+{
+  int i;
+
+  /* Only run once.  */
+  if (session_loaded)
+    return;
+  session_loaded = 1;
+
+  if (count <= 0)
+    return;
+
+  for (i = 0; i < count; ++i)
+    {
+      char *text, buf[20];
+      gboolean def;
+
+      sprintf (buf, "%d", i);
+      text = gnome_config_get_string_with_default (buf, &def);
+      if (! def)
+	gnome_execute_shell (NULL, text);
+      g_free (text);
+    }
+}
+
+/* Run the default session.  */
 static int
 run_default_session (void)
 {
-  char *argv[5];
+  int count;
 
-  argv[0] = "panel";
-  argv[1] = NULL;
-  gnome_execute_async (NULL, 1, argv);
-
-  argv[0] = "gnome-help-browser";
-  gnome_execute_async (NULL, 1, argv);
-
-  argv[0] = "gmc";
-  gnome_execute_async (NULL, 1, argv);
-
-#ifdef WINDOW_MANAGER
-  argv[0] = WINDOW_MANAGER;
-#else
-  /* icewm is the default because it actually implements session
-     management.  */
-  argv[0] = "icewm";
-#endif
-  gnome_execute_async (NULL, 1, argv);
-
-  argv[0] = "smproxy";
-  gnome_execute_async (NULL, 1, argv);
+  gnome_config_push_prefix ("=" DEFAULTDIR "/default.session=/Default/");
+  count = gnome_config_get_int ("num_preloads");
+  run_preloads (count);
+  gnome_config_pop_prefix ();
 
   return 1;
 }
@@ -254,8 +296,7 @@ run_default_session (void)
 int
 read_session (const char *name)
 {
-  int i, num_clients;
-  gboolean def;
+  int i, num_clients, preloads;
   char prefix[1024];
 
   if (! session_name)
@@ -263,17 +304,29 @@ read_session (const char *name)
   if (! name)
     name = DEFAULT_SESSION;
 
-  sprintf (prefix, "session/%s/num_clients=-1", name);
-  num_clients = gnome_config_get_int_with_default (prefix, &def);
+  sprintf (prefix, "session/%s/num_clients=0", name);
+  num_clients = gnome_config_get_int (prefix);
 
-  /* If default, then no client info exists.  */
-  if (def)
+  preloads = num_preloads ();
+
+  /* No clients means either this is the first time gnome-session has
+     been run, or the user exited everything the last time.  Either
+     way, we start the default session to make sure something happens.
+     We treat preloads as clients -- the user might legitimately exit
+     all the session-aware clients, but still have stuff start in his
+     session.  */
+  if (! num_clients && ! preloads)
     {
       if (! strcmp (name, DEFAULT_SESSION))
 	return run_default_session ();
       return 0;
     }
 
+  /* Start all the preloads.  */
+  gnome_config_push_prefix (PRELOAD_PREFIX);
+  run_preloads (preloads);
+  gnome_config_pop_prefix ();
+
   /* We must register each saved client as a `zombie' client.  Then
      when the client restarts it will get its new client id
      correctly.  */
@@ -295,7 +348,7 @@ read_session (const char *name)
 void
 delete_session (const char *name)
 {
-  int i, number;
+  int number;
   gboolean def;
   char prefix[1024];
 
