@@ -18,6 +18,8 @@
 
 #define USE_FILE_URLS
 
+int inTable=0;
+
 char *BaseFilename=NULL;
 char *OverrideBaseFilename=NULL;
 
@@ -161,11 +163,27 @@ void start_html_content( FILE *f )
 /* we want to put links to next, prev, and up nodes */
 void make_nav_links( FILE *f, NODE *node )
 {
+#if 0
   fprintf(f,"<PRE>\n");
   write_node_link_html( f, node->filename, "Next:", node->next );
   write_node_link_html( f, node->filename, "Prev:", node->prev );
   write_node_link_html( f, node->filename, "Up:", node->up );
   fprintf(f,"</PRE>\n");
+#else
+  fprintf(f,"<TABLE border=2 cellspacing=1 cellpadding=4 width=100%%>\n");
+  fprintf(f,"<TR bgcolor=\"#eeeee0\">\n");
+  fprintf(f,"\t<TH align=center width=33%%>\n\t");
+  write_node_link_html( f, node->filename, "Next:", node->next );
+  fprintf(f,"\t</TH>\n");
+  fprintf(f,"\t<TH align=center width=33%%>\n\t");
+  write_node_link_html( f, node->filename, "Prev:", node->prev );
+  fprintf(f,"\t</TH>\n");
+  fprintf(f,"\t<TH align=center width=34%%>\n\t");
+  write_node_link_html( f, node->filename, "Up:", node->up );
+  fprintf(f,"\t</TH>\n");
+  fprintf(f,"</TR>\n</TABLE>\n");
+#endif
+
 }
 
 /* s is error message */
@@ -287,7 +305,7 @@ void dump_html_for_node( NODE *node )
   /* make an anchor */
   escaped_nodename = escape_html_chars( node->nodename );
   map_spaces_to_underscores( escaped_nodename );
-  fprintf(f, "<A name=\"%s\">\n",escaped_nodename);
+  fprintf(f, "<A name=\"%s\"></A>\n",escaped_nodename);
   g_free(escaped_nodename);
 
   /* links to other immediate nodes */
@@ -727,13 +745,27 @@ void open_menu_html( FILE *f, char *p )
   if (*p != '\000')
     fprintf(f, "<H2>%s</H2>\n",p);
   /*  fprintf(f, "<UL>\n"); */
+#if 0
     fprintf(f, "<dl>\n"); 
+#else
+    if (inTable)
+	    fprintf(stderr, "In a table and starting new one!\n");
+    inTable = 1;
+    fprintf(f, "<table width=100%%><tr><td>&nbsp;</td></tr>\n");
+#endif
 }
 
 void close_menu_html( FILE *f )
 {
   /* fprintf(f, "</UL>\n"); */
-  fprintf(f, "</dl>\n"); 
+#if 0
+    fprintf(f, "</dl>\n");
+#else
+    if (!inTable)
+	    fprintf(stderr, "Not in a table and closing one!\n");
+    inTable = 0;
+    fprintf(f, "</table>\n");
+#endif
 }
 
 /* writes menu entry contained in string p */
@@ -805,13 +837,25 @@ void write_menu_entry_html( FILE *f, char *p, char *nodefile, char **menu_end )
   fprintf(f,"<dt><A HREF=\"../%s/%s.html\">%s</A>\n",
 	  reffile, converted_nodename, escaped_refname);
 #endif
+
   href = form_info_tag_href( reffile, converted_nodename );
+#if 0
   fprintf(f,"<dt><A %s>%s</A>\n", href, escaped_refname );
   fprintf(f,"<dd>");
   if (*end == '.' && *(end+1) == '\n')
     fprintf(f,"%s.\n",escaped_refnode);
   else
     fwrite(end+1, 1, *menu_end - end - 1, f);
+#else
+  fprintf(f,"<tr>\n\t<td width=30%%>\n\t\t<A %s>%s</A>\n\t</td>\n"
+	  "\t<td width=70%%>\n\t\t", 
+	  href, escaped_refname );
+  if (*end == '.' && *(end+1) == '\n')
+    fprintf(f,"%s.\n",escaped_refnode);
+  else
+    fwrite(end+1, 1, *menu_end - end - 1, f);
+  fprintf(f,"\n\t</td>\n</tr>\n");
+#endif
 
   if (href)
     g_free(href);
