@@ -163,11 +163,17 @@ GnomeUIInfo helpmenu[] = {
 };
  
 GnomeUIInfo windowmenu[] = {
-    GNOMEUIINFO_ITEM(N_("History"), N_("Show History Window"),
-		     ghelpShowHistory, NULL),
-    GNOMEUIINFO_ITEM(N_("Bookmarks"), N_("Show Bookmarks Window"),
-		     ghelpShowBookmarks, NULL),
-    GNOMEUIINFO_END
+	{GNOME_APP_UI_ITEM, 
+	 N_("History"), N_("Show History Window"),
+         ghelpShowHistory, NULL, NULL, 
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, 
+	 N_("Bookmarks"), N_("Show Bookmarks Window"),
+         ghelpShowBookmarks, NULL, NULL, 
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	 GNOMEUIINFO_END
 };
 
 GnomeUIInfo mainmenu[] = {
@@ -685,7 +691,7 @@ helpWindowNew(gchar *name,
 	w->humanRef = NULL;
 	w->Title    = NULL;
 
-	w->app = gnome_app_new (name, "Gnome Help Browser");
+	w->app = gnome_app_new (name, _("Gnome Help Browser"));
 	gtk_window_set_wmclass (GTK_WINDOW (w->app), "GnomeHelpBrowser",
 				"GnomeHelpBrowser");
 	gtk_widget_realize (w->app);
@@ -805,10 +811,10 @@ helpWindowShowURL(HelpWindow win, gchar *ref,
 	if (visitURL(win, ref, useCache, addToQueue, TRUE)) {
 		GtkWidget *msg;
 
-		snprintf(err, sizeof(err), "Error loading document:\n\n%s",
+		snprintf(err, sizeof(err), _("Error loading document:\n\n%s"),
 			 ref);
 		msg = gnome_message_box_new(err, GNOME_MESSAGE_BOX_ERROR,
-					   "Ok", NULL);
+					   _("Ok"), NULL);
 		gnome_message_box_set_modal (GNOME_MESSAGE_BOX (msg));
 		gtk_widget_show(msg);
 
