@@ -39,74 +39,23 @@ move_applet_callback(GtkWidget *widget, gpointer data)
 
 	g_return_if_fail(info != NULL);
 
-	panel = gtk_object_get_data(GTK_OBJECT(info->widget),
-				    PANEL_APPLET_PARENT_KEY);
+	panel = PANEL_WIDGET(info->widget->parent);
 	g_return_if_fail(panel!=NULL);
 
 	panel_widget_applet_drag_start(panel,info->widget);
 	panel_widget_applet_move_use_idle(panel);
 }
 
+/*destroy widgets and call the above cleanup function*/
 void
 panel_clean_applet(int applet_id)
 {
 	AppletInfo *info = get_applet_info(applet_id);
-	AppletType type;
-
+	
 	g_return_if_fail(info != NULL);
 
-	/*fixes reentrancy problem with this routine*/
-	if(info->type == APPLET_EMPTY)
-		return;
-
-	type = info->type;
-	info->type = APPLET_EMPTY;
-
-	if(info->widget) {
-		PanelWidget *panel;
-		GtkWidget *w = info->widget;
-
-		info->widget = NULL;
-
-		panel = gtk_object_get_data(GTK_OBJECT(w),
-					    PANEL_APPLET_PARENT_KEY);
-
-		if(panel) {
-			gtk_widget_ref(w);
-			gtk_container_remove(GTK_CONTAINER(panel),w);
-			gtk_widget_destroy(w);
-		}
-	}
-	info->applet_widget = NULL;
-	if(type == APPLET_DRAWER) {
-		Drawer *drawer = info->data;
-		g_assert(drawer);
-		if(drawer->drawer) {
-			GtkWidget *dw = drawer->drawer;
-			drawer->drawer = NULL;
-			PANEL_WIDGET(DRAWER_WIDGET(dw)->panel)->master_widget = NULL;
-			gtk_widget_destroy(dw);
-		}
-	}
-	if(info->menu)
-		gtk_widget_unref(info->menu);
-	info->menu=NULL;
-
-	info->data=NULL;
-
-	/*free the user menu*/
-	while(info->user_menu) {
-		AppletUserMenu *umenu = info->user_menu->data;
-		if(umenu->name)
-			g_free(umenu->name);
-		if(umenu->stock_item)
-			g_free(umenu->stock_item);
-		if(umenu->text)
-			g_free(umenu->text);
-		g_free(umenu);
-		info->user_menu = my_g_list_pop_first(info->user_menu);
-	}
-	mulapp_remove_empty_from_list();
+	if(info->widget)
+		gtk_widget_destroy(info->widget);
 }
 
 static void
@@ -367,93 +316,6 @@ create_applet_menu(AppletInfo *info)
 }
 
 void
-applet_menu_position (GtkMenu *menu, int *x, int *y, gpointer data)
-{
-	int wx, wy;
-	AppletInfo *info = get_applet_info(GPOINTER_TO_INT(data));
-	PanelWidget *panel;
-	GtkWidget *w; /*the panel window widget*/
-
-	g_return_if_fail(info != NULL);
-	g_return_if_fail(info->widget != NULL);
-
-	panel = gtk_object_get_data(GTK_OBJECT(info->widget),
-				    PANEL_APPLET_PARENT_KEY);
-
-	g_return_if_fail(panel != NULL);
-	
-	w = gtk_object_get_data(GTK_OBJECT(panel), PANEL_PARENT);
-
-	gdk_window_get_origin (info->widget->window, &wx, &wy);
-
-	if(IS_DRAWER_WIDGET(w)) {
-		if(panel->orient==PANEL_VERTICAL) {
-			*x = wx + info->widget->allocation.width;
-			*y = wy;
-		} else {
-			*x = wx;
-			*y = wy - GTK_WIDGET (menu)->allocation.height;
-		}
-	} else if(IS_SNAPPED_WIDGET(w)) {
-		switch(SNAPPED_WIDGET(w)->pos) {
-		case SNAPPED_BOTTOM:
-			*x = wx;
-			*y = wy - GTK_WIDGET (menu)->allocation.height;
-			break;
-		case SNAPPED_TOP:
-			*x = wx;
-			*y = wy + info->widget->allocation.height;
-			break;
-		case SNAPPED_LEFT:
-			*x = wx + info->widget->allocation.width;
-			*y = wy;
-			break;
-		case SNAPPED_RIGHT:
-			*x = wx - GTK_WIDGET (menu)->allocation.width;
-			*y = wy;
-			break;
-		}
-	} else if(IS_CORNER_WIDGET(w)) {
-		if(panel->orient==PANEL_HORIZONTAL) {
-			switch(CORNER_WIDGET(w)->pos) {
-			case CORNER_SE:
-			case CORNER_SW:
-				*x = wx;
-				*y = wy - GTK_WIDGET (menu)->allocation.height;
-				break;
-			case CORNER_NE:
-			case CORNER_NW:
-				*x = wx;
-				*y = wy + info->widget->allocation.height;
-				break;
-			}
-		} else {
-			switch(CORNER_WIDGET(w)->pos) {
-			case CORNER_NW:
-			case CORNER_SW:
-				*x = wx + info->widget->allocation.width;
-				*y = wy;
-				break;
-			case CORNER_NE:
-			case CORNER_SE:
-				*x = wx - GTK_WIDGET (menu)->allocation.width;
-				*y = wy;
-				break;
-			}
-		}
-	}
-
-	if(*x + GTK_WIDGET (menu)->allocation.width > gdk_screen_width())
-		*x=gdk_screen_width() - GTK_WIDGET (menu)->allocation.width;
-	if(*x < 0) *x =0;
-
-	if(*y + GTK_WIDGET (menu)->allocation.height > gdk_screen_height())
-		*y=gdk_screen_height() - GTK_WIDGET (menu)->allocation.height;
-	if(*y < 0) *y =0;
-}
-
-
-static void
 show_applet_menu(int applet_id, GdkEventButton *event)
 {
 	AppletInfo *info = get_applet_info(applet_id);
@@ -493,12 +355,44 @@ applet_destroy(GtkWidget *w, gpointer data)
 {
 	int applet_id = GPOINTER_TO_INT(data);
 	AppletInfo *info = get_applet_info(applet_id);
-
-	g_return_val_if_fail(info!=NULL,FALSE);
+	AppletType type;
+	
+	g_return_if_fail(info != NULL);
 
 	info->widget = NULL;
 
-	panel_clean_applet(applet_id);
+	if(info->type == APPLET_DRAWER) {
+		Drawer *drawer = info->data;
+		g_assert(drawer);
+		if(drawer->drawer) {
+			GtkWidget *dw = drawer->drawer;
+			drawer->drawer = NULL;
+			PANEL_WIDGET(DRAWER_WIDGET(dw)->panel)->master_widget = NULL;
+			gtk_widget_destroy(dw);
+		}
+	}
+	if(info->menu) {
+		gtk_widget_unref(info->menu);
+		info->menu=NULL;
+	}
+
+	info->type = APPLET_EMPTY;
+
+	info->data=NULL;
+
+	/*free the user menu*/
+	while(info->user_menu) {
+		AppletUserMenu *umenu = info->user_menu->data;
+		if(umenu->name)
+			g_free(umenu->name);
+		if(umenu->stock_item)
+			g_free(umenu->stock_item);
+		if(umenu->text)
+			g_free(umenu->text);
+		g_free(umenu);
+		info->user_menu = my_g_list_pop_first(info->user_menu);
+	}
+	mulapp_remove_empty_from_list();
 
 	return FALSE;
 }
@@ -510,54 +404,47 @@ register_toy(GtkWidget *applet,
 	     int pos,
 	     AppletType type)
 {
-	GtkWidget     *eventbox;
 	AppletInfo    info;
-	int           bind_lower;
 	
 	g_return_val_if_fail(applet != NULL, FALSE);
 	g_return_val_if_fail(panel != NULL, FALSE);
 
-	if(GTK_WIDGET_NO_WINDOW(applet) || GTK_IS_SOCKET(applet)) {
-		/* We wrap the applet in a GtkEventBox so that we can capture
-		   events over it */
-		eventbox = gtk_event_box_new();
-		gtk_widget_set_events(eventbox, (gtk_widget_get_events(eventbox) |
-						 APPLET_EVENT_MASK) &
-				      ~( GDK_POINTER_MOTION_MASK |
-					 GDK_POINTER_MOTION_HINT_MASK));
-		gtk_container_add(GTK_CONTAINER(eventbox), applet);
-	} else {
+	if(!GTK_WIDGET_NO_WINDOW(applet))
 		gtk_widget_set_events(applet, (gtk_widget_get_events(applet) |
 					       APPLET_EVENT_MASK) &
 				      ~( GDK_POINTER_MOTION_MASK |
 					 GDK_POINTER_MOTION_HINT_MASK));
-		eventbox = applet;
-	}
 
 	info.applet_id = applet_count;
 	info.type = type;
-	info.widget = eventbox;
-	info.applet_widget = applet;
+	info.widget = applet;
 	info.menu = NULL;
 	info.data = data;
 	info.user_menu = NULL;
 
-	gtk_object_set_data(GTK_OBJECT(eventbox),"applet_id",
+	/* Since we will be taking care of refcounting by ourselves,
+	 * sink the object.
+	 */
+
+	gtk_widget_ref (info.widget);
+	gtk_object_sink (GTK_OBJECT (info.widget));
+
+	gtk_object_set_data(GTK_OBJECT(applet),"applet_id",
 			    GINT_TO_POINTER(applet_count));
 
 	if(type == APPLET_DRAWER) {
 		Drawer *drawer = data;
 		PanelWidget *assoc_panel = PANEL_WIDGET(DRAWER_WIDGET(drawer->drawer)->panel);
 
-		gtk_object_set_data(GTK_OBJECT(eventbox),
+		gtk_object_set_data(GTK_OBJECT(applet),
 				    PANEL_APPLET_ASSOC_PANEL_KEY,assoc_panel);
-		assoc_panel->master_widget = eventbox;
+		assoc_panel->master_widget = applet;
 	}
-	gtk_object_set_data(GTK_OBJECT(eventbox),
+	gtk_object_set_data(GTK_OBJECT(applet),
 			    PANEL_APPLET_FORBIDDEN_PANELS,NULL);
 		
 	/*add to the array of applets*/
-	applets = g_array_append_val(applets,AppletInfo,info);
+	applets = g_array_append_val(applets,info);
 	applet_count++;
 
 	/*we will need to save this applet's config now*/
@@ -566,21 +453,16 @@ register_toy(GtkWidget *applet,
 			g_list_prepend(applets_to_sync,
 				       GINT_TO_POINTER(applet_count-1));
 
-	/*for a menu we don't bind other events except for the
-	  eventbox, the menu itself takes care of passing the relevant
-	  ones thrugh*/
-	bind_lower = (type == APPLET_MENU?FALSE:TRUE);
-	if(panel_widget_add_full(panel, eventbox, pos, bind_lower)==-1) {
+	if(panel_widget_add_full(panel, applet, pos, TRUE)==-1) {
 		GList *list;
 		for(list = panels; list != NULL; list = g_list_next(list))
-			if(panel_widget_add_full(panel, eventbox, pos, bind_lower)!=-1)
+			if(panel_widget_add_full(panel, applet, pos, TRUE)!=-1)
 				break;
 		if(!list) {
 			/*can't put it anywhere, clean up*/
 			AppletInfo *inf = get_applet_info(applet_count-1);
-			gtk_widget_unref(eventbox);
+			gtk_widget_unref(applet);
 			inf->widget = NULL;
-			inf->applet_widget = NULL;
 			panel_clean_applet(applet_count-1);
 			g_warning("Can't find an empty spot");
 			return FALSE;
@@ -588,24 +470,25 @@ register_toy(GtkWidget *applet,
 		panel = PANEL_WIDGET(list->data);
 	}
 
-	gtk_signal_connect(GTK_OBJECT(eventbox),
-			   "button_press_event",
-			   GTK_SIGNAL_FUNC(applet_button_press),
-			   GINT_TO_POINTER(applet_count-1));
+	if(!GTK_WIDGET_NO_WINDOW(applet))
+		gtk_signal_connect(GTK_OBJECT(applet),
+				   "button_press_event",
+				   GTK_SIGNAL_FUNC(applet_button_press),
+				   GINT_TO_POINTER(applet_count-1));
 
-	gtk_signal_connect(GTK_OBJECT(eventbox),
+	gtk_signal_connect(GTK_OBJECT(applet),
 			   "destroy",
 			   GTK_SIGNAL_FUNC(applet_destroy),
 			   GINT_TO_POINTER(applet_count-1));
 
-	gtk_widget_show_all(eventbox);
+	gtk_widget_show_all(applet);
 
-	/*gtk_signal_connect (GTK_OBJECT (eventbox), 
+	/*gtk_signal_connect (GTK_OBJECT (applet), 
 			    "drag_request_event",
 			    GTK_SIGNAL_FUNC(panel_dnd_drag_request),
 			    info);
 
-	gtk_widget_dnd_drag_set (GTK_WIDGET(eventbox), TRUE,
+	gtk_widget_dnd_drag_set (GTK_WIDGET(applet), TRUE,
 				 applet_drag_types, 1);*/
 
 	orientation_change(applet_count-1,panel);
