@@ -150,12 +150,16 @@ drawer_widget_get_pos(DrawerWidget *drawer, gint16 *x, gint16 *y,
 		int px, py, pw, ph;
 		GtkWidget *ppanel; /*parent panel*/
 
-		/*get's the panel data from the the applet*/
-		ppanel = gtk_object_get_data(GTK_OBJECT(panel->master_widget),
-					     PANEL_APPLET_PARENT_KEY);
+		/*get the parent of the applet*/
+		ppanel = PANEL_WIDGET(panel->master_widget->parent);
 		if (GTK_WIDGET_REALIZED (ppanel)) {
 			gdk_window_get_origin (panel->master_widget->window, &bx, &by);
-			gdk_window_get_size (panel->master_widget->window, &bw, &bh);
+			if(GTK_WIDGET_NO_WINDOW(panel->master_widget)) {
+				bx+=panel->master_widget->allocation.x;
+				by+=panel->master_widget->allocation.y;
+			}
+			bw = panel->master_widget->allocation.width;
+			bh = panel->master_widget->allocation.height;
 			gdk_window_get_origin (ppanel->window, &px, &py);
 			gdk_window_get_size (ppanel->window, &pw, &ph);
 
@@ -177,8 +181,11 @@ drawer_widget_get_pos(DrawerWidget *drawer, gint16 *x, gint16 *y,
 				*y = by+(bh-height)/2;
 				break;
 			}
+			return;
 		}
 	}
+	/*if we fail*/
+	*x = *y = -3000;
 }
 
 static void
@@ -202,6 +209,10 @@ drawer_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 			      &allocation->y,
 			      allocation->width,
 			      allocation->height);
+	
+	/*ugly optimisation*/
+	if(memcmp(allocation,&widget->allocation,sizeof(GtkAllocation))==0)
+		return;
 
 	widget->allocation = *allocation;
 	if (GTK_WIDGET_REALIZED (widget))
@@ -391,25 +402,23 @@ drawer_widget_open_drawer(DrawerWidget *drawer)
 	ignore_allocate = TRUE;
 	gtk_widget_show_now(GTK_WIDGET(drawer));
 	ignore_allocate = FALSE;
-	if(!pw_disable_animations) {
-		switch(drawer->orient) {
-		case ORIENT_UP:
-			move_vert_d(drawer,x,y,width,height, y+height, y,
-				    pw_drawer_step,FALSE);
-			break;
-		case ORIENT_DOWN:
-			move_vert_d(drawer,x,y,width,height, y-height, y,
-				    pw_drawer_step,FALSE);
-			break;
-		case ORIENT_LEFT:
-			move_horiz_d(drawer,x,y,width,height, x+width, x,
-				     pw_drawer_step,FALSE);
-			break;
-		case ORIENT_RIGHT:
-			move_horiz_d(drawer,x,y,width,height, x-width, x,
-				     pw_drawer_step,FALSE);
-			break;
-		}
+	switch(drawer->orient) {
+	case ORIENT_UP:
+		move_vert_d(drawer,x,y,width,height, y+height, y,
+			    pw_drawer_step,FALSE);
+		break;
+	case ORIENT_DOWN:
+		move_vert_d(drawer,x,y,width,height, y-height, y,
+			    pw_drawer_step,FALSE);
+		break;
+	case ORIENT_LEFT:
+		move_horiz_d(drawer,x,y,width,height, x+width, x,
+			     pw_drawer_step,FALSE);
+		break;
+	case ORIENT_RIGHT:
+		move_horiz_d(drawer,x,y,width,height, x-width, x,
+			     pw_drawer_step,FALSE);
+		break;
 	}
 
 	drawer->state = DRAWER_SHOWN;
@@ -569,6 +578,8 @@ drawer_widget_new (PanelOrientType orient,
 	case ORIENT_DOWN: porient = PANEL_VERTICAL; break;
 	case ORIENT_LEFT: porient = PANEL_HORIZONTAL; break;
 	case ORIENT_RIGHT: porient = PANEL_HORIZONTAL; break;
+	default:
+		porient = PANEL_HORIZONTAL;
 	}
 
 	drawer->panel = panel_widget_new(TRUE,
@@ -621,6 +632,7 @@ drawer_widget_change_params(DrawerWidget *drawer,
 	case ORIENT_DOWN: porient = PANEL_VERTICAL; break;
 	case ORIENT_LEFT: porient = PANEL_HORIZONTAL; break;
 	case ORIENT_RIGHT: porient = PANEL_HORIZONTAL; break;
+	default: porient = PANEL_HORIZONTAL;
 	}
 
 	oldstate = drawer->state;
