@@ -29,9 +29,6 @@ extern GlobalConfig global_config;
 extern char *panel_cfg_path;
 extern char *old_panel_cfg_path;
 
-/*list of child applet processes*/
-extern GList *children;
-
 void
 extern_clean(Extern *ext)
 {
@@ -83,8 +80,7 @@ applet_get_panel_orient(int applet_id)
 
 	g_return_val_if_fail(info != NULL,ORIENT_UP);
 
-	panel = gtk_object_get_data(GTK_OBJECT(info->widget),
-				    PANEL_APPLET_PARENT_KEY);
+	panel = PANEL_WIDGET(info->widget->parent);
 
 	g_return_val_if_fail(panel != NULL,ORIENT_UP);
 
@@ -102,8 +98,7 @@ applet_get_panel(int applet_id)
 
 	g_return_val_if_fail(info != NULL,-1);
 
-	p = gtk_object_get_data(GTK_OBJECT(info->widget),
-				PANEL_APPLET_PARENT_KEY);
+	p = PANEL_WIDGET(info->widget->parent);
 
 	for(panel=0,list=panels;list!=NULL;list=g_list_next(list),panel++)
 		if(list->data == p)
@@ -151,8 +146,8 @@ applet_drag_start(int applet_id)
 
 	g_return_if_fail(info != NULL);
 
-	panel = gtk_object_get_data(GTK_OBJECT(info->widget),
-				    PANEL_APPLET_PARENT_KEY);
+	panel = PANEL_WIDGET(info->widget->parent);
+
 	g_return_if_fail(panel!=NULL);
 
 	panel_widget_applet_drag_start(panel,info->widget);
@@ -169,8 +164,8 @@ applet_drag_stop(int applet_id)
 
 	g_return_if_fail(info != NULL);
 
-	panel = gtk_object_get_data(GTK_OBJECT(info->widget),
-				    PANEL_APPLET_PARENT_KEY);
+	panel = PANEL_WIDGET(info->widget->parent);
+
 	g_return_if_fail(panel!=NULL);
 
 	panel_widget_applet_drag_end(panel);
@@ -199,10 +194,9 @@ applet_request_id (const char *path, const char *param,
 		   char **globcfgpath, guint32 * winid)
 {
 	AppletInfo *info;
-	AppletChild *child;
 	int i;
 	Extern *ext;
-
+	
 	for(info=(AppletInfo *)applets->data,i=0;i<applet_count;i++,info++) {
 		if(info && info->type == APPLET_EXTERN_PENDING) {
 			Extern *ext = info->data;
@@ -211,11 +205,15 @@ applet_request_id (const char *path, const char *param,
 			   compare_params(param,ext->params)) {
 				/*we started this and already reserved a spot
 				  for it, including the socket widget*/
+				GtkWidget *socket =
+					GTK_BIN(info->widget)->child;
+				g_return_val_if_fail(GTK_IS_SOCKET(socket),-1);
+
 				*cfgpath = ext->cfg;
 				ext->cfg = NULL;
 				*globcfgpath = g_strdup(old_panel_cfg_path);
 				info->type = APPLET_EXTERN_RESERVED;
-				*winid=GDK_WINDOW_XWINDOW(info->applet_widget->window);
+				*winid=GDK_WINDOW_XWINDOW(socket->window);
 				if(!dorestart && !mulapp_is_in_list(path))
 					mulapp_add_to_list(path);
 
@@ -224,6 +222,8 @@ applet_request_id (const char *path, const char *param,
 		}
 	}
 	
+	/*this is an applet that was started from outside, otherwise we would
+	  have already reserved a spot for it*/
 	ext = g_new(Extern,1);
 	ext->ior = NULL;
 	ext->path = g_strdup(path);
@@ -244,13 +244,6 @@ applet_request_id (const char *path, const char *param,
 	if(!dorestart && !mulapp_is_in_list(path))
 		mulapp_add_to_list(path);
 
-	/*add to list of children, we haven't started this one so make
-	  pid -1*/
-	child = g_new(AppletChild,1);
-	child->pid = -1;
-	child->applet_id = i;
-	children = g_list_prepend(children,child);
-
 	return i;
 }
 
@@ -269,8 +262,7 @@ applet_register (const char * ior, int applet_id)
 	ext = info->data;
 	g_assert(ext);
 
- 	panel = gtk_object_get_data(GTK_OBJECT(info->widget),
-				    PANEL_APPLET_PARENT_KEY);
+	panel = PANEL_WIDGET(info->widget->parent);
 	g_return_if_fail(panel!=NULL);
 
 	/*no longer pending*/
@@ -280,18 +272,19 @@ applet_register (const char * ior, int applet_id)
 	g_free(ext->ior);
 	ext->ior = g_strdup(ior);
 
+	mulapp_add_ior_and_free_queue(ext->path, ext->ior);
+
 	orientation_change(applet_id,panel);
 	back_change(applet_id,panel);
-	send_applet_tooltips_state(ext->ior,
+	send_applet_tooltips_state(ext->ior,applet_id,
 				   global_config.tooltips_enabled);
-
-	mulapp_add_ior_and_free_queue(ext->path, ext->ior);
 }
 
 static int
 extern_socket_destroy(GtkWidget *w, gpointer data)
 {
 	Extern *ext = data;
+	gtk_widget_destroy(ext->ebox);
 	extern_clean(ext);
 	return FALSE;
 }
@@ -304,22 +297,33 @@ reserve_applet_spot (Extern *ext, PanelWidget *panel, int pos,
 {
 	GtkWidget *socket;
 
+	ext->ebox = gtk_event_box_new();
+	gtk_widget_set_events(ext->ebox, (gtk_widget_get_events(ext->ebox) |
+					  APPLET_EVENT_MASK) &
+			      ~( GDK_POINTER_MOTION_MASK |
+				 GDK_POINTER_MOTION_HINT_MASK));
+
 	socket = gtk_socket_new();
 
 	g_return_val_if_fail(socket!=NULL,0);
 
-	gtk_widget_show (socket);
-	
-	gtk_signal_connect_after(GTK_OBJECT(socket),"destroy",
-				 GTK_SIGNAL_FUNC(extern_socket_destroy),
-				 ext);
+	gtk_container_add(GTK_CONTAINER(ext->ebox),socket);
+
+	gtk_signal_connect(GTK_OBJECT(socket),"destroy",
+			   GTK_SIGNAL_FUNC(extern_socket_destroy),
+			   ext);
+
+	gtk_widget_show_all (ext->ebox);
 	
 	/*we save the ior in the id field of the appletinfo and the 
 	  path in the path field*/
-	if(!register_toy(socket,ext,panel,pos,type)) {
+	if(!register_toy(ext->ebox,ext,panel,pos,type)) {
 		g_warning("Couldn't add applet");
 		return 0;
 	}
+	
+	if(!GTK_WIDGET_REALIZED(socket))
+		gtk_widget_realize(socket);
 
 	return GDK_WINDOW_XWINDOW(socket->window);
 }
