@@ -25,40 +25,14 @@ extern int applet_count;
 
 static char *default_app_pixmap=NULL;
 
-extern PanelWidget *current_panel;
 
 
-
-static int
-launch (GtkWidget *widget, GdkEvent *event, void *data)
+static void
+launch (GtkWidget *widget, void *data)
 {
-	static int in_button = FALSE;
 	GnomeDesktopEntry *item = data;
-	GdkEventButton *bevent = (GdkEventButton *)event;
 
-	/*this is a release after a press inside a button*/
-	if(event->type == GDK_BUTTON_RELEASE && in_button) {
-		in_button = FALSE;
-		gtk_grab_remove(widget);
-		/*if it's inside it's a click*/
-		if(bevent->x >= 0 &&
-		   bevent->x < widget->allocation.width &&
-		   bevent->y >= 0 &&
-		   bevent->y < widget->allocation.height)
-			gnome_desktop_entry_launch (item);
-		return TRUE;
-	/*if it's inside and press, set in_button*/
-	} else if(event->type == GDK_BUTTON_PRESS &&
-		  bevent->button == 1 &&
-		  bevent->x >= 0 &&
-		  bevent->x < widget->allocation.width &&
-		  bevent->y >= 0 &&
-		  bevent->y < widget->allocation.height) {
-		gtk_grab_add(widget);
-		in_button = TRUE;
-		return TRUE;
-	}
-	return FALSE;
+	gnome_desktop_entry_launch (item);
 }
 
 static int
@@ -75,7 +49,7 @@ destroy_launcher(GtkWidget *widget, gpointer data)
 }
 
 
-Launcher *
+static Launcher *
 create_launcher (char *parameters, GnomeDesktopEntry *dentry)
 {
 	char *icon;
@@ -122,27 +96,26 @@ create_launcher (char *parameters, GnomeDesktopEntry *dentry)
 			dentry->icon = gnome_pixmap_file (icon);
 			g_free (icon);
 		}
-		launcher->button = gnome_pixmap_new_from_file (dentry->icon);
+		launcher->button = button_widget_new_from_file(dentry->icon,
+							       LAUNCHER_TILE,
+							       FALSE,
+							       ORIENT_UP);
 	}
 	if (!launcher->button) {
 		if (default_app_pixmap)
-			launcher->button = gnome_pixmap_new_from_file(default_app_pixmap);
+			launcher->button =
+				button_widget_new_from_file(default_app_pixmap,
+							    LAUNCHER_TILE,
+							    FALSE,ORIENT_UP);
 		else
 			launcher->button = gtk_button_new_with_label (_("App"));
 	}
-	gtk_widget_set_events(launcher->button,
-			      gtk_widget_get_events(launcher->button) |
-			      GDK_LEAVE_NOTIFY_MASK |
-			      GDK_ENTER_NOTIFY_MASK |
-			      GDK_BUTTON_PRESS_MASK |
-			      GDK_BUTTON_RELEASE_MASK);
 	gtk_widget_show (launcher->button);
 
-	launcher->signal_click_tag =
-		gtk_signal_connect (GTK_OBJECT(launcher->button),
-				    "event",
-				    (GtkSignalFunc) launch,
-				    dentry);
+	gtk_signal_connect (GTK_OBJECT(launcher->button),
+			    "clicked",
+			    (GtkSignalFunc) launch,
+			    dentry);
 	
 	gtk_signal_connect (GTK_OBJECT(launcher->button), "destroy",
 			    GTK_SIGNAL_FUNC(destroy_launcher),
@@ -176,8 +149,8 @@ properties_apply_callback(GtkWidget *widget, int page, gpointer data)
 	gtk_tooltips_set_tip (panel_tooltips,launcher->button,
 			      launcher->dentry->comment,NULL);
 	
-	/*it also might be a button*/
-	if(GNOME_IS_PIXMAP(launcher->button)) {
+	/*it also might be a text button*/
+	if(IS_BUTTON_WIDGET(launcher->button)) {
 		icon = launcher->dentry->icon;
 		if (icon && *icon) {
 			/* Sigh, now we need to make them local to the gnome
@@ -186,23 +159,19 @@ properties_apply_callback(GtkWidget *widget, int page, gpointer data)
 				launcher->dentry->icon = gnome_pixmap_file (icon);
 				g_free (icon);
 			}
-			gnome_pixmap_load_file (GNOME_PIXMAP(launcher->button),
-						     launcher->dentry->icon);
+			if(!button_widget_set_pixmap_from_file (BUTTON_WIDGET(launcher->button),
+								 launcher->dentry->icon))
+				/*we know default_app_pixmap is ok since otherwise we
+				  wouldn't get here*/
+				button_widget_set_pixmap_from_file (BUTTON_WIDGET(launcher->button),
+								    default_app_pixmap);
 		} else {
 			/*we know default_app_pixmap is ok since otherwise we
 			  wouldn't get here*/
-			gnome_pixmap_load_file (GNOME_PIXMAP(launcher->button),
-						default_app_pixmap);
+			button_widget_set_pixmap_from_file (BUTTON_WIDGET(launcher->button),
+							    default_app_pixmap);
 		}
 	}
-
-	gtk_signal_disconnect(GTK_OBJECT(launcher->button),
-			      launcher->signal_click_tag);
-
-	launcher->signal_click_tag =
-		gtk_signal_connect (GTK_OBJECT(launcher->button), "event",
-				    GTK_SIGNAL_FUNC(launch),
-				    launcher->dentry);
 }
 
 static int
@@ -215,16 +184,8 @@ properties_close_callback(GtkWidget *widget, gpointer data)
 	return FALSE;
 }
 
-static void
-notify_change (GtkWidget *widget, void *data)
-{
-	GnomePropertyBox *box = GNOME_PROPERTY_BOX (data);
-
-	gnome_property_box_changed (box);
-}
-
 static GtkWidget *
-create_properties_dialog(GnomeDesktopEntry *dentry, Launcher *launcher)
+create_properties_dialog(Launcher *launcher)
 {
 	GtkWidget  *dialog;
 
@@ -240,9 +201,9 @@ create_properties_dialog(GnomeDesktopEntry *dentry, Launcher *launcher)
 	gnome_dentry_edit_set_dentry(GNOME_DENTRY_EDIT(launcher->dedit),
 				     launcher->dentry);
 	
-	gtk_signal_connect(GTK_OBJECT(launcher->dedit), "changed",
-			   GTK_SIGNAL_FUNC(notify_change),
-			   dialog);
+	gtk_signal_connect_object(GTK_OBJECT(launcher->dedit), "changed",
+				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
+				  GTK_OBJECT(dialog));
 
 	gtk_signal_connect(GTK_OBJECT(dialog), "destroy",
 			   GTK_SIGNAL_FUNC(properties_close_callback),
@@ -258,7 +219,6 @@ create_properties_dialog(GnomeDesktopEntry *dentry, Launcher *launcher)
 void
 launcher_properties(Launcher *launcher)
 {
-	GnomeDesktopEntry *dentry;
 	GtkWidget         *dialog;
 
 	dialog = gtk_object_get_data(GTK_OBJECT(launcher->button),
@@ -268,7 +228,7 @@ launcher_properties(Launcher *launcher)
 		return;
 	}
 
-	dialog = create_properties_dialog(dentry,launcher);
+	dialog = create_properties_dialog(launcher);
 	gtk_object_set_data(GTK_OBJECT(launcher->button),
 			    LAUNCHER_PROPERTIES,dialog);
 	gtk_widget_show_all (dialog);
@@ -300,18 +260,20 @@ static void
 really_add_launcher(GtkWidget *d,int button, gpointer data)
 {
 	GnomeDEntryEdit *dedit = GNOME_DENTRY_EDIT(data);
+	int pos = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(d),"pos"));
+	PanelWidget *panel = gtk_object_get_data(GTK_OBJECT(d),"panel");
 	if(button==0)
 		_load_launcher_applet(NULL, gnome_dentry_get_dentry(dedit),
-				      current_panel, 0);
+				      panel, pos);
 	gtk_widget_destroy(d);
 }
 
 void
-ask_about_launcher(void)
+ask_about_launcher(char *file, PanelWidget *panel, int pos)
 {
 	GtkWidget *d;
 	GtkWidget *notebook;
-	GtkObject *dedit;
+	GnomeDEntryEdit *dee;
 
 	d = gnome_dialog_new(_("Create launcher applet"),
 			     GNOME_STOCK_BUTTON_OK,
@@ -323,10 +285,20 @@ ask_about_launcher(void)
 	notebook = gtk_notebook_new();
 	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(d)->vbox),notebook,
 			   TRUE,TRUE,5);
-	dedit = gnome_dentry_edit_new(GTK_NOTEBOOK(notebook));
+	dee = GNOME_DENTRY_EDIT(gnome_dentry_edit_new(GTK_NOTEBOOK(notebook)));
+	
+	if(file)
+		gtk_entry_set_text(GTK_ENTRY(dee->exec_entry), file);
+	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(dee->type_combo)->entry),
+			   "Application");
+	
+	
+	gtk_object_set_data(GTK_OBJECT(d),"pos", GINT_TO_POINTER(pos));
+	gtk_object_set_data(GTK_OBJECT(d),"panel",panel);
+
 	gtk_signal_connect(GTK_OBJECT(d),"clicked",
 			   GTK_SIGNAL_FUNC(really_add_launcher),
-			   dedit);
+			   dee);
 
 	gnome_dialog_close_hides(GNOME_DIALOG(d),FALSE);
 
