@@ -18,7 +18,6 @@ BEGIN_GNOME_DECLS
 typedef struct {
 	int                applet_id;
 	GtkWidget         *button;
-	int                signal_click_tag;
 	GtkObject	  *dedit;
 	GnomeDesktopEntry *dentry;
 } Launcher;
@@ -26,7 +25,7 @@ typedef struct {
 void load_launcher_applet(char *params, PanelWidget *panel, int pos);
 void launcher_properties(Launcher *launcher);
 
-void ask_about_launcher(void);
+void ask_about_launcher(char *file, PanelWidget *panel, int pos);
 
 END_GNOME_DECLS
 
