@@ -12,6 +12,7 @@
 #include <dirent.h>
 #include <unistd.h>
 #include <string.h>
+#include <errno.h>
 #include <gnome.h>
 
 #include "panel-include.h"
@@ -26,8 +27,9 @@
 
 static char *gnome_folder = NULL;
 
+/*thingies on menus*/
 GList *small_icons = NULL;
-int show_small_icons = TRUE;
+GList *dot_buttons = NULL;
 
 extern GArray *applets;
 extern int applet_count;
@@ -62,7 +64,7 @@ struct _MenuFinfo {
 PanelWidget *current_panel = NULL;
 
 /*the most important dialog in the whole application*/
-void
+static void
 about_cb (GtkWidget *widget, gpointer data)
 {
 	GtkWidget *about;
@@ -88,7 +90,19 @@ about_cb (GtkWidget *widget, gpointer data)
 	return;
 }
 
-void
+static void
+about_gnome_cb(GtkObject *object, char *program_path)
+{
+  if(!fork()) {
+    int i;
+    for(i = 0; i < 255; i++)
+      close(i);
+    execlp(program_path, program_path, NULL);
+    _exit(1);
+  }
+}
+
+static void
 activate_app_def (GtkWidget *widget, void *data)
 {
 	GnomeDesktopEntry *item = data;
@@ -97,10 +111,10 @@ activate_app_def (GtkWidget *widget, void *data)
 }
 
 static void
-kill_small_icon(GtkWidget *widget, gpointer data)
+kill_widget_from_list(GtkWidget *widget, GList ** list)
 {
-	if(small_icons)
-		small_icons = g_list_remove(small_icons,widget);
+	if(list && *list)
+		*list = g_list_remove(*list,widget);
 }
 
 static void
@@ -154,6 +168,9 @@ get_files_from_menudir(char *menudir)
 		if(!string_is_in_list(out,dent->d_name))
 			out = g_list_append(out,g_strdup(dent->d_name));
 	}
+
+	closedir(dir);
+
 	return out;
 }
 
@@ -281,35 +298,128 @@ restore_grabs(GtkWidget *w, gpointer data)
 					   NULL, cursor, 0) == 0);
 		gdk_cursor_destroy (cursor);
 	}
-
+	
 	gtk_grab_add (GTK_WIDGET (menu));
 }
-	
 
+static void
+dentry_apply_callback(GtkWidget *widget, int page, gpointer data)
+{
+	GnomeDesktopEntry *dentry;
+
+	if (page != -1)
+		return;
+	
+	g_return_if_fail(data!=NULL);
+	g_return_if_fail(GNOME_IS_DENTRY_EDIT(data));
+
+	dentry = gnome_dentry_get_dentry(GNOME_DENTRY_EDIT(data));
+	dentry->location = g_strdup(gtk_object_get_data(data,"location"));
+	gnome_desktop_entry_save(dentry);
+	gnome_desktop_entry_free(dentry);
+}
+
+static void
+edit_dentry(GtkWidget *widget, GnomeDesktopEntry *dentry)
+{
+	GtkWidget *dialog;
+	GtkObject *o;
+
+	dialog = gnome_property_box_new();
+	gtk_window_set_title(GTK_WINDOW(dialog), _("Desktop entry properties"));
+	gtk_window_set_policy(GTK_WINDOW(dialog), FALSE, FALSE, TRUE);
+	
+	o = gnome_dentry_edit_new(GTK_NOTEBOOK(GNOME_PROPERTY_BOX(dialog)->notebook));
+	gtk_object_set_data(o,"location",dentry->location);
+
+	gnome_dentry_edit_set_dentry(GNOME_DENTRY_EDIT(o),dentry);
+
+	gtk_signal_connect_object(GTK_OBJECT(o), "changed",
+				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
+				  GTK_OBJECT(dialog));
+
+	gtk_signal_connect(GTK_OBJECT(dialog), "apply",
+			   GTK_SIGNAL_FUNC(dentry_apply_callback),
+			   o);
+	gtk_widget_show(dialog);
+}
 
 static int
-show_item_menu(GtkWidget *w, GdkEvent *event, gpointer data)
+destroy_dedit(GtkObject *dedit,gpointer data)
+{
+	char *s = gtk_object_get_data(dedit,"location");
+	g_free(s);
+	return FALSE;
+}
+
+static void
+edit_direntry(GtkWidget *widget, MenuFinfo *mf)
+{
+	GtkWidget *dialog;
+	GtkObject *o;
+	char *dirfile = g_concat_dir_and_file(mf->menudir, ".directory");
+	GnomeDesktopEntry *dentry;
+
+	dialog = gnome_property_box_new();
+	gtk_window_set_title(GTK_WINDOW(dialog), _("Desktop entry properties"));
+	gtk_window_set_policy(GTK_WINDOW(dialog), FALSE, FALSE, TRUE);
+	
+	o = gnome_dentry_edit_new(GTK_NOTEBOOK(GNOME_PROPERTY_BOX(dialog)->notebook));
+
+	dentry = gnome_desktop_entry_load_unconditional(dirfile);
+	if (dentry) {
+		gnome_dentry_edit_set_dentry(GNOME_DENTRY_EDIT(o), dentry);
+		gtk_object_set_data(o,"location",g_strdup(dentry->location));
+		gnome_desktop_entry_destroy(dentry);
+		g_free(dirfile);
+	} else {
+		dentry = g_new0(GnomeDesktopEntry, 1);
+		dentry->name =
+			mf->dir_name?g_strdup(mf->dir_name):g_strdup("Menu");
+		dentry->type = g_strdup("Directory");
+		/*we don't have to free dirfile here it will be freed as if
+		  we had strduped it here*/
+		gtk_object_set_data(o,"location",dirfile);
+		gnome_dentry_edit_set_dentry(GNOME_DENTRY_EDIT(o), dentry);
+		gnome_desktop_entry_destroy(dentry);
+	}
+
+	gtk_widget_set_sensitive(GNOME_DENTRY_EDIT(o)->exec_entry, FALSE);
+	gtk_widget_set_sensitive(GNOME_DENTRY_EDIT(o)->tryexec_entry, FALSE);
+	gtk_widget_set_sensitive(GNOME_DENTRY_EDIT(o)->doc_entry, FALSE);
+	gtk_widget_set_sensitive(GNOME_DENTRY_EDIT(o)->type_combo, FALSE);
+	gtk_widget_set_sensitive(GNOME_DENTRY_EDIT(o)->terminal_button, FALSE);
+
+	gtk_signal_connect_object(o, "changed",
+				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
+				  GTK_OBJECT(dialog));
+	gtk_signal_connect(o, "destroy", GTK_SIGNAL_FUNC(destroy_dedit),NULL);
+
+	gtk_signal_connect(GTK_OBJECT(dialog), "apply",
+			   GTK_SIGNAL_FUNC(dentry_apply_callback),
+			   o);
+	gtk_widget_show(dialog);
+}
+
+static void
+show_item_menu(GtkWidget *item, GdkEventButton *bevent, int type)
 {
 	GtkWidget *menu, *menuitem, *prop_item;
-	GdkEventButton *bevent = (GdkEventButton *)event;
 	GnomeDesktopEntry *dentry;
 	MenuFinfo *mf;
-	int type = GPOINTER_TO_INT(data);
-
-	if(event->type!=GDK_BUTTON_PRESS)
-		return FALSE;
 	
-	dentry = gtk_object_get_data(GTK_OBJECT(w),"dentry");
-	mf = gtk_object_get_data(GTK_OBJECT(w),"mf");
-	menu = gtk_object_get_data(GTK_OBJECT(w),"menu");
-	prop_item = gtk_object_get_data(GTK_OBJECT(w),"prop_item");
+	dentry = gtk_object_get_data(GTK_OBJECT(item),"dentry");
+	mf = gtk_object_get_data(GTK_OBJECT(item),"mf");
+	menu = gtk_object_get_data(GTK_OBJECT(item),"item_menu");
+	prop_item = gtk_object_get_data(GTK_OBJECT(item),"prop_item");
 	
 	if(!menu) {
 		menu = gtk_menu_new ();
-		gtk_object_set_data(GTK_OBJECT(w),"menu",menu);
+		
+		gtk_object_set_data(GTK_OBJECT(item),"item_menu",menu);
 		gtk_signal_connect(GTK_OBJECT(menu),"deactivate",
 				   GTK_SIGNAL_FUNC(restore_grabs),
-				   w->parent->parent);
+				   item);
 
 
 		if(type == 1) {
@@ -339,14 +449,34 @@ show_item_menu(GtkWidget *w, GdkEvent *event, gpointer data)
 		}
 
 		prop_item = gtk_menu_item_new ();
-		gtk_object_set_data(GTK_OBJECT(w),"prop_item",prop_item);
+		/*when activated we must pop down the first menu*/
+		gtk_signal_connect_object(GTK_OBJECT(prop_item), "activate",
+					  GTK_SIGNAL_FUNC(gtk_menu_shell_deactivate),
+					  GTK_OBJECT(item->parent));
+		if(type == 1)
+			gtk_signal_connect(GTK_OBJECT(prop_item), "activate",
+					   GTK_SIGNAL_FUNC(edit_dentry),
+					   dentry);
+		else
+			gtk_signal_connect(GTK_OBJECT(prop_item), "activate",
+					   GTK_SIGNAL_FUNC(edit_direntry),
+					   mf);
+		gtk_object_set_data(GTK_OBJECT(item),"prop_item",prop_item);
 		setup_menuitem (prop_item, 0, _("Properties ..."));
 		gtk_menu_append (GTK_MENU (menu), prop_item);
 	}
 	
-	/*FIXME: do properties*/
 	gtk_widget_set_sensitive(prop_item,FALSE);
-
+	if(dentry && access(dentry->location,W_OK)==0) {
+		/*file exists and is writable, we're in bussines*/
+		gtk_widget_set_sensitive(prop_item,TRUE);
+	} else if(!dentry || errno==ENOENT) {
+		/*the dentry isn't there, check if we can write the
+		  directory*/
+		if(access(mf->menudir,W_OK)==0)
+			gtk_widget_set_sensitive(prop_item,TRUE);
+	}
+	
 	gtk_menu_popup (GTK_MENU (menu),
 			NULL,
 			NULL,
@@ -354,10 +484,36 @@ show_item_menu(GtkWidget *w, GdkEvent *event, gpointer data)
 			NULL,
 			bevent->button,
 			0);
+}
+
+static int
+show_item_menu_b_cb(GtkWidget *w, GdkEvent *event, gpointer data)
+{
+	GdkEventButton *bevent = (GdkEventButton *)event;
+	GtkWidget *item;
+	int type = GPOINTER_TO_INT(data);
+	
+	if(event->type!=GDK_BUTTON_PRESS)
+		return FALSE;
+	
+	item = w->parent->parent;
+	show_item_menu(item,bevent,type);
 	
 	return TRUE;
 }
 
+static int
+show_item_menu_mi_cb(GtkWidget *w, GdkEvent *event, gpointer data)
+{
+	GdkEventButton *bevent = (GdkEventButton *)event;
+	int type = GPOINTER_TO_INT(data);
+	
+	if(event->type==GDK_BUTTON_PRESS && bevent->button==3)
+		show_item_menu(w,bevent,type);
+	
+	return FALSE;
+}
+
 static int
 destroy_item_menu(GtkWidget *w, gpointer data)
 {
@@ -366,7 +522,7 @@ destroy_item_menu(GtkWidget *w, gpointer data)
 	menu = gtk_object_get_data(GTK_OBJECT(w),"menu");
 	
 	if(menu)
-		gtk_widget_destroy(menu);
+		gtk_widget_unref(menu);
 	return FALSE;
 }
 
@@ -397,21 +553,30 @@ setup_title_menuitem (GtkWidget *menuitem, GtkWidget *pixmap, char *title,
 
 	small_icons = g_list_prepend (small_icons, align);
 	gtk_signal_connect(GTK_OBJECT(align),"destroy",
-			   GTK_SIGNAL_FUNC(kill_small_icon),NULL);
+			   GTK_SIGNAL_FUNC(kill_widget_from_list),
+			   &small_icons);
 
 	gtk_box_pack_start (GTK_BOX (hbox), align, FALSE, FALSE, 0);
 
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 4);
 	if(mf) {
 		GtkWidget *w = gtk_button_new_with_label(_("..."));
-		gtk_object_set_data(GTK_OBJECT(w),"mf",mf);
+		dot_buttons = g_list_prepend (dot_buttons, w);
+		gtk_signal_connect(GTK_OBJECT(w),"destroy",
+				   GTK_SIGNAL_FUNC(kill_widget_from_list),
+				   &dot_buttons);
+		gtk_object_set_data(GTK_OBJECT(menuitem),"mf",mf);
+		gtk_signal_connect(GTK_OBJECT(menuitem),"event",
+				   GTK_SIGNAL_FUNC(show_item_menu_mi_cb),
+				   GINT_TO_POINTER(0));
 		gtk_signal_connect(GTK_OBJECT(w),"event",
-				   GTK_SIGNAL_FUNC(show_item_menu),
+				   GTK_SIGNAL_FUNC(show_item_menu_b_cb),
 				   GINT_TO_POINTER(0));
 		gtk_signal_connect(GTK_OBJECT(w),"destroy",
 				   GTK_SIGNAL_FUNC(destroy_item_menu),
 				   NULL);
-		gtk_widget_show(w);
+		if(global_config.show_dot_buttons)
+			gtk_widget_show(w);
 		gtk_box_pack_end (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 		/*this is not really a problem for large fonts but it
 		  makes the button smaller*/
@@ -454,7 +619,8 @@ setup_full_menuitem (GtkWidget *menuitem, GtkWidget *pixmap, char *title,
 
 	small_icons = g_list_prepend (small_icons, align);
 	gtk_signal_connect(GTK_OBJECT(align),"destroy",
-			   GTK_SIGNAL_FUNC(kill_small_icon),NULL);
+			   GTK_SIGNAL_FUNC(kill_widget_from_list),
+			   &small_icons);
 
 
 	gtk_box_pack_start (GTK_BOX (hbox), align, FALSE, FALSE, 0);
@@ -462,14 +628,22 @@ setup_full_menuitem (GtkWidget *menuitem, GtkWidget *pixmap, char *title,
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 4);
 	if(dentry) {
 		GtkWidget *w = gtk_button_new_with_label(_("..."));
-		gtk_object_set_data(GTK_OBJECT(w),"dentry",dentry);
+		dot_buttons = g_list_prepend (dot_buttons, w);
+		gtk_signal_connect(GTK_OBJECT(w),"destroy",
+				   GTK_SIGNAL_FUNC(kill_widget_from_list),
+				   &dot_buttons);
+		gtk_object_set_data(GTK_OBJECT(menuitem),"dentry",dentry);
+		gtk_signal_connect(GTK_OBJECT(menuitem),"event",
+				   GTK_SIGNAL_FUNC(show_item_menu_mi_cb),
+				   GINT_TO_POINTER(1));
 		gtk_signal_connect(GTK_OBJECT(w),"event",
-				   GTK_SIGNAL_FUNC(show_item_menu),
+				   GTK_SIGNAL_FUNC(show_item_menu_b_cb),
 				   GINT_TO_POINTER(1));
 		gtk_signal_connect(GTK_OBJECT(w),"destroy",
 				   GTK_SIGNAL_FUNC(destroy_item_menu),
 				   NULL);
-		gtk_widget_show(w);
+		if(global_config.show_dot_buttons)
+			gtk_widget_show(w);
 		gtk_box_pack_end (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 		/*this is not really a problem for large fonts but it
 		  makes the button smaller*/
@@ -486,7 +660,7 @@ setup_menuitem (GtkWidget *menuitem, GtkWidget *pixmap, char *title)
 	setup_full_menuitem(menuitem,pixmap,title,NULL);
 }
 
-void
+static void
 free_app_def (GtkWidget *widget, void *data)
 {
 	GnomeDesktopEntry *item = data;
@@ -495,7 +669,7 @@ free_app_def (GtkWidget *widget, void *data)
 		gnome_desktop_entry_free (item);
 }
 
-void
+static void
 add_menu_separator (GtkWidget *menu)
 {
 	GtkWidget *menuitem;
@@ -505,12 +679,6 @@ add_menu_separator (GtkWidget *menu)
 	gtk_container_add (GTK_CONTAINER (menu), menuitem);
 }
 
-void
-free_string (GtkWidget *widget, void *data)
-{
-	g_free (data);
-}
-
 static int
 add_drawer_to_panel (GtkWidget *widget, void *data)
 {
@@ -653,7 +821,6 @@ check_and_reread(GtkWidget *menuw,Menu *menu,int main_menu)
 		}
 
 		if(need_reread) {
-			puts("debug: rereading menu");
 			if(main_menu)
 				add_menu_widget(menu,NULL,main_menu,TRUE);
 			else {
@@ -706,7 +873,6 @@ check_and_reread(GtkWidget *menuw,Menu *menu,int main_menu)
 			for(list = mfl; list != NULL;
 			    list = g_list_next(list)) {
 				MenuFinfo *mf = list->data;
-				puts("debug: rereading menu");
 				menuw = create_menu_at(old_menu,
 						       mf->menudir,
 						       mf->applets,
@@ -1012,43 +1178,6 @@ create_menu_at (GtkWidget *menu,
 	return menu;
 }
 
-void
-menu_position (GtkMenu *menu, int *x, int *y, gpointer data)
-{
-	Menu * menup = data;
-	GtkWidget *widget = menup->button;
-	int wx, wy;
-	
-	gdk_window_get_origin (widget->window, &wx, &wy);
-
-	switch(menup->orient) {
-		case ORIENT_DOWN:
-			*x = wx;
-			*y = wy + widget->allocation.height;
-			break;
-		case ORIENT_UP:
-			*x = wx;
-			*y = wy - GTK_WIDGET (menu)->allocation.height;
-			break;
-		case ORIENT_RIGHT:
-			*x = wx + widget->allocation.width;
-			*y = wy;
-			break;
-		case ORIENT_LEFT:
-			*x = wx - GTK_WIDGET (menu)->allocation.width;
-			*y = wy;
-			break;
-	}
-
-	if(*x + GTK_WIDGET (menu)->allocation.width > gdk_screen_width())
-		*x=gdk_screen_width() - GTK_WIDGET (menu)->allocation.width;
-	if(*x < 0) *x =0;
-
-	if(*y + GTK_WIDGET (menu)->allocation.height > gdk_screen_height())
-		*y=gdk_screen_height() - GTK_WIDGET (menu)->allocation.height;
-	if(*y < 0) *y =0;
-}
-
 static void
 destroy_menu (GtkWidget *widget, gpointer data)
 {
@@ -1070,6 +1199,9 @@ menu_deactivate(GtkWidget *w, gpointer data)
 	/* allow the panel to hide again */
 	if(IS_SNAPPED_WIDGET(panel))
 		SNAPPED_WIDGET(panel)->autohide_inhibit = FALSE;
+	BUTTON_WIDGET(menu->button)->in_button = FALSE;
+	BUTTON_WIDGET(menu->button)->ignore_leave = FALSE;
+	button_widget_up(BUTTON_WIDGET(menu->button));
 }
 
 static char *
@@ -1096,14 +1228,6 @@ get_real_menu_path(char *arguments, char *menu_base)
 	return this_menu;
 }
 
-
-
-void
-panel_configure (GtkWidget *widget, void *data)
-{
-	panel_config_global();
-}
-
 static GtkWidget *
 create_applets_menu(int fake_submenus)
 {
@@ -1138,6 +1262,7 @@ create_new_panel(GtkWidget *w,gpointer data)
 		panel = snapped_widget_new(SNAPPED_BOTTOM,
 					   SNAPPED_EXPLICIT_HIDE,
 					   SNAPPED_SHOWN,
+					   TRUE,
 					   PANEL_BACK_NONE,
 					   NULL,
 					   TRUE,
@@ -1299,6 +1424,12 @@ current_panel_config(GtkWidget *w, gpointer data)
 	panel_config(parent);
 }
 
+static void
+ask_about_launcher_cb(GtkWidget *w, gpointer data)
+{
+	ask_about_launcher(NULL,current_panel,0);
+}
+
 void
 make_panel_submenu (GtkWidget *menu, int fake_submenus)
 {
@@ -1346,7 +1477,7 @@ make_panel_submenu (GtkWidget *menu, int fake_submenus)
 	setup_menuitem (menuitem, 0, _("Add new launcher"));
 	gtk_menu_append (GTK_MENU (menu), menuitem);
 	gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-			   GTK_SIGNAL_FUNC(ask_about_launcher),NULL);
+			   GTK_SIGNAL_FUNC(ask_about_launcher_cb),NULL);
 
 	add_menu_separator(menu);
 
@@ -1367,7 +1498,7 @@ make_panel_submenu (GtkWidget *menu, int fake_submenus)
 			_("Global properties..."));
 	gtk_menu_append (GTK_MENU (menu), menuitem);
 	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC(panel_configure), 
+			    GTK_SIGNAL_FUNC(panel_config_global), 
 			    NULL);
 
 }
@@ -1383,6 +1514,7 @@ add_special_entries (GtkWidget *menu, int fake_submenus)
 {
 	GtkWidget *menuitem;
 	GtkWidget *panel_menu;
+	char *char_tmp;
 
 	/* Panel entry */
 
@@ -1413,6 +1545,20 @@ add_special_entries (GtkWidget *menu, int fake_submenus)
 			    GTK_SIGNAL_FUNC(about_cb),
 			    NULL);
 
+	char_tmp = gnome_is_program_in_path("guname");
+	if(char_tmp) {
+	  menuitem = gtk_menu_item_new ();
+	  setup_menuitem (menuitem,
+			  gnome_stock_pixmap_widget(menu,
+						    GNOME_STOCK_PIXMAP_ABOUT),
+			  _("About GNOME..."));
+	  gtk_menu_append (GTK_MENU (menu), menuitem);
+	  gtk_signal_connect_interp(GTK_OBJECT (menuitem), "activate",
+				    (GtkCallbackMarshal)about_gnome_cb,
+				    char_tmp, (GtkDestroyNotify)g_free,
+				    TRUE);
+	}
+
 	menuitem = gtk_menu_item_new ();
 	setup_menuitem (menuitem,
 			gnome_stock_pixmap_widget(menu,
@@ -1431,7 +1577,8 @@ create_root_menu(int fake_submenus, MainMenuType type)
 	GtkWidget *uroot_menu;
 
 	root_menu = create_system_menu(NULL,fake_submenus);
-
+	uroot_menu = NULL;
+	
 	if(type == MAIN_MENU_BOTH)
 		root_menu = create_user_menu(root_menu, fake_submenus);
 	else
@@ -1483,69 +1630,43 @@ add_menu_widget (Menu *menu, GList *menudirl, int main_menu, int fake_subs)
 			    GTK_SIGNAL_FUNC (menu_deactivate), menu);
 }
 
-static GtkWidget *
-listening_parent(GtkWidget *widget)
-{
-	if (GTK_WIDGET_NO_WINDOW(widget))
-		return listening_parent(widget->parent);
-
-	return widget;
-}
-
-static int
-menu_button_press(GtkWidget *widget, GdkEvent *event, gpointer data)
+static void
+menu_button_pressed(GtkWidget *widget, gpointer data)
 {
 	Menu *menu = data;
-	if(event->type == GDK_BUTTON_PRESS) {
-		GdkEventButton *bevent = (GdkEventButton *)event; 
-		if(bevent->button==1) {
-			GtkWidget *wpanel =
-				get_panel_parent(menu->button);
-			int main_menu = (strcmp (menu->path, ".") == 0);
+	GdkEventButton *bevent = (GdkEventButton*)gtk_get_current_event();
+	GtkWidget *wpanel = get_panel_parent(menu->button);
+	int applet_id =
+		GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(menu->button),
+						    "applet_id"));
+	int main_menu = (strcmp (menu->path, ".") == 0);
+	
+	check_and_reread(menu->menu,menu,main_menu);
 
-			check_and_reread(menu->menu,menu,main_menu);
+	/*so that the panel doesn't pop down until we're
+	  done with the menu */
+	if(IS_SNAPPED_WIDGET(wpanel)) {
+		SNAPPED_WIDGET(wpanel)->autohide_inhibit = TRUE;
+		snapped_widget_queue_pop_down(SNAPPED_WIDGET(wpanel));
+	}
 
-			/*so that the panel doesn't pop down until we're
-			  done with the menu */
-			if(IS_SNAPPED_WIDGET(wpanel)) {
-				SNAPPED_WIDGET(wpanel)->autohide_inhibit = TRUE;
-				snapped_widget_queue_pop_down(SNAPPED_WIDGET(wpanel));
-			}
+	/*this HAS to be set everytime we popup the menu*/
+	current_panel = PANEL_WIDGET(menu->button->parent);
+	
+	BUTTON_WIDGET(menu->button)->ignore_leave = TRUE;
+	gtk_grab_remove(menu->button);
 
-			/*this HAS to be set everytime we popup the menu*/
-			current_panel =
-				gtk_object_get_data(GTK_OBJECT(menu->button),
-						    PANEL_APPLET_PARENT_KEY);
-
-			gtk_menu_popup(GTK_MENU(menu->menu), 0,0, menu_position,
-				       data, bevent->button, bevent->time);
-			return TRUE;
-		}
-		return gtk_widget_event(listening_parent(widget->parent), event);
-	} else if(event->type == GDK_BUTTON_RELEASE)
-		return gtk_widget_event(listening_parent(widget->parent), event);
-	return FALSE;
+	gtk_menu_popup(GTK_MENU(menu->menu), 0,0, applet_menu_position,
+		       GINT_TO_POINTER(applet_id),
+		       bevent->button, bevent->time);
 }
 
 static char *
-get_pixmap(char *menudir, PanelOrientType orient, int main_menu)
+get_pixmap(char *menudir, int main_menu)
 {
 	char *pixmap_name;
 	if (main_menu) {
-		switch(orient) {
-		case ORIENT_DOWN:
-			pixmap_name = gnome_unconditional_pixmap_file ("gnome-menu-down.png");
-			break;
-		case ORIENT_UP:
-			pixmap_name = gnome_unconditional_pixmap_file ("gnome-menu-up.png");
-			break;
-		case ORIENT_RIGHT:
-			pixmap_name = gnome_unconditional_pixmap_file ("gnome-menu-right.png");
-			break;
-		case ORIENT_LEFT:
-			pixmap_name = gnome_unconditional_pixmap_file ("gnome-menu-left.png");
-			break;
-		}
+		pixmap_name = gnome_unconditional_pixmap_file("gnome-logo-icon-transparent.png");
 	} else {
 		char *dentry_name;
 		GnomeDesktopEntry *item_info;
@@ -1569,31 +1690,23 @@ create_panel_menu (char *menudir, int main_menu,
 		   PanelOrientType orient, MainMenuType main_menu_type)
 {
 	Menu *menu;
-
-	char *pixmap_name = NULL;
+	
+	char *pixmap_name;
 
 	menu = g_new(Menu,1);
 
-	pixmap_name = get_pixmap(menudir,orient,main_menu);
+	pixmap_name = get_pixmap(menudir,main_menu);
 
-	menu->orient = orient;
-	
 	menu->main_menu_type = main_menu_type;
 
 
 
 	/*make the pixmap*/
-	menu->button = gnome_pixmap_new_from_file_at_size (pixmap_name,
-							   BIG_ICON_SIZE,
-							   BIG_ICON_SIZE);
-	gtk_widget_set_events(menu->button,
-			      gtk_widget_get_events(menu->button) |
-			      GDK_LEAVE_NOTIFY_MASK |
-			      GDK_ENTER_NOTIFY_MASK |
-			      GDK_BUTTON_PRESS_MASK |
-			      GDK_BUTTON_RELEASE_MASK);
-	gtk_signal_connect (GTK_OBJECT (menu->button), "event",
-			    GTK_SIGNAL_FUNC (menu_button_press), menu);
+	menu->button = button_widget_new_from_file (pixmap_name,
+						    MENU_TILE,
+						    TRUE,orient);
+	gtk_signal_connect_after (GTK_OBJECT (menu->button), "pressed",
+				  GTK_SIGNAL_FUNC (menu_button_pressed), menu);
 	gtk_signal_connect (GTK_OBJECT (menu->button), "destroy",
 			    GTK_SIGNAL_FUNC (destroy_menu), menu);
 	gtk_widget_show(menu->button);
@@ -1610,7 +1723,8 @@ create_panel_menu (char *menudir, int main_menu,
 }
 
 static Menu *
-create_menu_applet(char *arguments, PanelOrientType orient, MainMenuType main_menu_type)
+create_menu_applet(char *arguments, PanelOrientType orient,
+		   MainMenuType main_menu_type)
 {
 	Menu *menu;
 	int main_menu;
@@ -1625,10 +1739,10 @@ create_menu_applet(char *arguments, PanelOrientType orient, MainMenuType main_me
 
 
 	if(!gnome_folder) {
-		gnome_folder = gnome_unconditional_pixmap_file
-			("gnome-folder.png");
+		gnome_folder =
+			gnome_unconditional_pixmap_file("gnome-folder.png");
 		if (!g_file_exists (gnome_folder)) {
-			free (gnome_folder);
+			g_free (gnome_folder);
 			gnome_folder = NULL;
 		}
 	}
@@ -1646,11 +1760,13 @@ create_menu_applet(char *arguments, PanelOrientType orient, MainMenuType main_me
 }
 
 static void
-set_show_small_icons_foreach(gpointer data, gpointer user_data)
+set_show_stuff_foreach(gpointer data, gpointer user_data)
 {
 	GtkWidget *w = data;
-	g_return_if_fail(w);
-	if (global_config.show_small_icons)
+
+	g_return_if_fail(w!=NULL);
+
+	if (GPOINTER_TO_INT(user_data))
 		gtk_widget_show(w);
 	else
 		gtk_widget_hide(w);
@@ -1659,35 +1775,23 @@ set_show_small_icons_foreach(gpointer data, gpointer user_data)
 void
 set_show_small_icons(void)
 {
-	g_list_foreach(small_icons,set_show_small_icons_foreach,NULL);
+	g_list_foreach(small_icons,set_show_stuff_foreach,
+		       GINT_TO_POINTER(global_config.show_small_icons));
+}
+void
+set_show_dot_buttons(void)
+{
+	g_list_foreach(dot_buttons,set_show_stuff_foreach,
+		       GINT_TO_POINTER(global_config.show_dot_buttons));
 }
 
 void
 set_menu_applet_orient(Menu *menu, PanelOrientType orient)
 {
-	char *pixmap_name = NULL;
-	char *this_menu;
-	char *menu_base;
-
 	g_return_if_fail(menu!=NULL);
-	g_return_if_fail(menu->path!=NULL);
 
-	menu->orient = orient;
-
-	menu_base = gnome_unconditional_datadir_file ("apps");
-	this_menu = get_real_menu_path(menu->path,menu_base);
-	pixmap_name = get_pixmap(this_menu,menu->orient,
-				 strcmp (menu->path, ".") == 0);
-	g_free(menu_base);
-	g_free(this_menu);
-
-	/*make the pixmap*/
-	gnome_pixmap_load_file_at_size (GNOME_PIXMAP(menu->button),
-					pixmap_name,
-					BIG_ICON_SIZE,
-					BIG_ICON_SIZE);
-
-	g_free(pixmap_name);
+	button_widget_set_params(BUTTON_WIDGET(menu->button),
+				 MENU_TILE,TRUE,orient);
 }
 
 static void
@@ -1697,7 +1801,6 @@ properties_apply_callback(GtkWidget *widget, int page, gpointer data)
 	GtkWidget *main_menu = gtk_object_get_data(GTK_OBJECT(widget), "main_menu");
 	GtkWidget *menu_both = gtk_object_get_data(GTK_OBJECT(widget), "menu_both");
 	GtkWidget *menu_system = gtk_object_get_data(GTK_OBJECT(widget), "menu_system");
-	GtkWidget *menu_user = gtk_object_get_data(GTK_OBJECT(widget), "menu_user");
 	GtkWidget *pathentry = gtk_object_get_data(GTK_OBJECT(widget), "path");
 	char *s;
 
@@ -1729,13 +1832,11 @@ properties_apply_callback(GtkWidget *widget, int page, gpointer data)
 		char *menu_base = gnome_unconditional_datadir_file ("apps");
 		char *this_menu = get_real_menu_path(menu->path,menu_base);
 		GList *list = g_list_append(NULL,this_menu);
-		char *pixmap_name = get_pixmap(this_menu,menu->orient,
+		char *pixmap_name = get_pixmap(this_menu,
 					       strcmp(menu->path,".")==0);
 		/*make the pixmap*/
-		gnome_pixmap_load_file_at_size (GNOME_PIXMAP(menu->button),
-						pixmap_name,
-						BIG_ICON_SIZE,
-						BIG_ICON_SIZE);
+		button_widget_set_pixmap_from_file (BUTTON_WIDGET(menu->button),
+						    pixmap_name);
 		g_free(pixmap_name);
 		
 		add_menu_widget(menu,list, strcmp(menu->path,".")==0, TRUE);
@@ -1960,3 +2061,123 @@ load_menu_applet(char *params, int main_menu_type,
 				    _("Properties..."));
 	}
 }
+
+/*menu related utility functions .. also used elswhere*/
+
+static void
+get_menu_position (GtkMenu *menu, int *x, int *y,
+		   int wx, int wy, int ww, int wh,
+		   GtkWidget *pwidget)
+{
+	if(IS_DRAWER_WIDGET(pwidget)) {
+		PanelWidget *panel =
+			PANEL_WIDGET(DRAWER_WIDGET(pwidget)->panel);
+		if(panel->orient==PANEL_VERTICAL) {
+			*x = wx + ww;
+			*y += wy;
+		} else {
+			*x += wx;
+			*y = wy - GTK_WIDGET (menu)->requisition.height;
+		}
+	} else if(IS_SNAPPED_WIDGET(pwidget)) {
+		switch(SNAPPED_WIDGET(pwidget)->pos) {
+		case SNAPPED_BOTTOM:
+			*x += wx;
+			*y = wy - GTK_WIDGET (menu)->requisition.height;
+			break;
+		case SNAPPED_TOP:
+			*x += wx;
+			*y = wy + wh;
+			break;
+		case SNAPPED_LEFT:
+			*x = wx + ww;
+			*y += wy;
+			break;
+		case SNAPPED_RIGHT:
+			*x = wx - GTK_WIDGET (menu)->requisition.width;
+			*y += wy;
+			break;
+		}
+	} else if(IS_CORNER_WIDGET(pwidget)) {
+		PanelWidget *panel =
+			PANEL_WIDGET(CORNER_WIDGET(pwidget)->panel);
+		if(panel->orient==PANEL_HORIZONTAL) {
+			switch(CORNER_WIDGET(pwidget)->pos) {
+			case CORNER_SE:
+			case CORNER_SW:
+				*x += wx;
+				*y = wy - GTK_WIDGET (menu)->requisition.height;
+				break;
+			case CORNER_NE:
+			case CORNER_NW:
+				*x += wx;
+				*y = wy + wh;
+				break;
+			}
+		} else {
+			switch(CORNER_WIDGET(pwidget)->pos) {
+			case CORNER_NW:
+			case CORNER_SW:
+				*x = wx + ww;
+				*y += wy;
+				break;
+			case CORNER_NE:
+			case CORNER_SE:
+				*x = wx - GTK_WIDGET (menu)->requisition.width;
+				*y += wy;
+				break;
+			}
+		}
+	}
+
+	if(*x + GTK_WIDGET (menu)->requisition.width > gdk_screen_width())
+		*x=gdk_screen_width() - GTK_WIDGET (menu)->requisition.width;
+	if(*x < 0) *x =0;
+
+	if(*y + GTK_WIDGET (menu)->requisition.height > gdk_screen_height())
+		*y=gdk_screen_height() - GTK_WIDGET (menu)->requisition.height;
+	if(*y < 0) *y =0;
+}
+
+void
+panel_menu_position (GtkMenu *menu, int *x, int *y, gpointer data)
+{
+	GtkWidget *w = data;
+	int wx, wy;
+
+	g_return_if_fail(w != NULL);
+
+	gdk_window_get_origin (w->window, &wx, &wy);
+	
+	gtk_widget_get_pointer(w, x, y);
+	get_menu_position(menu,x,y,wx,wy,w->allocation.width,w->allocation.height,w);
+}
+
+void
+applet_menu_position (GtkMenu *menu, int *x, int *y, gpointer data)
+{
+	int wx, wy;
+	AppletInfo *info = get_applet_info(GPOINTER_TO_INT(data));
+	PanelWidget *panel;
+	GtkWidget *w; /*the panel window widget*/
+
+	g_return_if_fail(info != NULL);
+	g_return_if_fail(info->widget != NULL);
+
+	panel = PANEL_WIDGET(info->widget->parent);
+	g_return_if_fail(panel != NULL);
+	
+	w = gtk_object_get_data(GTK_OBJECT(panel), PANEL_PARENT);
+
+	gdk_window_get_origin (info->widget->window, &wx, &wy);
+	if(GTK_WIDGET_NO_WINDOW(info->widget)) {
+		wx += info->widget->allocation.x;
+		wy += info->widget->allocation.y;
+	}
+	*x = *y = 0;
+	get_menu_position(menu,x,y,wx,wy,
+			  info->widget->allocation.width,
+			  info->widget->allocation.height,
+			  w);
+}
+
