@@ -58,7 +58,7 @@ void server_start_new_applet(POA_GNOME_Applet *servant, CORBA_char * cookie, COR
 
 void server_back_change(POA_GNOME_Applet *servant, CORBA_char * cookie, CORBA_short applet_id, CORBA_short back_type, CORBA_char * pixmap, CORBA_short c_red, CORBA_short c_green, CORBA_short c_blue, CORBA_Environment *ev);
 
-void server_tooltips_state(POA_GNOME_Applet *servant, CORBA_char * cookie, CORBA_short enabled, CORBA_Environment *ev);
+void server_tooltips_state(POA_GNOME_Applet *servant, CORBA_char * cookie, CORBA_short applet_id, CORBA_short enabled, CORBA_Environment *ev);
 
 static POA_GNOME_Applet__epv applet_epv = {
   NULL, /* _private */
@@ -72,18 +72,6 @@ static POA_GNOME_Applet__epv applet_epv = {
 static POA_GNOME_Applet__vepv vepv = { &base_epv, &applet_epv };
 static POA_GNOME_Applet applet_servant = { NULL, &vepv };
 
-BEGIN_GNOME_DECLS
-
-void _gnome_applet_change_orient(int applet_id, int orient);
-int _gnome_applet_session_save(int applet_id, const char *cfgpath,
-			       const char *globcfgpath);
-int _gnome_applet_start_new_applet(const char *params);
-void _gnome_applet_back_change(int applet_id, int back_type,
-			       const char *pixmap, GdkColor *color);
-void _gnome_applet_tooltips_state(int enabled);
-
-END_GNOME_DECLS
-
 
 void server_change_orient(POA_GNOME_Applet *servant, CORBA_char * ccookie, CORBA_short applet_id, CORBA_short orient, CORBA_Environment *ev)
 {
@@ -134,11 +122,11 @@ void server_back_change(POA_GNOME_Applet *servant, CORBA_char * ccookie, CORBA_s
   _gnome_applet_back_change(applet_id, back_type, pixmap, &color);
 }
 
-void server_tooltips_state(POA_GNOME_Applet *servant, CORBA_char * ccookie, CORBA_short enabled, CORBA_Environment *ev)
+void server_tooltips_state(POA_GNOME_Applet *servant, CORBA_char * ccookie, CORBA_short applet_id, CORBA_short enabled, CORBA_Environment *ev)
 {
   CHECK_COOKIE();
 
-  _gnome_applet_tooltips_state(enabled);
+  _gnome_applet_tooltips_state(applet_id, enabled);
 }
 
 int gnome_panel_applet_reinit_corba(void)
@@ -153,8 +141,8 @@ int gnome_panel_applet_reinit_corba(void)
   if (hostname [0] == 0)
     strcpy (hostname, "unknown-host");
 
-	/*do a 20 second timeout until we get the iior*/
-  for(i=0;i<20;i++) {
+  /*do a 30 second timeout until we get the iior*/
+  for(i=0;i<30;i++) {
     name = g_copy_strings ("/CORBA-servers/Panel-", hostname, 
 			   "/DISPLAY-", getenv ("DISPLAY"), NULL);
 
@@ -433,10 +421,10 @@ gnome_panel_applet_request_id (const char *path,
 	int i;
 
 	/*this is the first call to panel so we'll do a loop and timeout
-	  after 20 seconds if we don't find a panel*/
+	  after 30 seconds if we don't find a panel*/
 	*applet_id = -1;
 
-	for(i=0;i<20;i++) {
+	for(i=0;i<30;i++) {
 		  /*reserve a spot and get an id for this applet*/
 	  *applet_id = GNOME_Panel_applet_request_id(panel_client,
 						     cookie,
@@ -446,11 +434,10 @@ gnome_panel_applet_request_id (const char *path,
 						     &cfg,
 						     &globcfg,
 						     &wid, &ev);
-	  sleep(1);
-	  gnome_panel_applet_reinit_corba ();
 	  if(*applet_id!=-1)
 	    break;
 	  sleep(1);
+	  gnome_panel_applet_reinit_corba ();
 	}
 	/*if the request_id never completed*/
 	if(*applet_id == -1)
@@ -489,37 +476,45 @@ gnome_panel_applet_register (GtkWidget *widget, int applet_id)
 	/*the applet implementation, it's only created once*/
 	static GNOME_Applet applet = NULL;
 
-	if(!ior) {
+	if(!applet) {
 	  PortableServer_POA poa;
 
-	  static const PortableServer_ObjectId objid = {0, sizeof("GNOME/Applet"),
-							"GNOME/Applet"};
+	  PortableServer_ObjectId *objid;
 	  POA_GNOME_Applet__init(&applet_servant, &ev);
 
-	  poa = orb->root_poa; /* non-portable temp hack */
+	  g_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, NULL);
+
+	  poa = (PortableServer_POA)
+	    CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev);
 
 	  PortableServer_POAManager_activate(PortableServer_POA__get_the_POAManager(poa, &ev), &ev);
+	  g_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, NULL);
 
-	  PortableServer_POA_activate_object_with_id(poa,
-						     &objid, &applet_servant,
+	  objid = PortableServer_POA_activate_object(poa, &applet_servant,
 						     &ev);
+	  g_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, NULL);
 
 	  applet = PortableServer_POA_servant_to_reference(poa,
 							   &applet_servant,
 							   &ev);
 
+	  g_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, NULL);
+
 	/* Now a way to find out the CORBA impl from the widget */
 
 	  ior = CORBA_ORB_object_to_string(orb, applet, &ev);
+	  g_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, NULL);
 	}
 
 	gtk_object_set_data (GTK_OBJECT (widget), "CORBA_object", applet);
 
 	GNOME_Panel_applet_register(panel_client, cookie, ior, applet_id, &ev);
 
+#if 0
 	CORBA_free(ior);
 
 	ior = NULL;
+#endif
 
 	bind_top_applet_events(widget, applet_id);
 
@@ -596,8 +591,8 @@ gnome_panel_applet_cleanup(int applet_id)
     nlist = g_list_next(list);
     if(info->applet_id == applet_id) {
       g_free(info->name);
-      g_list_remove_link(applet_callbacks,list);
-      g_list_free(list);
+      applet_callbacks = g_list_remove_link(applet_callbacks,list);
+      g_list_free_1(list);
       g_free(info);
     }
     list = nlist;
@@ -649,17 +644,16 @@ static void orb_remove_connection(GIOPConnection *cnx)
 void
 applet_corba_gtk_main (char *str)
 {
-  static const PortableServer_ObjectId objid = {0, sizeof("GNOME/Applet"),
-					  "GNOME/Applet"};
   gtk_main();
-
-  PortableServer_POA_deactivate_object(orb->root_poa, &objid, &ev);
 }
 
 void
 applet_corba_gtk_main_quit (void)
 {
-  CORBA_ORB_shutdown(orb, CORBA_FALSE, &ev);
+  if(panel_client)
+    CORBA_Object_release(panel_client, &ev);
+
+  CORBA_ORB_shutdown(orb, CORBA_TRUE, &ev);
   gtk_main_quit();
 }
 
