@@ -476,11 +476,11 @@ void send_applet_change_back (const char *ior, int applet_id,
   CORBA_Object_release(appl, &ev);
 }
 
-void send_applet_tooltips_state (const char *ior, int enabled)
+void send_applet_tooltips_state (const char *ior, int applet_id, int enabled)
 {
   GNOME_Applet appl = CORBA_ORB_string_to_object(orb, (CORBA_char *)ior, &ev);
 
-  GNOME_Applet_tooltips_state(appl, cookie, enabled, &ev);
+  GNOME_Applet_tooltips_state(appl, cookie, applet_id, enabled, &ev);
 
   CORBA_Object_release(appl, &ev);
 }
@@ -503,10 +503,22 @@ static void orb_add_connection(GIOPConnection *cnx)
 						GDK_INPUT_READ|GDK_INPUT_EXCEPTION,
 						(GdkInputFunction)orb_handle_connection,
 						NULL, cnx, NULL);
+#if 0
+  g_message("Adding FD #%d (tag %d)", GIOP_CONNECTION_GET_FD(cnx),
+	    cnx->user_data);
+#endif
 }
 
 static void orb_remove_connection(GIOPConnection *cnx)
 {
+  if(cnx->user_data == (gpointer)-1)
+    return;
+
+#if 0
+  g_message("Removing FD #%d (tag %d)", GIOP_CONNECTION_GET_FD(cnx),
+	    cnx->user_data);
+#endif
+
   gtk_input_remove((guint)cnx->user_data);
   cnx->user_data = (gpointer)-1;
 }
@@ -570,17 +582,23 @@ panel_corba_gtk_init(void)
   IIOPRemoveConnectionHandler = orb_remove_connection;
 
   /* It's not like ORBit reads the cmdline anyways, right now */
-  orb = CORBA_ORB_init(&n, &name /* dummy */, "mico-local-orb", &ev);
+  orb = CORBA_ORB_init(&n, &name /* dummy */, "orbit-local-orb", &ev);
 
   POA_GNOME_Panel__init(&servant, &ev);
+  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
-  thepoa = (PortableServer_POA)orb->root_poa; /* non-portable temporary hack */
+  thepoa = (PortableServer_POA)
+    CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev);
+  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
   PortableServer_POAManager_activate(PortableServer_POA__get_the_POAManager(thepoa, &ev), &ev);
+  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
-  PortableServer_POA_activate_object_with_id((PortableServer_POA)orb->root_poa, &objid, &servant, &ev);
+  PortableServer_POA_activate_object_with_id(thepoa, &objid, &servant, &ev);
+  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
-  acc = PortableServer_POA_servant_to_reference((PortableServer_POA)orb->root_poa, &servant, &ev);
+  acc = PortableServer_POA_servant_to_reference(thepoa, &servant, &ev);
+  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
   ior = CORBA_ORB_object_to_string(orb, acc, &ev);
   
@@ -597,6 +615,8 @@ panel_corba_gtk_init(void)
   CORBA_free(ior);
 
   CORBA_Object_release(acc, &ev);
+  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
   ORBit_custom_run_setup(orb, &ev);
+  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 }
