@@ -2,11 +2,15 @@
 #ifndef PANEL_INCLUDE_H
 #define PANEL_INCLUDE_H
 
+#include "panel-types.h"
+
 #include "panel-widget.h"
 #include "snapped-widget.h"
 #include "drawer-widget.h"
 #include "corner-widget.h"
 
+#include "button-widget.h"
+
 #include "panel.h"
 #include "applet.h"
 #include "session.h"
@@ -25,8 +29,7 @@
 #include "mulapp.h"
 #include "exec-queue.h"
 
-#include "mico-glue.h"
-#include "mico-parse.h"
+#include "orbit-glue.h"
 
 #include "panel-util.h"
 #include "gdkextra.h"
