@@ -3,7 +3,7 @@
 #include <glib.h>
 #include <fcntl.h>
 
-#include "panel-util.h"
+#include "panel-include.h"
 
 /* this function might be a slight overkill, but it should work
    perfect, hopefully it should be 100% buffer overrun safe too*/
@@ -38,6 +38,7 @@ get_full_path(char *argv0)
 		free(curpath);
 
 		realpath(outbuf,buf);
+		g_free(outbuf);
 	
 		return g_strdup(buf);
 	}
@@ -297,7 +298,15 @@ resize_window(GtkWidget *widget, int w, int h)
 GList *
 my_g_list_pop_first(GList *list)
 {
-	GList *r = g_list_remove_link(list,list);
-	g_list_free(list);
+	GList *r;
+	
+	if(!list)
+		return NULL;
+       
+	r = list->next;
+	list->next = NULL;
+	if(r)
+		r->prev = NULL;
+	g_list_free_1(list);
 	return r;
 }
