@@ -9,12 +9,14 @@
 #include <gtk/gtk.h>
 #include <gnome.h>
 #include "panel-widget.h"
+#include "button-widget.h"
 #include "panel-util.h"
 #include "gdkextra.h"
 
 GList *panels=NULL; /*other panels we might want to move the applet to*/
 
-#define DEBUG 1
+/*define for some debug output*/
+/*#define DEBUG 1*/
 
 /*there  can universally be only one applet being dragged since we assume
 we only have one mouse :) */
@@ -35,7 +37,10 @@ static void panel_widget_cadd		(GtkContainer     *container,
 					 GtkWidget        *widget);
 static void panel_widget_cremove	(GtkContainer     *container,
 					 GtkWidget        *widget);
-
+static int  panel_widget_expose		(GtkWidget        *widget,
+					 GdkEventExpose   *event);
+static void panel_widget_draw		(GtkWidget        *widget,
+					 GdkRectangle     *area);
 
 
 GdkCursor *fleur_cursor;
@@ -50,8 +55,6 @@ int pw_disable_animations = FALSE;
 PanelMovementType pw_movement_type = PANEL_SWITCH_MOVE;
 int pw_applet_padding = 3;
 
-static char *image_drop_types[] = {"url:ALL", "application/x-color"};
-
 #define APPLET_EVENT_MASK (GDK_BUTTON_PRESS_MASK |		\
 			   GDK_BUTTON_RELEASE_MASK |		\
 			   GDK_POINTER_MOTION_MASK |		\
@@ -71,10 +74,6 @@ typedef void (*AppletSignal) (GtkObject * object,
 			      GtkWidget * applet,
 			      gpointer data);
 
-typedef int (*Button1Signal) (GtkObject * object,
-			      GtkWidget * applet,
-			      gpointer data);
-
 /************************
  debugging
  ************************/
@@ -133,8 +132,6 @@ enum {
 	APPLET_ADDED_SIGNAL,
 	APPLET_REMOVED_SIGNAL,
 	BACK_CHANGE_SIGNAL,
-	APPLET_CLICKED_SIGNAL, /*these two are only for NO WINDOW applets, other*/
-	APPLET_BUTTON1_SIGNAL, /*applets won't get these two*/
 	LAST_SIGNAL
 };
 
@@ -186,24 +183,6 @@ marshal_signal_back (GtkObject * object,
 		  func_data);
 }
 
-static void
-marshal_signal_button1 (GtkObject * object,
-			GtkSignalFunc func,
-			gpointer func_data,
-			GtkArg * args)
-{
-	Button1Signal rfunc;
-	int *retval;
-
-	rfunc = (Button1Signal) func;
-
-	retval = GTK_RETLOC_BOOL(args[1]);
-
-	*retval = (*rfunc) (object, GTK_VALUE_POINTER (args[0]),
-		  	    func_data);
-}
-
- 
 static void
 panel_widget_class_init (PanelWidgetClass *class)
 {
@@ -265,26 +244,6 @@ panel_widget_class_init (PanelWidgetClass *class)
 			       GTK_TYPE_ENUM,
 			       GTK_TYPE_POINTER,
 			       GTK_TYPE_POINTER);
-	panel_widget_signals[APPLET_CLICKED_SIGNAL] =
-		gtk_signal_new("applet_clicked",
-			       GTK_RUN_LAST,
-			       object_class->type,
-			       GTK_SIGNAL_OFFSET(PanelWidgetClass,
-			       			 applet_clicked),
-			       marshal_signal_applet,
-			       GTK_TYPE_NONE,
-			       1,
-			       GTK_TYPE_POINTER);
-	panel_widget_signals[APPLET_BUTTON1_SIGNAL] =
-		gtk_signal_new("applet_button1",
-			       GTK_RUN_LAST,
-			       object_class->type,
-			       GTK_SIGNAL_OFFSET(PanelWidgetClass,
-			       			 applet_button1),
-			       marshal_signal_button1,
-			       GTK_TYPE_BOOL,
-			       1,
-			       GTK_TYPE_POINTER);
 	gtk_object_class_add_signals(object_class,panel_widget_signals,
 				     LAST_SIGNAL);
 
@@ -296,6 +255,8 @@ panel_widget_class_init (PanelWidgetClass *class)
 	
 	widget_class->size_request = panel_widget_size_request;
 	widget_class->size_allocate = panel_widget_size_allocate;
+	widget_class->expose_event = panel_widget_expose;
+	widget_class->draw = panel_widget_draw;
 
 	container_class->add = panel_widget_cadd;
 	container_class->remove = panel_widget_cremove;
@@ -305,6 +266,13 @@ static void
 remove_panel_from_forbidden(PanelWidget *panel, PanelWidget *r)
 {
 	GList *list;
+	GtkWidget *parent_panel;
+	
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(r!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(r));
+
 	if(!panel->master_widget)
 		return;
 
@@ -316,16 +284,22 @@ remove_panel_from_forbidden(PanelWidget *panel, PanelWidget *r)
 				    PANEL_APPLET_FORBIDDEN_PANELS,
 				    list);
 	}
-	panel = gtk_object_get_data(GTK_OBJECT(panel->master_widget),
-				    PANEL_APPLET_PARENT_KEY);
-	if(panel)
-		remove_panel_from_forbidden(panel, r);
+	parent_panel = panel->master_widget->parent;
+	if (parent_panel)
+		remove_panel_from_forbidden(PANEL_WIDGET(parent_panel), r);
 }
 
 static void
 add_panel_to_forbidden(PanelWidget *panel, PanelWidget *r)
 {
 	GList *list;
+	GtkWidget *parent_panel;
+
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(r!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(r));
+
 	if(!panel->master_widget)
 		return;
 
@@ -338,11 +312,9 @@ add_panel_to_forbidden(PanelWidget *panel, PanelWidget *r)
 				    PANEL_APPLET_FORBIDDEN_PANELS,
 				    list);
 	}
-
-	panel = gtk_object_get_data(GTK_OBJECT(panel->master_widget),
-				    PANEL_APPLET_PARENT_KEY);
-	if(panel)
-		add_panel_to_forbidden(panel, r);
+	parent_panel = panel->master_widget->parent;
+	if (parent_panel)
+		add_panel_to_forbidden(PANEL_WIDGET(parent_panel), r);
 }
 
 static void
@@ -350,6 +322,10 @@ run_up_forbidden(PanelWidget *panel,
 		 void (*runfunc)(PanelWidget *,PanelWidget *))
 {
 	GList *list;
+
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+
 	for(list = panel->applet_list;list!=NULL;list = g_list_next(list)) {
 		AppletData *ad = list->data;
 		PanelWidget *p =
@@ -370,6 +346,7 @@ panel_widget_cadd(GtkContainer *container, GtkWidget *widget)
 	g_return_if_fail (container != NULL);
 	g_return_if_fail (IS_PANEL_WIDGET (container));
 	g_return_if_fail (widget != NULL);
+	g_return_if_fail (GTK_IS_WIDGET (widget));
 
 	panel_widget_add(PANEL_WIDGET(container),widget,0);
 	p = gtk_object_get_data(GTK_OBJECT(widget),
@@ -388,6 +365,7 @@ panel_widget_cremove(GtkContainer *container, GtkWidget *widget)
 	g_return_if_fail (container != NULL);
 	g_return_if_fail (IS_PANEL_WIDGET (container));
 	g_return_if_fail (widget != NULL);
+	g_return_if_fail (GTK_IS_WIDGET (widget));
 	
 	panel = PANEL_WIDGET (container);
 	
@@ -395,6 +373,9 @@ panel_widget_cremove(GtkContainer *container, GtkWidget *widget)
 	p = gtk_object_get_data(GTK_OBJECT(widget),
 				PANEL_APPLET_ASSOC_PANEL_KEY);
 
+	if(p)
+		run_up_forbidden(p,remove_panel_from_forbidden);
+
 	gtk_widget_ref(widget);
 	if (GTK_CONTAINER_CLASS (parent_class)->remove)
 		(* GTK_CONTAINER_CLASS (parent_class)->remove) (container,
@@ -407,9 +388,6 @@ panel_widget_cremove(GtkContainer *container, GtkWidget *widget)
 			g_list_remove (panel->no_window_applet_list, ad);
 	}
 
-	if(p)
-		run_up_forbidden(p,remove_panel_from_forbidden);
-
 	gtk_signal_emit(GTK_OBJECT(container),
 			panel_widget_signals[APPLET_REMOVED_SIGNAL],
 			widget);
@@ -421,6 +399,9 @@ panel_widget_cremove(GtkContainer *container, GtkWidget *widget)
 int
 panel_widget_get_applet_count(PanelWidget *panel)
 {
+	g_return_val_if_fail(panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),-1);
+
 	return g_list_length(GTK_FIXED(panel)->children);
 }
 
@@ -429,6 +410,9 @@ static GList *
 get_applet_list_pos(PanelWidget *panel, int pos)
 {
 	GList *list;
+
+	g_return_val_if_fail(panel!=NULL,NULL);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),NULL);
 	
 	for(list=panel->applet_list;list!=NULL;list=g_list_next(list)) {
 		AppletData *ad = list->data;
@@ -444,8 +428,12 @@ get_applet_list_pos(PanelWidget *panel, int pos)
 AppletData *
 get_applet_data_pos(PanelWidget *panel, int pos)
 {
-	GList *list = get_applet_list_pos(panel,pos);
-	if(list)
+	GList *list;
+
+	g_return_val_if_fail(panel!=NULL,NULL);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),NULL);
+	
+	if((list = get_applet_list_pos(panel,pos)))
 		return list->data;
 	return NULL;
 }
@@ -459,7 +447,9 @@ panel_widget_is_applet_stuck(PanelWidget *panel, GtkWidget *applet)
 	int i;
 
 	g_return_val_if_fail(panel!=NULL,FALSE);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),FALSE);
 	g_return_val_if_fail(applet!=NULL,FALSE);
+	g_return_val_if_fail(GTK_IS_WIDGET(applet),FALSE);
 
 	ad = gtk_object_get_data(GTK_OBJECT(applet), PANEL_APPLET_DATA);
 
@@ -484,10 +474,16 @@ panel_widget_is_applet_stuck(PanelWidget *panel, GtkWidget *applet)
 static void
 panel_widget_switch_applet_right(PanelWidget *panel, GList *list)
 {
-	AppletData *ad = list->data;
+	AppletData *ad;
 	AppletData *nad;
 	GList *nlist;
 
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(list!=NULL);
+	
+	ad = list->data;
+
 	nlist = g_list_next(list);
 	if(nlist)
 		nad = nlist->data;
@@ -512,10 +508,16 @@ panel_widget_switch_applet_right(PanelWidget *panel, GList *list)
 static void
 panel_widget_switch_applet_left(PanelWidget *panel, GList *list)
 {
-	AppletData *ad = list->data;
+	AppletData *ad;
 	AppletData *pad;
 	GList *nlist;
 
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(list!=NULL);
+	
+	ad = list->data;
+
 	nlist = g_list_previous(list);
 	if(nlist)
 		pad = nlist->data;
@@ -540,8 +542,15 @@ panel_widget_switch_applet_left(PanelWidget *panel, GList *list)
 static int
 panel_widget_get_right_switch_pos(PanelWidget *panel, GList *list)
 {
-	AppletData *ad = list->data;
+	AppletData *ad;
 	AppletData *nad;
+
+	g_return_val_if_fail(panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),-1);
+	g_return_val_if_fail(list!=NULL,-1);
+	
+	ad = list->data;
+
 	list = g_list_next(list);
 	if(list)
 		nad = list->data;
@@ -553,8 +562,15 @@ panel_widget_get_right_switch_pos(PanelWidget *panel, GList *list)
 static int
 panel_widget_get_left_switch_pos(PanelWidget *panel, GList *list)
 {
-	AppletData *ad = list->data;
+	AppletData *ad;
 	AppletData *pad;
+
+	g_return_val_if_fail(panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),-1);
+	g_return_val_if_fail(list!=NULL,-1);
+	
+	ad = list->data;
+
 	list = g_list_previous(list);
 	if(list)
 		pad = list->data;
@@ -573,6 +589,7 @@ panel_widget_switch_move(PanelWidget *panel, AppletData *ad, int moveby)
 
 	g_return_if_fail(ad!=NULL);
 	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
 
 	if(moveby==0)
 		return;
@@ -612,6 +629,10 @@ panel_widget_right_stick(PanelWidget *panel,int old_size)
 	int i,pos;
 	GList *list,*prev;
 	AppletData *ad;
+
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(old_size>=0);
 	
 	if(old_size>=panel->size ||
 	   panel->packed)
@@ -645,8 +666,15 @@ panel_widget_right_stick(PanelWidget *panel,int old_size)
 static void
 panel_widget_size_request(GtkWidget *widget, GtkRequisition *requisition)
 {
-	PanelWidget *panel = PANEL_WIDGET(widget);
+	PanelWidget *panel;
 	GList *list;
+
+	g_return_if_fail(widget!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(widget));
+	g_return_if_fail(requisition!=NULL);
+
+	panel = PANEL_WIDGET(widget);
+
 	requisition->height = 0;
 	requisition->width = 0;
 	if(panel->orient == PANEL_HORIZONTAL)
@@ -688,15 +716,180 @@ panel_widget_size_request(GtkWidget *widget, GtkRequisition *requisition)
 	}
 }
 
+void
+panel_widget_draw_all(PanelWidget *panel)
+{
+	GList *li;
+	GtkWidget *widget;
+	GdkGC *gc;
+
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	
+	if(!panel->pixmap) /*it will get drawn soon anyhow*/
+		return;
+
+	widget = GTK_WIDGET(panel);
+	
+	gc = widget->style->bg_gc[GTK_WIDGET_STATE(widget)];
+
+	if(widget->style->bg_pixmap[GTK_WIDGET_STATE(widget)]) {
+		gdk_gc_set_fill(gc, GDK_TILED);
+		gdk_gc_set_tile(gc, widget->style->bg_pixmap[GTK_WIDGET_STATE(widget)]);
+	}
+				
+	gdk_draw_rectangle(panel->pixmap,gc, TRUE, 0,0,-1,-1);
+
+	gdk_gc_set_fill(gc, GDK_SOLID);
+/*	gdk_gc_set_tile(gc, NULL); */
+	
+	for(li = panel->applet_list; li != NULL;
+	    li = g_list_next(li)) {
+		AppletData *ad = li->data;
+		if(IS_BUTTON_WIDGET(ad->applet))
+			button_widget_draw(BUTTON_WIDGET(ad->applet),
+					   panel->pixmap);
+	}
+	if(GTK_WIDGET_DRAWABLE(widget))
+		gdk_draw_pixmap(widget->window,
+				widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
+				panel->pixmap,
+				0,0,0,0,-1,-1);
+}
+
+void
+panel_widget_draw_icon(PanelWidget *panel, ButtonWidget *button)
+{
+	GtkWidget *widget;
+	GtkWidget *applet;
+	GdkGC *gc;
+	
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(button != NULL);
+	g_return_if_fail(IS_BUTTON_WIDGET(button));
+
+	if(!panel->pixmap) /*it will get drawn soon anyhow*/
+		return;
+
+	widget = GTK_WIDGET(panel);
+	applet = GTK_WIDGET(button);
+	
+	gc = widget->style->bg_gc[GTK_WIDGET_STATE(widget)];
+
+	if(widget->style->bg_pixmap[GTK_WIDGET_STATE(widget)]) {
+		gdk_gc_set_fill(gc, GDK_TILED);
+		gdk_gc_set_tile(gc, widget->style->bg_pixmap[GTK_WIDGET_STATE(widget)]);
+	}
+				
+	gdk_draw_rectangle(panel->pixmap,gc, TRUE,
+			   applet->allocation.x,applet->allocation.y,
+			   applet->allocation.width,applet->allocation.height);
+
+	gdk_gc_set_fill(gc, GDK_SOLID);
+/*	gdk_gc_set_tile(gc, NULL); */
+
+	button_widget_draw(button, panel->pixmap);
+
+	if(GTK_WIDGET_DRAWABLE(widget))
+		gdk_draw_pixmap(widget->window,
+				widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
+				panel->pixmap,
+				applet->allocation.x,applet->allocation.y,
+				applet->allocation.x,applet->allocation.y,
+				applet->allocation.width,applet->allocation.height);
+
+}
+
+static void
+panel_widget_draw(GtkWidget *widget, GdkRectangle *area)
+{
+	GList *li;
+	PanelWidget *panel;
+
+	g_return_if_fail(widget!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(widget));
+
+	panel = PANEL_WIDGET(widget);
+
+	if(!GTK_WIDGET_DRAWABLE(widget))
+		return;
+	if(panel->pixmap) {
+		gdk_draw_pixmap(widget->window,
+				widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
+				panel->pixmap,
+				area->x, area->y,
+				area->x, area->y,
+				area->width, area->height);
+	}
+	for(li = panel->applet_list;
+	    li != NULL;
+	    li = g_list_next(li)) {
+		AppletData *ad = li->data;
+		GdkRectangle ch_area;
+		if(!IS_BUTTON_WIDGET(ad->applet) &&
+		   gtk_widget_intersect(ad->applet, area, &ch_area))
+			gtk_widget_draw(ad->applet, &ch_area);
+	}
+}
+
+static int
+panel_widget_expose(GtkWidget *widget, GdkEventExpose *event)
+{
+	GList *li;
+	PanelWidget *panel;
+
+	g_return_val_if_fail(widget!=NULL,FALSE);
+	g_return_val_if_fail(IS_PANEL_WIDGET(widget),FALSE);
+	g_return_val_if_fail(event!=NULL,FALSE);
+
+	panel = PANEL_WIDGET(widget);
+
+	if(!GTK_WIDGET_DRAWABLE(widget))
+		return FALSE;
+	if(panel->pixmap) {
+		gdk_draw_pixmap(widget->window,
+				widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
+				panel->pixmap,
+				event->area.x, event->area.y,
+				event->area.x, event->area.y,
+				event->area.width, event->area.height);
+	}
+	for(li = panel->applet_list;
+	    li != NULL;
+	    li = g_list_next(li)) {
+		AppletData *ad = li->data;
+		GdkEventExpose ch_event = *event;
+
+		if(!IS_BUTTON_WIDGET(ad->applet) &&
+		   GTK_WIDGET_NO_WINDOW (ad->applet) &&
+		   gtk_widget_intersect (ad->applet, &event->area, 
+					 &ch_event.area))
+			gtk_widget_event (ad->applet, (GdkEvent*) &ch_event);
+	}
+
+	return FALSE;
+}
+
 static void
 panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 {
-	PanelWidget *panel = PANEL_WIDGET(widget);
+	PanelWidget *panel;
 	GList *list;
 	GList *send_move = NULL;
 	int i;
-	int old_size = panel->size;
+	int old_size;
+	int old_thick;
 
+	g_return_if_fail(widget!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(widget));
+	g_return_if_fail(allocation!=NULL);
+
+	panel = PANEL_WIDGET(widget);
+
+	old_size = panel->size;
+	old_thick = panel->thick;
+	
 	widget->allocation = *allocation;
 	if (GTK_WIDGET_REALIZED (widget))
 		gdk_window_move_resize (widget->window,
@@ -705,7 +898,6 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 					allocation->width, 
 					allocation->height);
 
-
 	if(panel->orient == PANEL_HORIZONTAL)
 		panel->size = allocation->width;
 	else
@@ -799,7 +991,9 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	else
 		panel->thick = allocation->width;
 
-	if(panel->fit_pixmap_bg && panel->back_type == PANEL_BACK_PIXMAP)
+	if(old_thick != panel->thick &&
+	   panel->fit_pixmap_bg &&
+	   panel->back_type == PANEL_BACK_PIXMAP)
 		panel_resize_pixmap(panel);
 
 	
@@ -810,6 +1004,22 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 				ad->applet);
 		send_move = my_g_list_pop_first(send_move);
 	}
+	
+	if (GTK_WIDGET_REALIZED (widget)) {
+		if(!panel->pixmap ||
+		   allocation->width != panel->pixw ||
+		   allocation->height != panel->pixh) {
+			if(panel->pixmap)
+				gdk_pixmap_unref(panel->pixmap);
+			panel->pixw = allocation->width;
+			panel->pixh = allocation->height;
+			panel->pixmap = gdk_pixmap_new(widget->window,
+						       panel->pixw,
+						       panel->pixh,
+						       gtk_widget_get_visual(widget)->depth);
+		}
+		panel_widget_draw_all(panel);
+	}
 }
 
 int
@@ -817,9 +1027,16 @@ panel_widget_is_cursor(PanelWidget *panel, int overlap)
 {
 	int x,y;
 	int w,h;
-	GtkWidget *widget = panel->drop_widget;
+	GtkWidget *widget;
+
+	g_return_val_if_fail(panel!=NULL,FALSE);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),FALSE);
+
+	widget = panel->drop_widget;
 	
-	if(!w || !GTK_WIDGET_VISIBLE(widget))
+	if(!widget ||
+	   !GTK_IS_WIDGET(widget) ||
+	   !GTK_WIDGET_VISIBLE(widget))
 		return FALSE;
 
 	gtk_widget_get_pointer(widget, &x, &y);
@@ -833,16 +1050,17 @@ panel_widget_is_cursor(PanelWidget *panel, int overlap)
 	return FALSE;
 }
 
-static void
-panel_widget_dnd_dropped_filename (GtkWidget *widget,
-				   GdkEventDropDataAvailable *event,
-				   PanelWidget *panel)
+void
+panel_widget_set_back_pixmap (PanelWidget *panel, char *file)
 {
-	if (panel_try_to_set_pixmap (panel, event->data)) {
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(file!=NULL);
+
+	if (panel_try_to_set_pixmap (panel, file)) {
 		if (panel->back_pixmap)
 			g_free (panel->back_pixmap);
-		panel->back_pixmap = g_strdup (event->data);
-		gtk_widget_queue_draw (widget);
+		panel->back_pixmap = g_strdup (file);
 		panel->back_type = PANEL_BACK_PIXMAP;
 		gtk_signal_emit(GTK_OBJECT(panel),
 				panel_widget_signals[BACK_CHANGE_SIGNAL],
@@ -857,13 +1075,16 @@ panel_try_to_set_default_back(PanelWidget *panel)
 {
 	GtkStyle *ns;
 
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+
 	ns = gtk_style_new();
 
 	gtk_style_ref(ns);
 	gtk_widget_set_style(GTK_WIDGET(panel), ns);
 	gtk_style_unref(ns);
 
-	gtk_widget_queue_draw(GTK_WIDGET(panel));
+	panel_widget_draw_all(panel);
 }
 
 static void
@@ -871,6 +1092,10 @@ panel_try_to_set_back_color(PanelWidget *panel, GdkColor *color)
 {
 	GtkStyle *ns;
 
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(color!=NULL);
+
 	ns = gtk_style_copy(GTK_WIDGET(panel)->style);
 	gtk_style_ref(ns);
 
@@ -887,44 +1112,24 @@ panel_try_to_set_back_color(PanelWidget *panel, GdkColor *color)
 
 	gtk_style_unref(ns);
 
-	gtk_widget_queue_draw(GTK_WIDGET(panel));
+	panel_widget_draw_all(panel);
 }
 
-static void
-panel_widget_dnd_dropped_color (GtkWidget *widget,
-				GdkEventDropDataAvailable *event,
-				PanelWidget *panel)
+void
+panel_widget_set_back_color(PanelWidget *panel, GdkColor *color)
 {
-	gdouble *dropped = (gdouble *)event->data;
-	GdkColor c;
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(color!=NULL);
 
-	c.red = (dropped[1]*65535);
-	c.green = (dropped[2]*65535);
-	c.blue = (dropped[3]*65535);
-	c.pixel = 0;
+	panel_try_to_set_back_color(panel, color);
 
-	panel_try_to_set_back_color(panel, &c);
-}
-
-static void
-panel_widget_dnd_drop_internal(GtkWidget *widget,
-			       GdkEventDropDataAvailable *event,
-			       gpointer data)
-{
-	PanelWidget *panel = data;
-	/* Test for the type that was dropped */
-	if (strcmp (event->data_type, "url:ALL") == 0) {
-		panel_widget_dnd_dropped_filename (widget, event, panel);
-	} else if(!strcmp(event->data_type, "application/x-color")) {
-		panel_widget_dnd_dropped_color(widget, event, panel);
-		panel->back_type = PANEL_BACK_COLOR;
-		gtk_signal_emit(GTK_OBJECT(panel),
-				panel_widget_signals[BACK_CHANGE_SIGNAL],
-				panel->back_type,
-				panel->back_pixmap,
-				&panel->back_color);
-	}
-	return;
+	panel->back_type = PANEL_BACK_COLOR;
+	gtk_signal_emit(GTK_OBJECT(panel),
+			panel_widget_signals[BACK_CHANGE_SIGNAL],
+			panel->back_type,
+			panel->back_pixmap,
+			&panel->back_color);
 }
 
 static void
@@ -935,6 +1140,9 @@ panel_resize_pixmap(PanelWidget *panel)
 	GtkStyle *ns;
 	int w, h;
 
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+
 	im = gtk_object_get_data(GTK_OBJECT(panel),"gdk_image");
 	if(!im) return;
 
@@ -976,6 +1184,9 @@ panel_try_to_set_pixmap (PanelWidget *panel, char *pixmap)
 	GdkPixmap *p;
 	GtkStyle *ns;
 
+	g_return_val_if_fail(panel!=NULL,FALSE);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),FALSE);
+
 	if(!pixmap || strcmp(pixmap,"")==0) {
 		ns = gtk_style_copy(GTK_WIDGET(panel)->style);
 		gtk_style_ref(ns);
@@ -988,15 +1199,17 @@ panel_try_to_set_pixmap (PanelWidget *panel, char *pixmap)
 		gtk_widget_set_style(GTK_WIDGET(panel), ns);
 	
 		gtk_style_unref(ns);
-		return 1;
+
+		panel_widget_draw_all(panel);
+		return TRUE;
 	}
 
 	if (!g_file_exists (pixmap))
-		return 0;
+		return FALSE;
 	
 	im = gdk_imlib_load_image (pixmap);
 	if (!im)
-		return 0;
+		return FALSE;
 
 	im2 = gtk_object_get_data(GTK_OBJECT(panel),"gdk_image");
 	if(im2) gdk_imlib_destroy_image (im2);
@@ -1035,13 +1248,20 @@ panel_try_to_set_pixmap (PanelWidget *panel, char *pixmap)
 	
 	gtk_style_unref(ns);
 	gtk_object_set_data(GTK_OBJECT(panel),"gdk_image",im);
-	return 1;
+	
+	panel_widget_draw_all(panel);
+	return TRUE;
 }
 
 static void
 panel_widget_realize(GtkWidget *w, gpointer data)
 {
-	PanelWidget *panel = PANEL_WIDGET(w);
+	PanelWidget *panel;
+
+	g_return_if_fail(w!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(w));
+
+	panel = PANEL_WIDGET(w);
 
 	if(panel->back_type == PANEL_BACK_PIXMAP) {
 		if (!panel_try_to_set_pixmap (panel, panel->back_pixmap))
@@ -1050,10 +1270,16 @@ panel_widget_realize(GtkWidget *w, gpointer data)
 		panel_try_to_set_back_color(panel, &panel->back_color);
 	}
 
-	gtk_widget_dnd_drop_set (GTK_WIDGET(panel), TRUE,
-				 image_drop_types,
-				 sizeof(image_drop_types)/sizeof(char *),
-				 FALSE);
+	if(panel->pixmap)
+		gdk_pixmap_unref(panel->pixmap);
+	panel->pixw = w->allocation.width;
+	panel->pixh = w->allocation.height;
+	panel->pixmap = gdk_pixmap_new(w->window,
+				       panel->pixw,
+				       panel->pixh,
+				       gtk_widget_get_visual(w)->depth);
+
+	panel_widget_draw_all(panel);
 }
 
 static int
@@ -1061,6 +1287,9 @@ panel_widget_destroy(GtkWidget *w, gpointer data)
 {
 	GdkImlibImage *im;
 
+	g_return_val_if_fail(w!=NULL,FALSE);
+	g_return_val_if_fail(IS_PANEL_WIDGET(w),FALSE);
+
 	im = gtk_object_get_data(GTK_OBJECT(w),"gdk_image");
 	if(im) gdk_imlib_destroy_image (im);
 	gtk_object_set_data(GTK_OBJECT(w),"gdk_image",NULL);
@@ -1073,8 +1302,13 @@ panel_widget_destroy(GtkWidget *w, gpointer data)
 
 static int panel_widget_applet_event(GtkWidget *widget, GdkEvent *event, gpointer data);
 
-static int is_in_widget(GdkEventButton *bevent, GtkWidget *widget)
+static int
+is_in_widget(GdkEventButton *bevent, GtkWidget *widget)
 {
+	g_return_val_if_fail(widget!=NULL,FALSE);
+	g_return_val_if_fail(GTK_IS_WIDGET(widget),FALSE);
+	g_return_val_if_fail(bevent!=NULL,FALSE);
+
 	if(bevent->x >= widget->allocation.x &&
 	   bevent->x < (widget->allocation.x + widget->allocation.width) &&
 	   bevent->y >= widget->allocation.y &&
@@ -1083,62 +1317,49 @@ static int is_in_widget(GdkEventButton *bevent, GtkWidget *widget)
 	return FALSE;
 }
 
-static GtkWidget *pressed_applet = NULL;
 static int
 panel_widget_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
-	PanelWidget *panel = PANEL_WIDGET(widget);
+	PanelWidget *panel;
 	GList *list;
-	GdkEventButton *bevent = (GdkEventButton *) event;
-	
-	if(event->type != GDK_BUTTON_PRESS &&
-	   event->type != GDK_BUTTON_RELEASE)
-		return FALSE;
+	GdkEventButton *bevent;
 
-	/*this would be a button release event and it would be right after
-	  a button press*/
-	if(pressed_applet) {
-		gtk_grab_remove(pressed_applet);
-		if(is_in_widget(bevent,pressed_applet)) {
-			gtk_signal_emit(GTK_OBJECT(panel),
-					panel_widget_signals[APPLET_CLICKED_SIGNAL],
-					pressed_applet);
-		}
-		pressed_applet = NULL;
-		return TRUE;
-	}
+	g_return_val_if_fail(widget!=NULL,FALSE);
+	g_return_val_if_fail(IS_PANEL_WIDGET(widget),FALSE);
+	g_return_val_if_fail(event!=NULL,FALSE);
+
+	panel = PANEL_WIDGET(widget);
+	bevent = (GdkEventButton *) event;
+
+	if((event->type != GDK_BUTTON_PRESS &&
+	    event->type != GDK_BUTTON_RELEASE) ||
+	   bevent->window != widget->window)
+		return FALSE;
 
 	for(list = panel->no_window_applet_list; list!=NULL;
 	    list = g_list_next(list)) {
 		AppletData *ad = list->data;
-		if(is_in_widget(bevent,ad->applet)) {
-			if(bevent->button != 1) {
-				return panel_widget_applet_event(ad->applet,
-								 event,data);
-			} else if(event->type == GDK_BUTTON_PRESS) {
-				int return_val = FALSE;
-				gtk_signal_emit(GTK_OBJECT(panel),
-						panel_widget_signals[APPLET_BUTTON1_SIGNAL],
-						ad->applet,&return_val);
-				
-				if(!return_val) {
-					pressed_applet = ad->applet;
-					gtk_grab_add(pressed_applet);
-				}
-			}
-		}
+		if(is_in_widget(bevent,ad->applet) &&
+		   bevent->button != 1)
+			return panel_widget_applet_event(ad->applet,
+							 event,data);
 	}
 	return FALSE;
 }
 
-
 static void
 panel_widget_init (PanelWidget *panel)
 {
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+
 	/*this makes the popup "pop down" once the button is released*/
 	gtk_widget_set_events(GTK_WIDGET(panel),
 			      gtk_widget_get_events(GTK_WIDGET(panel)) |
 			      GDK_BUTTON_RELEASE_MASK);
+	
+	panel->pixmap = NULL;
+	panel->pixw = panel->pixh = -1;
 
 	panel->back_type =PANEL_BACK_NONE;
 	panel->fit_pixmap_bg = FALSE;
@@ -1168,12 +1389,6 @@ panel_widget_init (PanelWidget *panel)
 			   GTK_SIGNAL_FUNC(panel_widget_event),
 			   NULL);
 
-	/* Ok, cool hack begins: drop image files on the panel */
-	gtk_signal_connect (GTK_OBJECT (panel),
-			    "drop_data_available_event",
-			    GTK_SIGNAL_FUNC (panel_widget_dnd_drop_internal),
-			    panel);
-	
 	panels = g_list_append(panels,panel);
 }
 
@@ -1243,15 +1458,20 @@ _panel_widget_applet_drag_start_no_grab(PanelWidget *panel, GtkWidget *applet)
 void
 panel_widget_applet_drag_start_no_grab(PanelWidget *panel, GtkWidget *applet)
 {
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(applet!=NULL);
+	g_return_if_fail(GTK_IS_WIDGET(panel));
+
 	panel_applet_in_drag = TRUE;
 	_panel_widget_applet_drag_start_no_grab(panel,applet);
 }
 
-void
+static void
 _panel_widget_applet_drag_end_no_grab(PanelWidget *panel)
 {
 #ifdef DEBUG
-  g_message("Ending drag\n");
+	g_message("Ending drag\n");
 #endif
 	panel->currently_dragged_applet = NULL;
 }
@@ -1259,6 +1479,9 @@ _panel_widget_applet_drag_end_no_grab(PanelWidget *panel)
 void
 panel_widget_applet_drag_end_no_grab(PanelWidget *panel)
 {
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+
 	_panel_widget_applet_drag_end_no_grab(panel);
 	panel_applet_in_drag = FALSE;
 }
@@ -1286,6 +1509,11 @@ _panel_widget_applet_drag_start(PanelWidget *panel, GtkWidget *applet)
 void
 panel_widget_applet_drag_start(PanelWidget *panel, GtkWidget *applet)
 {
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(applet!=NULL);
+	g_return_if_fail(GTK_IS_WIDGET(panel));
+
 	panel_applet_in_drag = TRUE;
 	_panel_widget_applet_drag_start(panel, applet);
 }
@@ -1302,16 +1530,39 @@ _panel_widget_applet_drag_end(PanelWidget *panel)
 void
 panel_widget_applet_drag_end(PanelWidget *panel)
 {
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+
 	_panel_widget_applet_drag_end(panel);
 	panel_applet_in_drag = FALSE;
 }
 
+/*get pos of the cursor location*/
+int
+panel_widget_get_cursorloc(PanelWidget *panel)
+{
+	int x,y;
+
+	g_return_val_if_fail(panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),-1);
+
+	gtk_widget_get_pointer(GTK_WIDGET(panel), &x, &y);
+
+	if(panel->orient == PANEL_HORIZONTAL)
+		return x;
+	else
+		return y;
+}
+
 /*calculates the value to move the applet by*/
 static int
 panel_widget_get_moveby(PanelWidget *panel, int pos)
 {
 	int x,y;
 
+	g_return_val_if_fail(panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),-1);
+
 	gtk_widget_get_pointer(GTK_WIDGET(panel), &x, &y);
 
 	if(panel->orient == PANEL_HORIZONTAL)
@@ -1324,6 +1575,9 @@ static GList *
 walk_up_to(int pos, GList *list)
 {
 	AppletData *ad = list->data;
+
+	g_return_val_if_fail(list!=NULL,NULL);
+
 	if(ad->pos <= pos && ad->pos+ad->cells > pos)
 		return list;
 	while(g_list_next(list) && ad->pos+ad->cells <= pos) {
@@ -1340,6 +1594,8 @@ walk_up_to(int pos, GList *list)
 static GtkWidget *
 is_in_applet(int pos, AppletData *ad)
 {
+	g_return_val_if_fail(ad!=NULL,NULL);
+
 	if(ad->pos <= pos && ad->pos+ad->cells > pos)
 		return ad->applet;
 	return NULL;
@@ -1355,6 +1611,10 @@ panel_widget_get_free_spot(PanelWidget *panel, AppletData *ad)
 	int right=-1,left=-1;
 	GList *list;
 
+	g_return_val_if_fail(panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),-1);
+	g_return_val_if_fail(ad!=NULL,-1);
+
 	gtk_widget_get_pointer(GTK_WIDGET(panel), &x, &y);
 
 	if(panel->orient == PANEL_HORIZONTAL)
@@ -1428,6 +1688,10 @@ ad->cells free at pos otherwise we will mess up the panel*/
 static void
 panel_widget_nice_move(PanelWidget *panel, AppletData *ad, int pos)
 {
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(ad!=NULL);
+
 	if(pos==ad->pos)
 		return;
 
@@ -1447,6 +1711,9 @@ panel_widget_nice_move(PanelWidget *panel, AppletData *ad, int pos)
 int
 panel_widget_applet_move_to_cursor(PanelWidget *panel)
 {
+	g_return_val_if_fail(panel!=NULL,FALSE);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),FALSE);
+
 	if (panel->currently_dragged_applet) {
 		int moveby;
 		int pos = panel->currently_dragged_applet->pos;
@@ -1520,12 +1787,18 @@ panel_widget_applet_move_to_cursor(PanelWidget *panel)
 static int
 move_timeout_handler(gpointer data)
 {
+	g_return_val_if_fail(data!=NULL,FALSE);
+	g_return_val_if_fail(IS_PANEL_WIDGET(data),FALSE);
+
 	return panel_widget_applet_move_to_cursor(PANEL_WIDGET(data));
 }
 
 void
 panel_widget_applet_move_use_idle(PanelWidget *panel)
 {
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+
 	gtk_timeout_add (30,move_timeout_handler,panel);
 }
 
@@ -1537,7 +1810,13 @@ panel_widget_applet_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 	PanelWidget *panel;
 	GdkEventButton *bevent;
 
-	panel = gtk_object_get_data(GTK_OBJECT(widget),PANEL_APPLET_PARENT_KEY);
+	g_return_val_if_fail(widget!=NULL,FALSE);
+	g_return_val_if_fail(GTK_IS_WIDGET(widget),FALSE);
+	g_return_val_if_fail(widget->parent!=NULL,FALSE);
+	g_return_val_if_fail(IS_PANEL_WIDGET(widget->parent),FALSE);
+	g_return_val_if_fail(event!=NULL,FALSE);
+
+	panel = PANEL_WIDGET(widget->parent);
 
 	g_return_val_if_fail(panel!=NULL,TRUE);
 
@@ -1577,6 +1856,9 @@ panel_widget_applet_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 static GtkWidget *
 listening_parent(GtkWidget *widget)
 {
+	g_return_val_if_fail(widget!=NULL,NULL);
+	g_return_val_if_fail(GTK_IS_WIDGET(widget),NULL);
+
 	if (GTK_WIDGET_NO_WINDOW(widget))
 		return listening_parent(widget->parent);
 
@@ -1586,6 +1868,10 @@ listening_parent(GtkWidget *widget)
 static int
 panel_sub_event_handler(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
+	g_return_val_if_fail(widget!=NULL,FALSE);
+	g_return_val_if_fail(GTK_IS_WIDGET(widget),FALSE);
+	g_return_val_if_fail(event!=NULL,FALSE);
+
 	switch (event->type) {
 		GdkEventButton *bevent;
 		/*pass these to the parent!*/
@@ -1609,6 +1895,9 @@ panel_sub_event_handler(GtkWidget *widget, GdkEvent *event, gpointer data)
 static void
 bind_applet_events(GtkWidget *widget, gpointer data)
 {
+	g_return_if_fail(widget!=NULL);
+	g_return_if_fail(GTK_IS_WIDGET(widget));
+
 	/* XXX: This is more or less a hack.  We need to be able to
 	 * capture events over applets so that we can drag them with
 	 * the mouse and such.  So we need to force the applet's
@@ -1629,30 +1918,36 @@ bind_applet_events(GtkWidget *widget, gpointer data)
 static int
 panel_widget_applet_destroy(GtkWidget *applet, gpointer data)
 {
-	PanelWidget *panel;
 	AppletData *ad;
 
-	panel = gtk_object_get_data(GTK_OBJECT(applet),PANEL_APPLET_PARENT_KEY);
-	g_return_val_if_fail(panel!=NULL,FALSE);
+	g_return_val_if_fail(applet!=NULL,FALSE);
+	g_return_val_if_fail(GTK_IS_WIDGET(applet),FALSE);
 
 	ad = gtk_object_get_data(GTK_OBJECT(applet), PANEL_APPLET_DATA);
 
-	if(panel->currently_dragged_applet == ad)
-		panel->currently_dragged_applet = NULL;
-	
-	panel->applet_list = g_list_remove(panel->applet_list,ad);
-	panel->no_window_applet_list =
-		g_list_remove (panel->no_window_applet_list, ad);
+	/*if it wasn't yet removed*/
+	if(applet->parent) {
+		PanelWidget *panel = PANEL_WIDGET(applet->parent);
+
+		if(panel->currently_dragged_applet == ad)
+			panel->currently_dragged_applet = NULL;
+
+		panel->applet_list = g_list_remove(panel->applet_list,ad);
+		panel->no_window_applet_list =
+			g_list_remove (panel->no_window_applet_list, ad);
+	}
 
 	g_free(ad);
 	return FALSE;
 }
 
 
-
 static void
 bind_top_applet_events(GtkWidget *widget, int bind_lower)
 {
+	g_return_if_fail(widget!=NULL);
+	g_return_if_fail(GTK_IS_WIDGET(widget));
+
 	gtk_signal_connect(GTK_OBJECT(widget), "destroy",
 			   GTK_SIGNAL_FUNC(panel_widget_applet_destroy),
 			   NULL);
@@ -1682,6 +1977,10 @@ panel_widget_find_empty_pos(PanelWidget *panel, int pos)
 	int right=-1,left=-1;
 	GList *list;
 
+	g_return_val_if_fail(panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),-1);
+	g_return_val_if_fail(pos>=0,-1);
+
 	if(pos>=panel->size)
 		pos = panel->size-1;
 
@@ -1722,6 +2021,9 @@ panel_widget_find_empty_pos(PanelWidget *panel, int pos)
 void
 panel_widget_add_forbidden(PanelWidget *panel)
 {
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+
 	add_panel_to_forbidden(panel,panel);
 }
 
@@ -1731,9 +2033,11 @@ panel_widget_add_full (PanelWidget *panel, GtkWidget *applet, int pos, int bind_
 	AppletData *ad = NULL;
 
 	g_return_val_if_fail(panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),-1);
 	g_return_val_if_fail(applet!=NULL,-1);
+	g_return_val_if_fail(GTK_IS_WIDGET(applet),-1);
 	g_return_val_if_fail(pos>=0,-1);
-
+	
 	ad = gtk_object_get_data(GTK_OBJECT(applet),PANEL_APPLET_DATA);
 
 	if(ad)
@@ -1753,16 +2057,6 @@ panel_widget_add_full (PanelWidget *panel, GtkWidget *applet, int pos, int bind_
 
 	if(pos==-1) return -1;
 
-	/*this will get done right on size allocate!*/
-	if(panel->orient == PANEL_HORIZONTAL)
-		gtk_fixed_put(GTK_FIXED(panel),applet,
-			      pos,0);
-	else
-		gtk_fixed_put(GTK_FIXED(panel),applet,
-			      0,pos);
-
-	gtk_object_set_data(GTK_OBJECT(applet),PANEL_APPLET_PARENT_KEY,panel);
-	
 	if(!ad) {
 		ad = g_new(AppletData,1);
 		ad->applet = applet;
@@ -1781,12 +2075,21 @@ panel_widget_add_full (PanelWidget *panel, GtkWidget *applet, int pos, int bind_
 		panel->no_window_applet_list =
 			g_list_prepend(panel->no_window_applet_list,ad);
 
+	/*this will get done right on size allocate!*/
+	if(panel->orient == PANEL_HORIZONTAL)
+		gtk_fixed_put(GTK_FIXED(panel),applet,
+			      pos,0);
+	else
+		gtk_fixed_put(GTK_FIXED(panel),applet,
+			      0,pos);
+
+
+	gtk_widget_queue_resize(GTK_WIDGET(panel));
+
 	gtk_signal_emit(GTK_OBJECT(panel),
 			panel_widget_signals[APPLET_ADDED_SIGNAL],
 			applet);
 	
-	gtk_widget_queue_resize(GTK_WIDGET(panel));
-
 	/*NOTE: forbidden list is not updated on addition, use the
 	function above for the panel*/
 
@@ -1803,8 +2106,11 @@ panel_widget_reparent (PanelWidget *old_panel,
 	AppletData *ad;
 
 	g_return_val_if_fail(old_panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(old_panel),-1);
 	g_return_val_if_fail(new_panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(new_panel),-1);
 	g_return_val_if_fail(applet!=NULL,-1);
+	g_return_val_if_fail(GTK_IS_WIDGET(applet),-1);
 	g_return_val_if_fail(pos>=0,-1);
 
 	ad = gtk_object_get_data(GTK_OBJECT(applet), PANEL_APPLET_DATA);
@@ -1812,16 +2118,8 @@ panel_widget_reparent (PanelWidget *old_panel,
 	
 	ad->pos = pos;
 
-/*this should work right I guess*/
-#if 1
 	/*reparent applet*/
 	gtk_widget_reparent(applet,GTK_WIDGET(new_panel));
-#else
-	gtk_widget_ref(applet);
-	gtk_container_remove(GTK_CONTAINER(old_panel),applet);
-	gtk_container_add(GTK_CONTAINER(new_panel),applet);
-	gtk_widget_unref(applet);
-#endif
 
 	return pos;
 }
@@ -1832,7 +2130,9 @@ panel_widget_move (PanelWidget *panel, GtkWidget *applet, int pos)
 	AppletData *ad;
 
 	g_return_val_if_fail(panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),-1);
 	g_return_val_if_fail(applet!=NULL,-1);
+	g_return_val_if_fail(GTK_IS_WIDGET(applet),-1);
 	g_return_val_if_fail(pos>=0,-1);
 
 	ad = gtk_object_get_data(GTK_OBJECT(applet), PANEL_APPLET_DATA);
@@ -1873,15 +2173,16 @@ panel_widget_get_pos(PanelWidget *panel, GtkWidget *applet)
 {
 	AppletData *ad;
 
-	g_return_val_if_fail(panel,-1);
-	g_return_val_if_fail(applet,-1);
+	g_return_val_if_fail(panel!=NULL,-1);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),-1);
+	g_return_val_if_fail(applet!=NULL,-1);
+	g_return_val_if_fail(GTK_IS_WIDGET(applet),-1);
 
 	ad = gtk_object_get_data(GTK_OBJECT(applet), PANEL_APPLET_DATA);
 
 	g_return_val_if_fail(ad,-1);
 
-	if(panel !=
-	   gtk_object_get_data(GTK_OBJECT(applet), PANEL_APPLET_PARENT_KEY))
+	if(panel != PANEL_WIDGET(applet->parent))
 		return -1;
 
 	return ad->pos;
@@ -1896,19 +2197,17 @@ panel_widget_change_params(PanelWidget *panel,
 			   GdkColor *back_color)
 {
 	PanelOrientation oldorient;
-	
 	int change_back = FALSE;
 
-	g_return_if_fail(panel);
-	g_return_if_fail(GTK_WIDGET_REALIZED(GTK_WIDGET(panel)));
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+	g_return_if_fail(GTK_WIDGET_REALIZED(panel));
 
 	oldorient = panel->orient;
 
 	panel->orient = orient;
 
 	if(oldorient != panel->orient) {
-		/*postpone all adjustments until fixed is size_allocated*/
-		/*panel->postpone_adjust = TRUE;*/
 	   	gtk_signal_emit(GTK_OBJECT(panel),
 	   			panel_widget_signals[ORIENT_CHANGE_SIGNAL],
 	   			panel->orient);
@@ -1954,6 +2253,7 @@ panel_widget_change_params(PanelWidget *panel,
 				panel->back_pixmap,
 				&panel->back_color);
 	}
+	gtk_widget_queue_resize(GTK_WIDGET(panel));
 }
 
 void
