@@ -1,5 +1,5 @@
 /* Gnome panel: panel widget
- * (C) 1997 the Free Software Foundation
+ * (C) 1997-1998 the Free Software Foundation
  *
  * Authors:  George Lebl
  */
@@ -12,6 +12,7 @@
 
 
 #include <gtk/gtk.h>
+#include "button-widget.h"
 
 BEGIN_GNOME_DECLS
 
@@ -21,7 +22,6 @@ BEGIN_GNOME_DECLS
 
 #define PANEL_MINIMUM_WIDTH 48
 
-#define PANEL_APPLET_PARENT_KEY "panel_applet_parent_key"
 #define PANEL_APPLET_ASSOC_PANEL_KEY "panel_applet_assoc_panel_key"
 #define PANEL_APPLET_FORBIDDEN_PANELS "panel_applet_forbidden_panels"
 #define PANEL_APPLET_DATA "panel_applet_data"
@@ -57,6 +57,10 @@ struct _AppletData
 struct _PanelWidget
 {
 	GtkFixed		fixed;
+	
+	
+	GdkPixmap		*pixmap;
+	int			pixw,pixh;
 
 	GList			*applet_list;
 	GList			*no_window_applet_list;
@@ -99,10 +103,6 @@ struct _PanelWidgetClass
 			      PanelBackType type,
 			      char *pixmap,
 			      GdkColor *color);
-	void (* applet_clicked) (PanelWidget *panel,
-				 GtkWidget *applet);
-	int (* applet_button1) (PanelWidget *panel,
-				GtkWidget *applet);
 };
 
 guint		panel_widget_get_type		(void);
@@ -112,7 +112,6 @@ GtkWidget *	panel_widget_new		(int packed,
 						 char *back_pixmap,
 						 int fit_pixmap_bg,
 						 GdkColor *back_color);
-
 /*add an applet to the panel, preferably at position pos*/
 int		panel_widget_add_full		(PanelWidget *panel,
 						 GtkWidget *applet,
@@ -171,12 +170,26 @@ void		panel_widget_change_global	(int explicit_step,
 						 int disable_animations,
 						 int applet_padding);
 
+void		panel_widget_set_back_pixmap	(PanelWidget *panel,
+						 char *file);
+void		panel_widget_set_back_color	(PanelWidget *panel,
+						 GdkColor *color);
+
+/*draw EVERYTHING (meaning icons)*/
+void		panel_widget_draw_all		(PanelWidget *panel);
+/*draw just one icon (applet has to be an icon of course)*/
+void		panel_widget_draw_icon		(PanelWidget *panel,
+						 ButtonWidget *applet);
+
+
 /*get the number of applets*/
 int		panel_widget_get_applet_count	(PanelWidget *panel);
 
 /*tells us if an applet is "stuck" on the right side*/
 int		panel_widget_is_applet_stuck	(PanelWidget *panel,
 						 GtkWidget *applet);
+/*get pos of the cursor location*/
+int		panel_widget_get_cursorloc	(PanelWidget *panel);
 
 /*needed for other panel types*/
 AppletData	*get_applet_data_pos		(PanelWidget *panel,
