@@ -9,6 +9,8 @@
 #include <config.h>
 #include <string.h>
 #include <signal.h>
+#include <unistd.h>
+#include <sys/stat.h>
 #include <sys/wait.h>
 #include <gnome.h>
 
@@ -52,8 +54,8 @@ extern GlobalConfig global_config;
   opened that menu whilethe user is looking over the choices*/
 extern PanelWidget *current_panel;
 
-/*a list of started extern applet child processes*/
-extern GList * children;
+/*the types of stuff we accept*/
+static char *panel_drop_types[] = {"url:ALL", "application/x-color"};
 
 /*get the default panel widget if the panel has more then one or
   just get the that one*/
@@ -79,8 +81,7 @@ get_lowest_level_master_pd(PanelWidget *panel)
 	PanelData *pd;
 
 	while(panel->master_widget)
-		panel = gtk_object_get_data(GTK_OBJECT(panel->master_widget),
-					    PANEL_APPLET_PARENT_KEY);
+		panel = PANEL_WIDGET(panel->master_widget->parent);
 	parent = gtk_object_get_data(GTK_OBJECT(panel),PANEL_PARENT);
 	g_return_val_if_fail(parent!=NULL,NULL);
 	
@@ -193,7 +194,7 @@ get_applet_orient(PanelWidget *panel)
 	return orient;
 }
 
-void
+static void
 change_window_cursor(GdkWindow *window, GdkCursorType cursor_type)
 {
 	GdkCursor *cursor = gdk_cursor_new(cursor_type);
@@ -313,8 +314,7 @@ back_change(int applet_id,
 			send_applet_change_back(ext->ior, info->applet_id,
 						panel->back_type,panel->back_pixmap,
 						&panel->back_color);
-	}
-	/*FIXME: probably set other backgrounds as well*/
+	} 
 }
 
 
@@ -335,6 +335,7 @@ panel_back_change(GtkWidget *widget,
 		  GdkColor *color)
 {
 	gtk_container_foreach(GTK_CONTAINER(widget),back_change_foreach,widget);
+
 	panels_to_sync = TRUE;
 	/*update the configuration box if it is displayed*/
 	update_config_back(PANEL_WIDGET(widget));
@@ -459,8 +460,7 @@ panel_applet_added_idle(gpointer data)
 {
 	int applet_id = GPOINTER_TO_INT(data);
 	AppletInfo *info = get_applet_info(applet_id);
-	PanelWidget *panel = gtk_object_get_data(GTK_OBJECT(info->widget),
-						 PANEL_APPLET_PARENT_KEY);
+	PanelWidget *panel = PANEL_WIDGET(info->widget->parent);
 
 	orientation_change(applet_id,panel);
 
@@ -498,6 +498,11 @@ panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 	}
 
 	gtk_idle_add(panel_applet_added_idle,GINT_TO_POINTER(applet_id));
+
+	/*we will need to save this applet's config now*/
+	if(g_list_find(applets_to_sync, GINT_TO_POINTER(applet_id))==NULL)
+		applets_to_sync = g_list_prepend(applets_to_sync,
+						 GINT_TO_POINTER(applet_id));
 }
 
 static void
@@ -538,94 +543,6 @@ panel_applet_removed(GtkWidget *widget, GtkWidget *applet, gpointer data)
 						 GINT_TO_POINTER(applet_id));
 }
 
-static void
-panel_menu_position (GtkMenu *menu, int *x, int *y, gpointer data)
-{
-	GtkWidget *w = data;
-	int wx, wy;
-
-	g_return_if_fail(w != NULL);
-
-	gdk_window_get_origin (w->window, &wx, &wy);
-
-	if(IS_DRAWER_WIDGET(w)) {
-		PanelWidget *panel = PANEL_WIDGET(DRAWER_WIDGET(w)->panel);
-		if(panel->orient==PANEL_VERTICAL) {
-			gtk_widget_get_pointer(w, NULL, y);
-			*x = wx + w->allocation.width;
-			*y += wy;
-		} else {
-			gtk_widget_get_pointer(w, x, NULL);
-			*x += wx;
-			*y = wy - GTK_WIDGET (menu)->allocation.height;
-		}
-	} else if(IS_SNAPPED_WIDGET(w)) {
-		switch(SNAPPED_WIDGET(w)->pos) {
-		case SNAPPED_BOTTOM:
-			gtk_widget_get_pointer(w, x, NULL);
-			*x += wx;
-			*y = wy - GTK_WIDGET (menu)->allocation.height;
-			break;
-		case SNAPPED_TOP:
-			gtk_widget_get_pointer(w, x, NULL);
-			*x += wx;
-			*y = wy + w->allocation.height;
-			break;
-		case SNAPPED_LEFT:
-			gtk_widget_get_pointer(w, NULL, y);
-			*x = wx + w->allocation.width;
-			*y += wy;
-			break;
-		case SNAPPED_RIGHT:
-			gtk_widget_get_pointer(w, NULL, y);
-			*x = wx - GTK_WIDGET (menu)->allocation.width;
-			*y += wy;
-			break;
-		}
-	} else if(IS_CORNER_WIDGET(w)) {
-		PanelWidget *panel = PANEL_WIDGET(CORNER_WIDGET(w)->panel);
-		if(panel->orient==PANEL_HORIZONTAL) {
-			switch(CORNER_WIDGET(w)->pos) {
-			case CORNER_NE:
-			case CORNER_NW:
-				gtk_widget_get_pointer(w, x, NULL);
-				*x += wx;
-				*y = wy + w->allocation.height;
-				break;
-			case CORNER_SE:
-			case CORNER_SW:
-				gtk_widget_get_pointer(w, x, NULL);
-				*x += wx;
-				*y = wy - GTK_WIDGET (menu)->allocation.height;
-				break;
-			}
-		} else { /*vertical*/
-			switch(CORNER_WIDGET(w)->pos) {
-			case CORNER_NE:
-			case CORNER_SE:
-				gtk_widget_get_pointer(w, NULL, y);
-				*x = wx - GTK_WIDGET (menu)->allocation.width;
-				*y += wy;
-				break;
-			case CORNER_SW:
-			case CORNER_NW:
-				gtk_widget_get_pointer(w, NULL, y);
-				*x = wx + w->allocation.width;
-				*y += wy;
-				break;
-			}
-		}
-	}
-
-	if(*x + GTK_WIDGET (menu)->allocation.width > gdk_screen_width())
-		*x=gdk_screen_width() - GTK_WIDGET (menu)->allocation.width;
-	if(*x < 0) *x =0;
-
-	if(*y + GTK_WIDGET (menu)->allocation.height > gdk_screen_height())
-		*y=gdk_screen_height() - GTK_WIDGET (menu)->allocation.height;
-	if(*y < 0) *y =0;
-}
-
 static void
 menu_deactivate(GtkWidget *w, GtkWidget *panel)
 {
@@ -784,7 +701,6 @@ panel_applet_move(GtkWidget *panel,GtkWidget *widget, gpointer data)
 						 GINT_TO_POINTER(applet_id));
 }
 
-
 static int
 panel_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
@@ -897,7 +813,6 @@ panel_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 	return FALSE;
 }
 
-
 static int
 panel_sub_event_handler(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
@@ -935,6 +850,64 @@ bind_panel_events(GtkWidget *widget, gpointer data)
 				       bind_panel_events, NULL);
 }
 
+static void
+panel_widget_dnd_drop_internal(GtkWidget *widget,
+			       GdkEventDropDataAvailable *event,
+			       gpointer data)
+{
+	PanelWidget *panel;
+
+	g_return_if_fail(widget!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(widget));
+	g_return_if_fail(event!=NULL);
+
+	panel = PANEL_WIDGET(widget);
+
+	/* Test for the type that was dropped */
+	if (strcmp (event->data_type, "url:ALL") == 0) {
+		char *file = event->data;
+		struct stat s;
+
+		/*if we can't stat this file don't even bother loading it*/
+		if(stat(file,&s)==0) {
+			char *p = strrchr(file,'.');
+			int pos = panel_widget_get_cursorloc(panel);
+			if(S_ISDIR(s.st_mode)) /*add a menu*/
+				load_menu_applet(file,MAIN_MENU_BOTH,
+						 panel,pos);
+			else if(p && strcmp(p,".desktop")==0)
+				load_launcher_applet(file,panel,pos);
+			else if(S_IEXEC & s.st_mode) /*executable?*/
+				ask_about_launcher(file,panel,pos);
+			else /*if all else fails it might be a pixmap*/
+				panel_widget_set_back_pixmap (panel, file);
+		}
+	} else if(!strcmp(event->data_type, "application/x-color")) {
+		gdouble *dropped;
+		GdkColor c;
+
+		dropped = (gdouble *)event->data;
+
+		c.red = (dropped[1]*65535);
+		c.green = (dropped[2]*65535);
+		c.blue = (dropped[3]*65535);
+		c.pixel = 0;
+
+		panel_widget_set_back_color(panel, &c);
+	}
+}
+
+static void
+panelw_realize(PanelWidget *panel, gpointer data)
+{
+	g_return_if_fail(panel!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(panel));
+
+	gtk_widget_dnd_drop_set (GTK_WIDGET(panel), TRUE,
+				 panel_drop_types,
+				 sizeof(panel_drop_types)/sizeof(char *),
+				 FALSE);
+}
 
 static void
 panel_widget_setup(PanelWidget *panel)
@@ -955,6 +928,16 @@ panel_widget_setup(PanelWidget *panel)
 			   "back_change",
 			   GTK_SIGNAL_FUNC(panel_back_change),
 			   NULL);
+	gtk_signal_connect_after(GTK_OBJECT(panel),
+				 "realize",
+				 GTK_SIGNAL_FUNC(panelw_realize),
+				 NULL);
+
+	/* Ok, cool hack begins: drop image files on the panel */
+	gtk_signal_connect (GTK_OBJECT (panel),
+			    "drop_data_available_event",
+			    GTK_SIGNAL_FUNC (panel_widget_dnd_drop_internal),
+			    NULL);
 }
 
 void
@@ -1118,3 +1101,18 @@ send_state_change(void)
 					    NULL);
 	}
 }
+
+/* Destroy all panels - called upon exit */
+void
+destroy_all_panels(void)
+{
+	GList *list = panel_list;
+	while (list) {
+		PanelData *pd = list->data;
+		GList *tmp = list->next;
+		gtk_widget_destroy (pd->panel);
+		list = tmp;
+	}
+	g_list_free (panel_list);
+	panel_list = NULL;
+}
