@@ -25,6 +25,7 @@ struct _PerPanelConfig {
 	/*snapped types*/
 	SnappedPos		snapped_pos;
 	SnappedMode		snapped_mode;
+	int			snapped_hidebuttons;
 	
 	/*corner types*/
 	CornerPos		corner_pos;
@@ -48,7 +49,7 @@ struct _PerPanelConfig {
 	GtkWidget		*non;
 	GtkWidget		*pix;
 	GtkWidget		*col;
-	GnomeColorSelector	*backsel;
+	GtkWidget		*backsel;
 };
 
 static GList *ppconfigs=NULL;
@@ -135,11 +136,11 @@ update_config_back(PanelWidget *pw)
 					    TRUE);
 		break;
 	case PANEL_BACK_COLOR:
-		gnome_color_selector_set_color_int(ppc->backsel,
-			pw->back_color.red,
-			pw->back_color.green,
-			pw->back_color.blue,
-			65355);
+		gnome_color_picker_set_i16(GNOME_COLOR_PICKER(ppc->backsel),
+					   pw->back_color.red,
+					   pw->back_color.green,
+					   pw->back_color.blue,
+					   65535);
 		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->col),
 					    TRUE);
 		break;
@@ -180,6 +181,7 @@ config_apply (GtkWidget *widget, int page, gpointer data)
 					     ppc->snapped_pos,
 					     ppc->snapped_mode,
 					     SNAPPED_WIDGET(ppc->panel)->state,
+					     ppc->snapped_hidebuttons,
 					     ppc->back_type,
 					     ppc->back_pixmap,
 					     ppc->fit_pixmap_bg,
@@ -206,6 +208,48 @@ config_apply (GtkWidget *widget, int page, gpointer data)
 	gtk_widget_queue_draw (ppc->panel);
 }
 
+/*thy evil easter egg*/
+static int
+config_event(GtkWidget *widget,GdkEvent *event,GtkNotebook *nbook)
+{
+	GtkWidget *w;
+	char *file;
+	static int clicks=0;
+	static int pages=0;
+	GdkEventButton *bevent;
+	
+	if(event->type != GDK_BUTTON_PRESS)
+		return FALSE;
+	
+	bevent = (GdkEventButton *)event;
+	if(bevent->button != 3)
+		clicks = 0;
+	else
+		clicks++;
+	
+	if(clicks<3)
+		return FALSE;
+	clicks = 0;
+	
+	if(pages==0) {
+		file = gnome_unconditional_pixmap_file("gnome-gegl.png");
+		if (file && g_file_exists (file)) {
+			w = gnome_pixmap_new_from_file (file);
+			gtk_widget_show(w);
+			/*the GEGL shall not be translated*/
+			gtk_notebook_append_page (nbook, w,
+						  gtk_label_new ("GEGL"));
+			gtk_notebook_set_page(nbook,-1);
+			pages = 1;
+		}
+		g_free(file);
+	} else {
+			gtk_notebook_set_page(nbook,-1);
+	}
+	return FALSE;
+}
+
+
 static void
 snapped_set_pos (GtkWidget *widget, gpointer data)
 {
@@ -220,6 +264,16 @@ snapped_set_pos (GtkWidget *widget, gpointer data)
 		gnome_property_box_changed (GNOME_PROPERTY_BOX (ppc->config_window));
 }
 
+static void
+snapped_set_hidebuttons (GtkWidget *widget, gpointer data)
+{
+	PerPanelConfig *ppc = gtk_object_get_user_data(GTK_OBJECT(widget));
+
+	ppc->snapped_hidebuttons = !(GTK_TOGGLE_BUTTON(widget)->active);
+	if (ppc->register_changes)
+		gnome_property_box_changed (GNOME_PROPERTY_BOX (ppc->config_window));
+}
+
 static void
 snapped_set_mode (GtkWidget *widget, gpointer data)
 {
@@ -357,6 +411,16 @@ snapped_notebook_page(PerPanelConfig *ppc)
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
+	/* Auto-hide */
+	button = gtk_check_button_new_with_label (_("Disable hidebuttons"));
+	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
+	if (!ppc->snapped_hidebuttons)
+		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
+			    GTK_SIGNAL_FUNC (snapped_set_hidebuttons), NULL);
+	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
+			    CONFIG_PADDING_SIZE);
+
 	return (hbox);
 }
 
@@ -537,16 +601,13 @@ set_fit_pixmap_bg (GtkToggleButton *toggle, gpointer data)
 }
 
 static void
-color_changed_cb(GnomeColorSelector *sel, gpointer data)
+color_set_cb(GtkWidget *w, int r, int g, int b, int a, gpointer data)
 {
- 	int r,g,b;
 	PerPanelConfig *ppc = data;
 
-        gnome_color_selector_get_color_int(sel,&r,&g,&b, 65355);
-
 	ppc->back_color.red = r;
 	ppc->back_color.green = g;
-	ppc->back_color.blue =b;
+	ppc->back_color.blue = b;
 	
 	if (ppc->register_changes)
 		gnome_property_box_changed (GNOME_PROPERTY_BOX (ppc->config_window));
@@ -688,15 +749,16 @@ background_page (PerPanelConfig *ppc)
 	gtk_container_border_width(GTK_CONTAINER (box), CONFIG_PADDING_SIZE);
 	gtk_container_add (GTK_CONTAINER (f), box);
 
-	ppc->backsel = gnome_color_selector_new(color_changed_cb, ppc);
-        gnome_color_selector_set_color_int(ppc->backsel,
-		ppc->back_color.red,
-		ppc->back_color.green,
-		ppc->back_color.blue,
-		65355);
+	ppc->backsel = gnome_color_picker_new();
+	gtk_signal_connect(GTK_OBJECT(ppc->backsel),"color_set",
+			   GTK_SIGNAL_FUNC(color_set_cb), ppc);
+        gnome_color_picker_set_i16(GNOME_COLOR_PICKER(ppc->backsel),
+				   ppc->back_color.red,
+				   ppc->back_color.green,
+				   ppc->back_color.blue,
+				   65535);
 
-	gtk_box_pack_start (GTK_BOX (box),
-			    gnome_color_selector_get_button (ppc->backsel),
+	gtk_box_pack_start (GTK_BOX (box), ppc->backsel,
 			    FALSE, FALSE, CONFIG_PADDING_SIZE);
 
 	gtk_signal_connect (GTK_OBJECT (ppc->non), "toggled", 
@@ -744,6 +806,7 @@ panel_config(GtkWidget *panel)
 		PanelWidget *pw = PANEL_WIDGET(SNAPPED_WIDGET(panel)->panel);
 		ppc->snapped_pos = snapped->pos;
 		ppc->snapped_mode = snapped->mode;
+		ppc->snapped_hidebuttons = snapped->hidebuttons_enabled;
 		ppc->fit_pixmap_bg = pw->fit_pixmap_bg;
 		ppc->back_pixmap = g_strdup(pw->back_pixmap);
 		ppc->back_color = pw->back_color;
@@ -769,6 +832,9 @@ panel_config(GtkWidget *panel)
 	
 	/* main window */
 	ppc->config_window = gnome_property_box_new ();
+	gtk_widget_set_events(ppc->config_window,
+			      gtk_widget_get_events(ppc->config_window) |
+			      GDK_BUTTON_PRESS_MASK);
 	/*gtk_window_position(GTK_WINDOW(ppc->config_window), GTK_WIN_POS_CENTER);*/
 	gtk_window_set_policy(GTK_WINDOW(ppc->config_window), FALSE, FALSE, TRUE);
 
@@ -812,6 +878,9 @@ panel_config(GtkWidget *panel)
 	
 	gtk_signal_connect (GTK_OBJECT (ppc->config_window), "apply",
 			    GTK_SIGNAL_FUNC (config_apply), ppc);
+	gtk_signal_connect (GTK_OBJECT (ppc->config_window), "event",
+			    GTK_SIGNAL_FUNC (config_event),
+			    prop_nbook);
 	
 	ppc->register_changes = TRUE;
 
