@@ -1,4 +1,5 @@
 #include "panel-widget.h"
+#include "panel-types.h"
 
 #ifndef PANEL_CONFIG_GLOBAL_H
 #define PANEL_CONFIG_GLOBAL_H
@@ -12,13 +13,18 @@ struct _GlobalConfig {
 	int minimize_delay;
 	int tooltips_enabled;
 	int show_small_icons;
+	int show_dot_buttons;
 	int prompt_for_logout;
 	PanelMovementType movement_type;
 	int disable_animations;
 	int applet_padding;
+	int tiles_enabled;
+	char *tile_up[LAST_TILE];
+	char *tile_down[LAST_TILE];
+	int tile_border[LAST_TILE];
+	int tile_depth[LAST_TILE];
 };
 
-
 void panel_config_global(void);
 
 #endif /* PANEL_CONFIG_H */
