@@ -27,18 +27,7 @@ extern GtkTooltips *panel_tooltips;
 
 extern GnomeClient *client;
 
-GlobalConfig global_config = {
-		DEFAULT_AUTO_HIDE_STEP_SIZE,
-		DEFAULT_EXPLICIT_HIDE_STEP_SIZE,
-		DEFAULT_MINIMIZED_SIZE,
-		DEFAULT_MINIMIZE_DELAY,
-		TRUE, /*tooltips*/
-		TRUE, /*show small icons*/
-		TRUE, /*logout question*/
-		PANEL_SWITCH_MOVE,
-		FALSE, /*disable anims*/
-		3 /*applet padding*/
-	};
+GlobalConfig global_config;
 
 char *panel_cfg_path=NULL;
 char *old_panel_cfg_path=NULL;
@@ -46,31 +35,32 @@ char *old_panel_cfg_path=NULL;
 /*list of all panel widgets created*/
 extern GList *panel_list;
 
-/*a list of started extern applet child processes*/
-extern GList * children;
-
 /*send the tooltips state to all external applets*/
 static void
 send_tooltips_state(int enabled)
 {
-	GList *list;
-	
-	for(list = children;list!=NULL;list = g_list_next(list)) {
-		AppletChild *child = list->data;
-		AppletInfo *info = get_applet_info(child->applet_id);
-		Extern *ext = info->data;
-		g_assert(ext);
-		/*if it's not set yet, don't send it, it will be sent when
-		  the ior is discovered anyhow, so this would be redundant
-		  anyway*/
-		if(ext->ior)
-			send_applet_tooltips_state(ext->ior,enabled);
+	AppletInfo *info;
+	int i;
+
+	for(i=0,info=(AppletInfo *)applets->data;
+	    i<applet_count;
+	    i++,info++) {
+		if(info->type == APPLET_EXTERN) {
+			Extern *ext = info->data;
+			g_assert(ext);
+			/*if it's not set yet, don't send it, it will be sent
+			  when the ior is discovered anyhow, so this would be
+			  redundant anyway*/
+			if(ext->ior)
+				send_applet_tooltips_state(ext->ior,i,enabled);
+		}
 	}
 }
 
 void
 apply_global_config(void)
 {
+	int i;
 	panel_widget_change_global(global_config.explicit_hide_step_size,
 				   global_config.auto_hide_step_size,
 				   global_config.drawer_step_size,
@@ -84,7 +74,15 @@ apply_global_config(void)
 	else
 		gtk_tooltips_disable(panel_tooltips);
 	set_show_small_icons();
+	set_show_dot_buttons();
 	send_tooltips_state(global_config.tooltips_enabled);
+	button_widget_tile_enable(global_config.tiles_enabled);
+	for(i=0;i<LAST_TILE;i++) {
+		button_widget_load_tile(i, global_config.tile_up[i],
+					global_config.tile_down[i],
+					global_config.tile_border[i],
+					global_config.tile_depth[i]);
+	}
 }
 
 /*shouldn't this be in gnome-dentry?? :)*/
@@ -159,8 +157,7 @@ save_applet_configuration(int num)
 		return;
 	}
 
-	panel = gtk_object_get_data(GTK_OBJECT(info->widget),
-				    PANEL_APPLET_PARENT_KEY);
+	panel = PANEL_WIDGET(info->widget->parent);
 	ad = gtk_object_get_data(GTK_OBJECT(info->widget),PANEL_APPLET_DATA);
 
 	if((panel_num = g_list_index(panels,panel)) == -1) {
@@ -303,6 +300,8 @@ save_panel_configuration(gpointer data, gpointer user_data)
 		gnome_config_set_int("pos", snapped->pos);
 		gnome_config_set_int("mode", snapped->mode);
 		gnome_config_set_int("state", snapped->state);
+		gnome_config_set_bool("hidebuttons_enabled",
+				      snapped->hidebuttons_enabled);
 		break;
 		}
 	case CORNER_PANEL:
@@ -366,7 +365,7 @@ do_session_save(GnomeClient *client,
 		gnome_client_set_discard_command (client, 3, new_args);
 	}
 	
-	printf("Saving to [%s]\n",panel_cfg_path);
+	/*DEBUG*/printf("Saving to [%s]\n",panel_cfg_path);
 
 	/*take out the trailing / then call the clean_file function,
 	  otherwise it will make runaway directories*/
@@ -381,11 +380,9 @@ do_session_save(GnomeClient *client,
 		for(i=0;i<applet_count;i++)
 			save_applet_configuration(i);
 	} else {
-		while(sync_applets) {
-			save_applet_configuration(GPOINTER_TO_INT(sync_applets->data));
-			sync_applets = g_list_remove_link(sync_applets,
-							  sync_applets);
-		}
+		GList *li;
+		for(li = sync_applets; li!=NULL; li=g_list_next(li))
+			save_applet_configuration(GPOINTER_TO_INT(li->data));
 	}
 	/*DEBUG*/printf(" 2"); fflush(stdout);
 
@@ -393,7 +390,7 @@ do_session_save(GnomeClient *client,
 	gnome_config_push_prefix (buf);
 	g_free(buf);
 
-	if(complete_sync)
+	if(complete_sync || sync_applets)
 		gnome_config_set_int ("applet_count", applet_count);
 	/*DEBUG*/printf(" 3"); fflush(stdout);
 	if(complete_sync || sync_panels) {
@@ -421,12 +418,27 @@ do_session_save(GnomeClient *client,
 				      global_config.tooltips_enabled);
 		gnome_config_set_bool("show_small_icons",
 				      global_config.show_small_icons);
+		gnome_config_set_bool("show_dot_buttons",
+				      global_config.show_dot_buttons);
 		gnome_config_set_bool("prompt_for_logout",
 				      global_config.prompt_for_logout);
 		gnome_config_set_bool("disable_animations",
 				      global_config.disable_animations);
 		gnome_config_set_int("applet_padding",
 				     global_config.applet_padding);
+		gnome_config_set_bool("tiles_enabled",
+				      global_config.tiles_enabled);
+		for(i=0;i<LAST_TILE;i++) {
+			char buf[256];
+			g_snprintf(buf,256,"tile_up_%d",i);
+			gnome_config_set_string(buf,global_config.tile_up[i]);
+			g_snprintf(buf,256,"tile_down_%d",i);
+			gnome_config_set_string(buf,global_config.tile_down[i]);
+			g_snprintf(buf,256,"tile_border_%d",i);
+			gnome_config_set_int(buf,global_config.tile_border[i]);
+			g_snprintf(buf,256,"tile_depth_%d",i);
+			gnome_config_set_int(buf,global_config.tile_depth[i]);
+		}
 	}
 
 	gnome_config_pop_prefix ();
@@ -489,16 +501,15 @@ panel_session_die (GnomeClient *client,
 	    i<applet_count;
 	    i++,info++) {
 		if(info->type == APPLET_EXTERN) {
-			gtk_container_remove(GTK_CONTAINER(info->applet_widget->parent),
-					     info->applet_widget);
+			gtk_widget_destroy(info->widget);
 		} else if(info->type == APPLET_SWALLOW) {
 			Swallow *swallow = info->data;
-			XKillClient(GDK_DISPLAY(),
-				    GDK_WINDOW_XWINDOW(GTK_SOCKET(swallow->socket)->plug_window));
+			if(GTK_SOCKET(swallow->socket)->plug_window)
+				XKillClient(GDK_DISPLAY(),
+					    GDK_WINDOW_XWINDOW(GTK_SOCKET(swallow->socket)->plug_window));
 		}
 	}
 			
-	
 	/*clean up corba stuff*/
 	panel_corba_clean_up();
 	
@@ -709,6 +720,7 @@ init_user_panels(void)
 		panel = snapped_widget_new(SNAPPED_BOTTOM,
 					   SNAPPED_EXPLICIT_HIDE,
 					   SNAPPED_SHOWN,
+					   TRUE,
 					   PANEL_BACK_NONE,
 					   NULL,
 					   TRUE,
@@ -729,7 +741,8 @@ init_user_panels(void)
 		GdkColor back_color = {0,0,0,1};
 		int fit_pixmap_bg;
 
-		g_snprintf(buf,256,"%spanel/Panel_%d/", old_panel_cfg_path, num);
+		g_snprintf(buf,256,"%spanel/Panel_%d/",
+			   old_panel_cfg_path, num);
 		gnome_config_push_prefix (buf);
 		
 		back_pixmap = gnome_config_get_string ("backpixmap=");
@@ -757,6 +770,7 @@ init_user_panels(void)
 				SnappedPos pos;
 				SnappedMode mode;
 				SnappedState state;
+				int hidebuttons_enabled;
 
 				g_snprintf(buf,256,"pos=%d", SNAPPED_BOTTOM);
 				pos=gnome_config_get_int(buf);
@@ -766,10 +780,14 @@ init_user_panels(void)
 
 				g_snprintf(buf,256,"state=%d", SNAPPED_SHOWN);
 				state=gnome_config_get_int(buf);
-				
+
+				hidebuttons_enabled =
+					gnome_config_get_bool("hidebuttons_enabled=TRUE");
+
 				panel = snapped_widget_new(pos,
 							   mode,
 							   state,
+							   hidebuttons_enabled,
 							   back_type,
 							   back_pixmap,
 							   fit_pixmap_bg,
@@ -820,7 +838,7 @@ init_user_panels(void)
 							  &back_color);
 				break;
 			}
-		default: break;
+		default: panel=NULL; break; /*fix warning*/
 		}
 
 		gnome_config_pop_prefix ();
@@ -830,9 +848,7 @@ init_user_panels(void)
 
 		panel_setup(panel);
 
-		if(!IS_DRAWER_WIDGET(panel) ||
-		   DRAWER_WIDGET(panel)->state ==  DRAWER_SHOWN)
-			gtk_widget_show(panel);
+		gtk_widget_show(panel);
 	}
 }
 
@@ -840,6 +856,8 @@ void
 load_up_globals(void)
 {
 	char buf[256];
+	char *tile_def[]={"normal","purple","green"};
+	int i;
 
 	/*set up global options*/
 	
@@ -851,6 +869,9 @@ load_up_globals(void)
 
 	global_config.show_small_icons =
 		gnome_config_get_bool("show_small_icons=TRUE");
+
+	global_config.show_dot_buttons =
+		gnome_config_get_bool("show_dot_buttons=TRUE");
 		
 	global_config.prompt_for_logout =
 		gnome_config_get_bool("prompt_for_logout=TRUE");
@@ -880,6 +901,26 @@ load_up_globals(void)
 	global_config.movement_type=gnome_config_get_int(buf);
 
 	global_config.applet_padding=gnome_config_get_int("applet_padding=3");
+
+	global_config.tiles_enabled =
+		gnome_config_get_bool("tiles_enabled=TRUE");
+	
+	for(i=0;i<LAST_TILE;i++) {
+		g_free(global_config.tile_up[i]);
+		g_snprintf(buf,256,"tile_up_%d=tiles/tile-%s-up.png",
+			   i, tile_def[i]);
+		global_config.tile_up[i] = gnome_config_get_string(buf);
+
+		g_free(global_config.tile_down[i]);
+		g_snprintf(buf,256,"tile_down_%d=tiles/tile-%s-down.png",
+			   i,tile_def[i]);
+		global_config.tile_down[i] = gnome_config_get_string(buf);
+
+		g_snprintf(buf,256,"tile_border_%d=2",i);
+		global_config.tile_border[i] = gnome_config_get_int(buf);
+		g_snprintf(buf,256,"tile_depth_%d=2",i);
+		global_config.tile_depth[i] = gnome_config_get_int(buf);
+	}
 		
 	gnome_config_pop_prefix();
 
