@@ -132,6 +132,7 @@ snapped_widget_size_request(GtkWidget *widget,
 			    GtkRequisition *requisition)
 {
 	SnappedWidget *snapped = SNAPPED_WIDGET(widget);
+
 	if(snapped_widget_request_cube) {
 		requisition->width = 48;
 		requisition->height = 48;
@@ -638,12 +639,19 @@ snapped_leave_notify(SnappedWidget *snapped,
 static void
 snapped_widget_set_hidebuttons(SnappedWidget *snapped)
 {
-	if(PANEL_WIDGET(snapped->panel)->orient == PANEL_HORIZONTAL) {
+	/*hidebuttons are disabled*/
+	if(!snapped->hidebuttons_enabled) {
+		gtk_widget_hide(snapped->hidebutton_n);
+		gtk_widget_hide(snapped->hidebutton_e);
+		gtk_widget_hide(snapped->hidebutton_w);
+		gtk_widget_hide(snapped->hidebutton_s);
+	/* horizontal and enabled */
+	} else if(PANEL_WIDGET(snapped->panel)->orient == PANEL_HORIZONTAL) {
 		gtk_widget_hide(snapped->hidebutton_n);
 		gtk_widget_show(snapped->hidebutton_e);
 		gtk_widget_show(snapped->hidebutton_w);
 		gtk_widget_hide(snapped->hidebutton_s);
-	} else {
+	} else { /*vertical*/
 		gtk_widget_show(snapped->hidebutton_n);
 		gtk_widget_hide(snapped->hidebutton_e);
 		gtk_widget_hide(snapped->hidebutton_w);
@@ -708,7 +716,7 @@ snapped_widget_init (SnappedWidget *snapped)
 	/*EAST*/
 	snapped->hidebutton_e =
 		make_hidebutton(snapped,
-				"panel-arrow-left.xpm",
+				"panel-arrow-left.png",
 				GTK_SIGNAL_FUNC(snapped_show_hide_right),
 				TRUE);
 	gtk_table_attach(GTK_TABLE(snapped->table),snapped->hidebutton_e,
@@ -716,7 +724,7 @@ snapped_widget_init (SnappedWidget *snapped)
 	/*NORTH*/
 	snapped->hidebutton_n =
 		make_hidebutton(snapped,
-				"panel-arrow-up.xpm",
+				"panel-arrow-up.png",
 				GTK_SIGNAL_FUNC(snapped_show_hide_right),
 				FALSE);
 	gtk_table_attach(GTK_TABLE(snapped->table),snapped->hidebutton_n,
@@ -724,7 +732,7 @@ snapped_widget_init (SnappedWidget *snapped)
 	/*WEST*/
 	snapped->hidebutton_w =
 		make_hidebutton(snapped,
-				"panel-arrow-right.xpm",
+				"panel-arrow-right.png",
 				GTK_SIGNAL_FUNC(snapped_show_hide_left),
 				TRUE);
 	gtk_table_attach(GTK_TABLE(snapped->table),snapped->hidebutton_w,
@@ -732,7 +740,7 @@ snapped_widget_init (SnappedWidget *snapped)
 	/*SOUTH*/
 	snapped->hidebutton_s =
 		make_hidebutton(snapped,
-				"panel-arrow-down.xpm",
+				"panel-arrow-down.png",
 				GTK_SIGNAL_FUNC(snapped_show_hide_left),
 				FALSE);
 	gtk_table_attach(GTK_TABLE(snapped->table),snapped->hidebutton_s,
@@ -751,6 +759,7 @@ snapped_widget_init (SnappedWidget *snapped)
 	snapped->pos = SNAPPED_BOTTOM;
 	snapped->mode = SNAPPED_EXPLICIT_HIDE;
 	snapped->state = SNAPPED_SHOWN;
+	snapped->hidebuttons_enabled = TRUE;
 
 	snapped->leave_notify_timer_tag = 0;
 	snapped->autohide_inhibit = FALSE;
@@ -761,6 +770,7 @@ GtkWidget*
 snapped_widget_new (SnappedPos pos,
 		    SnappedMode mode,
 		    SnappedState state,
+		    int hidebuttons_enabled,
 		    PanelBackType back_type,
 		    char *back_pixmap,
 		    int fit_pixmap_bg,
@@ -803,6 +813,7 @@ snapped_widget_new (SnappedPos pos,
 
 	snapped->pos = pos;
 	snapped->mode = mode;
+	snapped->hidebuttons_enabled = hidebuttons_enabled;
 	if(state != SNAPPED_MOVING)
 		snapped->state = state;
 
@@ -827,6 +838,7 @@ snapped_widget_change_params(SnappedWidget *snapped,
 			     SnappedPos pos,
 			     SnappedMode mode,
 			     SnappedState state,
+			     int hidebuttons_enabled,
 			     PanelBackType back_type,
 			     char *pixmap_name,
 			     int fit_pixmap_bg,
@@ -845,6 +857,7 @@ snapped_widget_change_params(SnappedWidget *snapped,
 	oldstate = snapped->state;
 	snapped->state = state;
 	snapped->mode = mode;
+	snapped->hidebuttons_enabled = hidebuttons_enabled;
 
 	if(snapped->pos == SNAPPED_TOP ||
 	   snapped->pos == SNAPPED_BOTTOM)
@@ -899,6 +912,7 @@ snapped_widget_change_pos(SnappedWidget *snapped,
 				     pos,
 				     snapped->mode,
 				     snapped->state,
+				     snapped->hidebuttons_enabled,
 				     panel->back_type,
 				     panel->back_pixmap,
 				     panel->fit_pixmap_bg,
